--[[ Copyright (c) 2010 RAS
                   2011 FlyingBastard, L_konings, Nossah, KasperVld
                   2012-2013 Omni, Maarten
                   2024 Jetenergy

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

---------------------------------------------------------------------------------

SLEUTELWOORDEN
Chirurgen; Onderzoekers; Psychiaters
Assistenten; Basisartsen; Specialisten
Artsen; Zusters; Conciërges; Receptionistes

---------------------------------------------------------------------------------]]

Language("Nederlands", "Dutch", "nl", "dut", "nld")
Inherit("English")

newspaper = {
  [1] = {
    [1] = "DOC SHOCK HORROR",
    [2] = "ENGE ARTS SPEELT GOD",
    [3] = "DR FRANKENSTEIN GEVONDEN",
    [4] = "WAT ZAT ER OP LABJAS?",
    [5] = "ONETHISCH ONDERZOEK GESTOPT",
  },
  [2] = {
    [1] = "BEZOPEN ALS EEN VIS",
    [2] = "ZATTE CHIRURG ZOEKT SCALPEL",
    [3] = "STRAALBEZOPEN SPECIALIST",
    [4] = "IN DE LOREM",
    [5] = "CHIRURG MET LEGE PLATVINK",
    [6] = "OPEREREN ONDER INVLOED",
  },
  [3] = {
    [1] = "DOKTERTJE SPELEN IN ZIEKENHUIS",
    [2] = "DOKTER BROEKNEER",
    [3] = "PSYCHIATER GAAT PLAT",
    [4] = "ONBEVREDIGBARE ONDERZOEKER",
  },
  [4] = {
    [1] = "CREATIEF GEDOKTERT MET KASBOEK",
    [2] = "GE-ORGAAN-ISEERDE MISDAAD",
    [3] = "FINANCIELE OMLEIDINGSOPERATIES",
    [4] = "GELD VERDWIJNT IN ZIEKENHUIS",
  },
  [5] = {
    [1] = "SPECIALIST ROOFT UIT KIST",
    [2] = "ZIEKENHUISPERSONEEL STEELT UIT GRAF",
    [3] = "MET EEN LIJK IN DE PRAKTIJK",
    [4] = "TOL BETALEN AAN DOKTER DOOD",
    [5] = "TERMINALE PRAKTIJKEN",
    [6] = "GRAVEN IN GRAF GEHEKELD",
  },
  [6] = {
    [1] = "DOC NAAIT PATIENTEN!",
    [2] = "KWAKZALVERIJ",
    [3] = "TERMINALE DIAGNOSE",
    [4] = "SLONZIGE SPECIALIST",
  },
  [7] = {
    [1] = "CHIRURG HECHT AAN ZIJDEN DRAADJE",
    [2] = "CHIRURG 'OPEREERT' ZICHZELF",
    [3] = "DUISTERE DOKTERS DANS",
    [4] = "DOKTER BIBBER SCHANDAAL",
    [5] = "ZOOITJE IN ZIEKENHUIS",
  },
}
misc = {
  hospital_open = "Ziekenhuis open",
  save_success = "Spel succesvol opgeslagen",
  save_failed = "FOUT: opslaan mislukt",
  low_res = "Lage resolutie",
  no_heliport = "Er zijn nog geen ziektes ontdekt of er is geen helipad aanwezig",
  grade_adverb = {
    extremely = "zeer",
    mildly = "mild",
    moderately = "vrij",
  },
  not_yet_implemented = "(nog niet geïmplementeerd)",
  send_message = "Bericht sturen naar speler %d",
  out_of_sync = "Spel uit sync",
  balance = "Balans bestand:",
  load_failed = "Laden mislukt",
  mouse = "Muis",
  done = "Klaar",
  force = "Forceer",
  pause = "Pauze",
  send_message_all = "Bericht sturen naar alle spelers",
  cant_treat_emergency = "Je ziekenhuis kan deze noodsituatie niet behandelen omdat de ziekte nog niet is ontdekt. Probeer het gerust opnieuw.",
  earthquakes_off = "Aardbevingen zijn uitgeschakeld",
  earthquakes_on = "Aardbevingen zijn opnieuw ingeschakeld",
  epidemics_off = "Epidemieën zijn uitgeschakeld",
  epidemics_on = "Epidemieën zijn opnieuw ingeschakeld",
  epidemic_no_diseases = "Kan geen epidemie creëren - er zijn geen beschikbare besmettelijke ziekten.",
  epidemic_no_icon_to_toggle = "Kan geen geïnfecteerde iconen weergeven/verbergen - er zijn geen lopende epidemieën die niet zijn onthuld.",
  epidemic_no_receptionist = "Kan geen epidemie aanmaken - geen bemande receptie",
}
staff_descriptions = {
  good = {
    [1] = "Een snelle en ijverige werker. ",
    [2] = "Werkt nauwkeurig. Geeft veel om mensen. ",
    [3] = "Zeer competent. ",
    [4] = "Erg vriendelijk en goedlachs. ",
    [5] = "Een echte doorzetter. Gaat maar door. ",
    [6] = "Zeer beleefd en goedgemanierd. ",
    [7] = "Ongelofelijk getalenteerd en kundig. ",
    [8] = "Geeft veel om het afgeleverde werk. ",
    [9] = "Een pietje precies die maar niet opgeeft. ",
    [10] = "Toegewijd, helpt mensen met een glimlach. ",
    [11] = "Charmant, beleefd en behulpzaam. ",
    [12] = "Gemotiveerd en toegewijd. ",
    [13] = "Een zachtaardige en harde werker. ",
    [14] = "Trouw en vriendelijk. ",
    [15] = "Zorgvuldig en betrouwbaar in een noodsituatie. ",
  },
  misc = {
    [1] = "Speelt golf. ",
    [2] = "Houdt van duiken. ",
    [3] = "Maakt ijssculpturen. ",
    [4] = "Drinkt wijn. ",
    [5] = "Rijdt in rallyraces. ",
    [6] = "Doet aan bungee jumpen. ",
    [7] = "Verzamelt bierviltjes. ",
    [8] = "Houdt van stage-diving. ",
    [9] = "Houdt van ruftsurfen. ",
    [10] = "Programmeert voor CorsixTH. ", --EN: Developer for CorsixTH
    [11] = "Stookt whisky. ",
    [12] = "Een goede klusser. ",
    [13] = "Houdt van artistieke Franse films. ",
    [14] = "Speelt vaak Theme Park. ",
    [15] = "Heeft rijbewijs CE. ",
    [16] = "Doet aan motorracen. ",
    [17] = "Speelt viool en cello. ",
    [18] = "Gepassioneerd treinsloper. ",
    [19] = "Gek op honden. ",
    [20] = "Luistert graag naar de radio. ",
    [21] = "Neemt vaak een bad. ",
    [22] = "Leraar vlechtwerkjes. ",
    [23] = "Gebruikt uitgeholde groenten als zeepbakjes. ",
    [24] = "Vrijwillig politieagent. ",
    [25] = "Presenteerde een televisiequiz. ",
    [26] = "Verzamelt granaatscherven uit de Tweede Wereldoorlog. ",
    [27] = "Richt kamers in. ",
    [29] = "Pest insecten met deodorant. ",
    [28] = "Luistert naar rave en trip-hop muziek. ",
    [30] = "Haat slechte cabaretiers. ",
    [31] = "Spioneert voor de raad. ",
    [32] = "Tuiniert stiekem. ",
    [33] = "Smokkelt nephorloges. ",
    [34] = "Zingt in een rock-'n-roll band. ",
    [35] = "Aanbidt middagtelevisie. ",
    [36] = "Kietelt karpers. ",
    [37] = "Verpatst troep aan museumbezoekers. ",
  },
  bad = {
    [1] = "Langzaam en verstrooid. ",
    [2] = "Lui en ongemotiveerd. ",
    [3] = "Slecht opgeleid en lusteloos. ",
    [4] = "Grof en opdringerig. Irriteert mensen. ",
    [5] = "Geeft snel op - kan zich niet gedragen. ",
    [6] = "Doof als een kwartel. Stinkt naar bloemkool. ",
    [7] = "Slecht in het vak. Onbetrouwbaar. ",
    [8] = "Verstrooid en snel afgeleid. ",
    [9] = "Gespannen en maakt snel fouten. ",
    [10] = "Labiel en wrokkig - wordt verteerd door haat. ",
    [11] = "Slordig en onhandig. ",
    [12] = "Geeft niets om het vak. Luiaard. ",
    [13] = "Neemt, volledig apathisch, onnodig risico. ",
    [14] = "Sluw, geniepig en tegendraads. ",
    [15] = "Verwaand en zelfingenomen. ",
  },
}
information = {
  custom_game = "Welkom bij CorsixTH. Veel plezier in dit ziekenhuis!",
  cannot_restart = "Dit level is opgeslagen voordat de herstart-functie was geïmplementeerd.",
  very_old_save = "Er zijn veel updates geweest sinds je met dit level bent begonnen. Om zeker te zijn dat alles werkt zoals het hoort, kun je dit level beter opnieuw beginnen.",
  no_custom_game_in_demo = "Sorry, maar in de demo versie kan je niet als uitzendkracht werken.",
  level_lost = {
    [1] = "Balen! Je hebt het level verloren. Volgende keer beter!",
    [2] = "De reden dat je verloor:",
    reputation = "Je reputatie kwam onder %d",
    balance = "Je banksaldo was lager dan %d",
    percentage_killed = "Je hebt meer dan %d procent van je patiënten vermoord",
    cheat = "Je hebt (hopelijk niet per ongeluk) de \"Verlies het huidige level\" optie gebruikt", -- Zie ook cheats_window.cheats.lose_level
  },
  cheat_not_possible = "Cheat kan niet toegepast worden op dit level.",
}

staff_list = {
  morale = "MORAAL",
  tiredness = "VERMOEIDHEID",
  skill = "BEKWAAMHEID",
  total_wages = "SALARIS",
}
research = {
  allocated_amount = "Totale hoeveelheid",
  funds_allocation = "Totaal budget",
  categories = {
    improvements = "Verbeteringen",
    drugs = "Geneesmiddelen",
    diagnosis = "Diagnostische apparatuur",
    cure = "Behandelmethoden",
    specialisation = "Specialisatie",
  },
}
room_classes = {
  diagnosis = "Diagnose",
  clinics = "Klinieken",
  facilities = "Faciliteiten",
  treatment = "Behandeling",
}
buy_objects_window = {
  price = "Prijs: ",
  choose_items = "Kies voorwerpen",
  total = "Totaal: ",
}
place_objects_window = {
  pick_up_object = "Klik op het voorwerp dat je wil verplaatsen of kies een andere optie.",
  place_objects_in_corridor = "Plaats de voorwerpen in je ziekenhuis.",
  place_windows = "Plaats, indien gewenst, ramen en klik op bevestigen.",
  confirm_or_buy_objects = "Je kunt nu de kamer bevestigen of voorwerpen kopen of verplaatsen",
  drag_blueprint = "Sleep de blauwdruk tot je de gewenste grootte hebt bereikt.",
  place_door = "Plaats de deur.",
  place_objects = "Plaats de voorwerpen naar tevredenheid. Klik ten slotte op bevestigen.",
}
totd_window = {
  previous = "Vorige tip",
  tips = {
    "Elk ziekenhuis begint met een receptie en een praktijk. Daarna ligt het er helemaal aan wat voor patiënten er langskomen. Een apotheek is altijd een goede volgende keuze.",
    "Machines zoals de compressor in inflatie hebben onderhoud nodig. Huur één of twee conciërges in om je machines te repareren, anders loop je het risico je personeel en je patiënten te verwonden.",
    "Op een gegeven moment wordt je personeel moe. Bouw een personeelsruimte zodat ze zich kunnen ontspannen.",
    "Plaats genoeg radiatoren om je personeel en je patiënten warm, en daarmee tevreden te houden.",
    "De bekwaamheid van een arts bepaalt hoe snel en hoe goed zijn diagnoses zijn. Als je een goede arts in de praktijk plaatst, heb je ook niet zoveel diagnostische kamers nodig.",
    "Assistenten en basisartsen kunnen zich laten opleiden door een specialist in het klaslokaal. Als de specialist een specifieke kwalificatie heeft (chirurg, psychiater of onderzoeker), zal hij deze kennis overdragen aan zijn leerling(en).",
    "Heb je al geprobeerd het alarmnummer (112) te bellen op de faxmachine? Zet wel je geluid eerst aan!",
    "Je kunt instellingen zoals de schermresolutie en de taal in het instellingen menu wijzigen. Het instellingen menu is in het spel en in het hoofdmenu te vinden.",
    "De Nederlandse vertaling is up to date. Zie je toch nog Engelse woorden, of heb je een schrijf- of taalfout ontdekt? Meldt het alsjeblieft op het forum (www.corsixth.com).",
    "Het CorsixTH team zoekt versterking! Zou je willen coden, vertalen of graphics willen maken? Neem dan contact met ons op via ons forum (www.corsixth.com) of ons IRC kanaal (corsix-th op Freenode).",
    "Als je een bug vindt zouden we het op prijs stellen als je deze meldt via onze bugtracker: th-issues.corsix.org",
    "Bij elk level moet je aan bepaalde eisen voldoen voordat je door kunt gaan naar het volgende level. Controleer het statusscherm om te zien hoe ver of dicht je bij je doel bent.",
    "Als je een bestaande kamer wil aanpassen of verwijderen, kun je dat doen met de aanpassen-knop op de werkbalk.",
    "Je kunt eenvoudig uitvissen welke patiënten, van een grote groep, voor een bepaalde kamer staan te wachten door met je cursor in die kamer te gaan ''staan.''",
    "Klik op de deur van een kamer om de wachtrij voor die kamer te zien. Je zou ook wat aan kunnen passen, zoals de volgorde van de rij veranderen of een patiënt naar een andere kamer sturen.",
    "Ongelukkige werknemers zullen vaak om salarisverhoging vragen. Zorg voor een comfortabele werkomgeving om dit soort situaties te voorkomen.",
    "Patiënten krijgen dorst van het wachten, en het gaat helemaal hard als je de verwarming flink opschroeft! Plaats frisdrankautomaten op strategische locaties voor een extra zakcentje.",
    "Je kunt het diagnostische proces voor een patiënt vroegtijdig stopzetten als je al weet wat voor ziekte hij of zij heeft. Maar pas op, dit vergroot de kans op een verkeerde behandeling, wat fataal kan zijn voor de patiënt.",
    "Noodgevallen zijn vaak een goede bron van extra inkomsten. Maar je moet er wel zeker van zijn dat je deze patiënten binnen de tijd kunt behandelen.",
    "Wist je dat je klusjes mensen aan specifieke percelen kunt toewijzen? Klik gewoon op de tekst 'Overal' in hun personeelsprofiel om er doorheen te bladeren!",
  },
  next = "Volgende tip",
}
rooms_long = {
  ultrascan = "Ultrascan",
  research_room = "Laboratorium",
  general = "Algemeen",
  gps_office = "Praktijk",
  inflation = "Inflatie",
  staffroom = "Personeelsruimte",
  jelly_vat = "Gelatinetank",
  scanner = "Scanner",
  emergency = "Noodsituatie",
  decontamination = "Ontsmetting",
  corridors = "Gangen",
  cardiogram = "Cardiogram",
  ward = "Slaapzaal",
  training_room = "Klaslokaal",
  psychiatric = "Psychiatrie",
  operating_theatre = "Operatiekamer",
  dna_fixer = "DNA hersteller",
  tongue_clinic = "Lamme tongkliniek",
  hair_restoration = "Haarrestaurateur",
  general_diag = "Algemene diagnose",
  pharmacy = "Apotheek",
  fracture_clinic = "Gipskamer",
  toilets = "Toilet",
  electrolysis = "Elektrolysekliniek",
  x_ray = "Röntgenkamer",
  blood_machine = "Bloedmachinekamer",
}
options_window = {
  custom_resolution = "Aangepast...",
  caption = "Opties",
  option_on = "Aan",
  option_off = "Uit",
  resolution = "Resolutie",
  apply = "Toepassen",
  language = "Taal",
  fullscreen = "Volledig scherm",
  height = "Hoogte",
  width = "Breedte",
  change_resolution = "Resolutie wijzigen",
  back = "Terug",
  cancel = "Annuleren",
  folder = "Mappen",
  audio = "Audio algemeen",
  customise = "Aangepast",
  capture_mouse = "Cursor Vangen",
  check_for_updates = "Controleren op Updates",
  hotkey = "Sneltoetsen",
  jukebox = "Jukebox",
  option_disabled = "Uitgeschakeld",
  option_enabled = "Ingeschakeld",
  right_mouse_scrolling = "Muis Scrollen",
  right_mouse_scrolling_option_middle = "Middelste Knop",
  right_mouse_scrolling_option_right = "Rechterknop",
  scrollspeed = "Scrollsnelheid",
  shift_scrollspeed = "Shift Scrollsnelheid",
  zoom_speed = "Zoomsnelheid",
}
load_game_window = {
  caption = "Spel laden (%1%)",
}
queue_window = {
  num_in_queue = "Rijlengte",
  num_entered = "Bezoekers",
  max_queue_size = "Max lengte",
  num_expected = "Verwacht",
}
font_location_window = {
  caption = "Kies font (%1%)",
}
update_window = {
  new_version = "Nieuwe versie:",
  caption = "Update beschikbaar!",
  download = "Ga naar de download pagina",
  current_version = "Huidige versie:",
  ignore = "Negeer en ga naar het menu",
}
folders_window = {
  screenshots_location = "Selecteer de map om screenshots in op te slaan",
  music_label = "MP3's",
  back = "Terug",
  savegames_label = "Opgeslagen spellen",
  caption = "Bestands locaties",
  savegames_location = "Selecteer de map om spellen in op te slaan",
  font_label = "Lettertype",
  new_th_location = "Kies hier een andere map voor de Them Hospital installatie. Hiervoor wordt het spel opnieuw gestart.",
  screenshots_label = "Screenshots",
  music_location = "Selecteer de map die je wilt gebruiken voor muziek.",
  data_label = "TH Data",
}
customise_window = {
  movies = "Video algemeen",
  option_on = "Aan",
  option_off = "Uit",
  back = "Terug",
  paused = "Bouwen tijdens pause",
  intro = "Speel intro video",
  volume = "Volume lager koppeling",
  caption = "Aangepaste instellingen",
  fractured_bones = "Gebroken botten",
  average_contents = "Gemiddeld meubilair",
  aliens = "Alien patiënten",
  remove_destroyed_rooms = "Verwijder verwoeste kamers",
}

trophy_room = { --gebruik hiervoor meer formele tekst
  happy_vips = {
    trophies = {
      [1] = "Door de indruk die je hebt gemaakt op VIPs heb je een nobelprijs gewonnen. Iedereen die je ziekenhuis bezocht sprak niets dan lof.",
      [2] = "Het Beroemde Personenbureau keert u bij dezen de Celebrity trofee uit voor de lof die u van alle VIPs heeft ontvangen. Beschouw uzelf een beetje beroemd en bijna een van ons.",
      [3] = "Gefeliciteerd met het winnen van de VIP TRIP. U maakt de levens van hardwerkende beroemdheden een stuk mooier, door het ze allemaal naar hun zin te maken. Fantastisch!",
    },
  },
  rats_killed = {
    awards = {
    },
    trophies = {
      [1] = "Je hebt de Anti-Ongedierte trofee gewonnen voor het schieten van %d ratten in je ziekenhuis in het afgelopen jaar.",
      [2] = "Deze trofee wordt aangeboden door de Federatie Tegen Ratten en Muizen om uw uitzonderlijke schietwerk op %d ratten te eren.",
      [3] = "Deze Rattenknaller trofee wordt u aangeboden voor het afschieten van %d ratten in het afgelopen jaar.",
    },
  },
  rats_accuracy = {
    awards = {
    },
    trophies = {
      [1] = "U krijgt de Syndicate Wars Precisie trofee omdat %d%% van de schoten die u op ratten afvuurde doel troffen.",
      [2] = "Deze trofee eert uw fantastische precisie in het afschieten van  %d%% van de ratten waar u in het afgelopen jaar op gemikt heeft.",
      [3] = "Om te vieren dat u afgelopen jaar %d%% van alle ratten in uw ziekenhuis heeft uitgeroeid, belonen wij u met de Dungeon Keeper Ongediertevrij trofee. ProficiRAT",
    },
  },
  all_cured = {
    awards = {
      [1] = "Gefeliciteerd met het winnen van de Marie Curie Award voor het behandelen van alle patiënten in uw ziekenhuis in het afgelopen jaar.",
    },
    trophies = {
      [1] = "De Internationale Geneesstichting wil u eren met de Gezondheid voor Iedereen trofee voor het genezen van iedereen die in het afgelopen jaar uw ziekenhuis binnen is komen lopen.",
      [2] = "U krijgt de Geen Zieke Rochel trofee voor het genezen van alle patiënten die in het afgelopen jaar uw ziekenhuis hebben bezocht.",
    },
  },
  many_cured = {
    awards = {
      [1] = "Gefeliciteerd met het winnen van de Marie Curie Award voor het behandelen van bijna alle patiënten in uw ziekenhuis in het afgelopen jaar.",
      [2] = "U ontvangt deze trofee omdat u meer patiënten heeft genezen dan alle andere ziekenhuizen. Een opvallende prestatie.",
    },
    trophies = {
      [1] = "De Internationale Geneesstichting wil u eren met de Gezondheid voor Alles trofee voor het genezen van massa's mensen die in het afgelopen jaar uw ziekenhuis binnen zijn komen lopen.",
      [2] = "U krijgt de onderscheiding Het Kwieke Hoentje voor het genezen van een groot aantal patiënten dat in het afgelopen jaar uw ziekenhuis heeft bezocht.",
      [3] = "Hierbij ontvangt u de Gezonde Gorgel, een prijs voor het genezen van een enorm percentage van uw bezoekers in het afgelopen jaar.",
    },
    penalty = {
      [1] = "Het lukt uw ziekenhuis niet de patiënten effectief te genezen. Concentreer u op goede behandelmethoden, zodat behandelingen effectiever worden.",
      [2] = "Uw ziekenhuis is het minst effectief als het gaat om patiënten genezen. U heeft het ministerie teleur gesteld. Moeten we nog meer zeggen?",
    },
    regional = {
      [1] = "Vanwege het feit dat u meer zieken heeft genezen dan alle andere ziekenhuizen bij elkaar opgeteld, ontvangt u hiervoor de hoogst haalbare onderscheiding. Gefeliciteerd!",
    },
  },
  healthy_plants = {
    awards = {
      [1] = "Gefeliciteerd met het winnen van de Oei Ik Groei award voor de fantastische staat van de planten in uw ziekenhuis.",
    },
    trophies = {
      [1] = "De Vrienden van de Potplanten willen u de Groene Gezondheid trofee uitreiken voor de blakende gezondheid waarin uw planten zich de afgelopen twaalf maanden hebben verkeerd",
      [2] = "De Frisse Narcissen willen u de Groene Vingers trofee uitreiken voor de uitstekende gezondheid van uw planten in het afgelopen jaar.",
    },
  },
  no_deaths = {
    awards = {
      [1] = "U heeft de Nimmer Vergaan award gewonnen voor het in leven houden van al uw patiënten in het afgelopen jaar.",
      [2] = "Uw talent heeft gezorgd voor een minimaal aantal sterfgevallen in uw ziekenhuis. U kunt apetrots zijn op dit resultaat.",
    },
    trophies = {
      [1] = "De 'Het Leven Gaat Door'-corporatie presenteert u deze trofee omdat er in het afgelopen jaar geen mensen zijn overleden.",
      [2] = "U heeft de Overlijden Vermijden trofee uitgereikt gekregen voor het in leven houden van elke bezoeker van uw fantastische ziekenhuis in het afgelopen jaar. Bravo.",
      [3] = "Hierbij ontvangt u de 'Ik Leef Nog' prijs omdat dit jaar geen van uw patiënten is overleden in uw mooie ziekenhuis. Heel goed.",
    },
    penalty = {
      [1] = "Het aantal overledenen in uw ziekenhuis was het afgelopen jaar behoorlijk hoog. Let goed op en zorg dat in de toekomst meer mensen de behandeling overleven.",
      [2] = "Uw ziekenhuis is een gevaar voor de gezondheid van de patiënt. Er wordt verwacht dat u mensen geneest, niet laat doodgaan!",
    },
    regional = {
      [1] = "Het dodental in uw ziekenhuis was het laatste jaar lager dan dat van ieder ander ziekenhuis. Daarvoor bieden wij u deze trofee aan.",
    },
  },
  sold_drinks = {
    awards = {
    },
    trophies = {
      [1] = "De Wereld Tandartsen Vereniging is trots om u deze trofee en plak te presenteren voor het verkopen van massa's frisdrank in uw ziekenhuis.",
      [2] = "Uw ziekenhuis heeft de Frisse Zaak trofee gewonnen voor de grote hoeveelheid drankjes die uw gasten in het afgelopen jaar hebben gekocht.",
      [3] = "Uit naam van Goedgevuld Inc. presenteren wij u vol trots deze met chocola overgoten trofee ter ere van uw uitzonderlijk hoge aantal verkochte blikjes frisdrank.",
    },
  },
  high_rep = {
    awards = {
      [1] = "Hierbij eren wij uw hoge standaarden en een reputatie die dit jaar gewoon niet beter kan zijn. Goed werk.",
      [2] = "Gefeliciteerd met de Zuijver Op Den Graet trofee voor het ziekenhuis met de hoogste reputatie van het land. En het is welverdiend ook.",
    },
    penalty = {
      [1] = "Deze maatregel wordt genomen vanwege de zeer slechte reputatie over het afgelopen jaar. We gaan ervan uit dat u verbetering laat zien in de toekomst.",
      [2] = "De reputatie van uw ziekenhuis is het laagst in de omgeving. U bent een schande. Laat verbetering zien, of zoek een andere baan!",
    },
    regional = {
      [1] = "Wij bieden u de Bullfrog Award aan voor de hoogste reputatie van alle ziekenhuizen in het afgelopen jaar. Geniet ervan - u heeft het verdiend.",
      [2] = "Dit jaar behaalde uw ziekenhuis een reputatie die hoger is dan alle andere ziekenhuizen bij elkaar. Een enorme prestatie.",
    },
  },
  consistant_rep = {
    trophies = {
      [1] = "Hierbij ontvangt u de hoogste onderscheiding van het ministerie voor de meest onberispelijke standaarden en de hoogst mogelijke reputatie dit jaar. Heel goed.",
      [2] = "Proficiat met het behalen van de Brandschoon Trofee voor het ziekenhuis met de beste reputatie in het afgelopen jaar. Welverdiend.",
    },
  },
  happy_patients = {
    awards = {
      [1] = "U mag trots zijn op het feit dat bezoekers van uw ziekenhuis in het afgelopen jaar bijzonder tevreden waren.",
      [2] = "Bezoekers van uw ziekenhuis waren gemiddeld meer tevreden tijdens hun behandeling, dan bezoekers van andere ziekenhuizen in het spel.",
    },
    penalty = {
      [1] = "Bezoekers van uw ziekenhuis vinden het verschrikkelijk. U zult veel beter moeten presteren om waardering van het ministerie te krijgen.",
      [2] = "Mensen die in uw ziekenhuis in behandeling zijn, zijn zeer ontevreden over de staat van het ziekenhuis. U moet meer aandacht schenken aan het wel en wee van de patiënten.",
    },
  },
  happy_staff = {
    awards = {
      [1] = "Deze oorkonde ontvangt u van uw eigen personeel. Er is natuurlijk nog ruimte voor verbetering, maar over het algemeen wordt u als werkgever zeer gewaardeerd.",
      [2] = "Uw personeel is zo tevreden en gemotiveerd, niets kan hun glimlach nog verpesten. U bent een geweldige manager!",
    },
    trophies = {
      [1] = "U krijgt de Smiley trofee voor het zo gelukkig mogelijk houden van uw hardwerkende personeel.",
      [2] = "Het Adami Instituut van Tevredenheid keert u hierbij deze trofee uit omdat uw personeel geen moment blijk heeft gegeven van ontevredenheid.",
      [3] = "Deze trofee, de Straalmeer Cup, is hierbij de uwe voor uw inzet voor het welzijn en de tevredenheid van uw personeel. Een glimlach van iedereen!",
    },
    penalty = {
      [1] = "Uw personeel laat officieel weten dat ze ontevreden zijn. Gemotiveerd personeel is waardevol. Werk aan hun tevredenheid voor u ze helemaal zult verliezen.",
    },
    regional_good = {
      [1] = "Uw personeel is meer tevreden dan dat van andere ziekenhuizen. Tevreden personeel betekent meer inkomsten en minder sterfgevallen. Dit wordt door het ministerie zeer gewaardeerd.",
    },
    regional_bad = {
      [1] = "Uw personeel heeft zich het afgelopen jaar ontevreden getoond. Heeft u dat niet gemerkt? Op dit moment heeft ieder ander ziekenhuis meer tevreden personeel dan uw ziekenhuis.",
    },
  },
  wait_times = {
    award = { --attention: this string says AWARD, not AWARDS
      [1] = "Gefeliciteerd. Uw ziekenhuis heeft altijd zeer korte wachttijden. Dit is een belangrijke onderscheiding.",
    },
    penalty = {
      [1] = "Patiënten in uw ziekenhuis moeten veel te lang wachten. Er zijn altijd enorme wachtrijen. U kunt uw patiënten veel efficiënter helpen, maar daar moet u wel wat voor doen.",
    },
  },
  hosp_value = {
    awards = {
      [1] = "Het Ministerie van Volksgezondheid wil dit moment graag gebruiken om u te feliciteren met de indrukwekkende waarde die uw ziekenhuis heeft behaald.",
    },
    penalty = {
      [1] = "Uw ziekenhuis heeft gefaald een behoorlijke waarde te behalen. U heeft slechte financiële keuzes gemaakt. Houd in uw achterhoofd dat een goed ziekenhuis niet goedkoop is.",
    },
    regional = {
      [1] = "U bent een financieel wonder! Uw ziekenhuis is meer waard dan alle andere ziekenhuizen in de omgeving bij elkaar opgeteld.",
    },
  },
  best_value_hosp = {
    trophies = {
      [1] = "Proficiat met het behalen van de Brandschoon trofee voor het ziekenhuis met de beste reputatie in het afgelopen jaar. Welverdiend.",
    },
    penalty = {
      [1] = "Elke ziekenhuis in de omgeving is meer waard dan die van u. Doe iets aan deze beschamende gang van zaken. Zorg voor mooie en dure apparatuur!",
    },
    regional = {
      [1] = "Gefeliciteerd met het meest waardevolle ziekenhuis in het spel, goed werk. Probeer dat zo te houden.",
    },
  },
  curesvdeaths = {
    awards = {
      [1] = "Hartelijk gefeliciteerd met het behalen van een indrukwekkende genezen-of-overleden rato in uw ziekenhuis in het afgelopen jaar.",
    },
    penalty = {
      [1] = "Uw genezen-of-overleden rato is erg slecht. U moet ervoor zorgen u veel meer mensen geneest dan laat sterven. Laat het er niet bij zitten.",
    },
  },
  cleanliness = {
    award = {  --attention: this string says AWARD, not AWARDS
      [1] = "Inspecteurs vinden uw ziekenhuis heel schoon. Schone ziekenhuizen zijn veilige ziekenhuizen. Houden zo.",
    },
    regional_good = {
      [1] = "Uw ziekenhuis wordt genoemd als een van de minst schone in de omgeving. Een smerig ziekenhuis stinkt en is gevaarlijk. U moet meer aandacht hebben voor troep.",
    },
    regional_bad = {
      [1] = "Uw ziekenhuis is het smerigst van de regio. Alle andere managers is het gelukt hun gangen schoner te houden. U bent een schande voor de medische wereld.",
    },
  },
  gen_repairs = {
    awards = {
      [1] = "U ontvangt deze prijs vanwege de oplettendheid van uw conciërges die alle apparatuur heel goed hebben onderhouden. Heel goed. U kunt gerust op vakantie.",
      [2] = "Uw conciërges hebben beter gepresteerd dan die van andere ziekenhuizen. Dit is een enorme prestatie. Ere wie ere toekomt.",
      [3] = "Uw apparatuur is fantastisch onderhouden. De motivatie van uw conciërges in uitmuntend. Deze prijs heeft u meer dan verdiend. Geweldig!.",
    },
    penalty = {
      [1] = "Uw conciërges hebben uw apparatuur niet goed onderhouden. U moet hen beter in de gaten houden, of meer conciërges aannemen als het teveel werk is.",
      [2] = "Het onderhoud is een drama. Uw personeel moet de apparatuur beter in de gaten houden en zorgvuldiger onderhouden.",
    },
  },
  emergencies = {
    award = {  --attention: this string says AWARD, not AWARDS
      [1] = "Gefeliciteerd: vanwege uw efficiënte en effectieve manier van afhandelen van noodgevallen, ontvangt u deze speciale prijs. Goed werk.",
      [2] = "Uw werkwijze bij noodgevallen is een unicum. Deze prijs ontvangt u, omdat u absoluut het beste omgaat met grote drommen zieken en zwakken.",
    },
    penalty = {
      [1] = "U heeft noodgevallen niet goed afgehandeld. Spoed eisende patiënten moeten direct en goed worden geholpen, dat is u niet gelukt.",
    },
    regional_good = {
      [1] = "Het ministerie heeft het afgelopen jaar gezien dat u noodgevallen beter aankunt dan ieder ander ziekenhuis. Daarvoor ontvangt u deze prijs.",
    },
    regional_bad = {
      [1] = "Uw ziekenhuis doet het het slechtst van de regio als het gaat om noodgevallen. Het is uw eigen fout dat u onderaan de lokale noodgevallen ranglijst bungelt.",
    },
  },
  pop_percentage = {
    awards = {
      [1] = "Heeft u gezien dat een groot deel van de lokale bevolking voor uw ziekenhuis heeft gekozen? Goed gedaan.",
      [2] = "Gefeliciteerd. Vergeleken met andere medische instellingen heeft uw ziekenhuis het grootste aandeel in de bezoekers uit de regio.",
      [3] = "Briljant! U heeft meer lokale bewoners naar uw ziekenhuis weten te lokken dan alle andere ziekenhuizen bij elkaar opgeteld.",
    },
    penalty = {
      [1] = "Heel weinig mensen hebben dit jaar uw ziekenhuis bezocht. Om geld te verdienen heeft uw ziekenhuis voldoende betalende zieken nodig!",
      [2] = "Elk ziekenhuis in de omgeving heeft een groter aandeel lokale bewoners mogen begroeten dan u. Schaamt u zich niet een beetje?",
    },
  },
  research = {
    awards = {
      [1] = "Uw onderzoekers hebben er het afgelopen jaar voor gezorgd dat uw ziekenhuis volledig up-to-date is met de nieuwste ontwikkelingen. Uw personeel heeft deze onderscheiding verdiend. Heel goed.",
      [2] = "Het afgelopen jaar heeft u meer medicijnen en apparatuur ontwikkeld dan was verwacht. Wij bieden u deze prijs aan namens het volledige ministerie.",
    },
    penalty = {
      [1] = "U heeft een minimale hoeveelheid behandelmethoden, medicijnen en apparatuur ontwikkeld. Dit is helemaal niet goed, technologische vooruitgang is essentieel.",
    },
    regional_good ={
      [1] = "Uw onderzoekers hebben er het afgelopen jaar voor gezorgd dat uw ziekenhuis volledig up-to-date is met de nieuwste ontwikkelingen. Uw personeel heeft deze onderscheiding verdiend. Heel goed.",
    },
    regional_bad = {
      [1] = "Ieder ander ziekenhuis in de regio heeft meer en beter onderzoek gedaan dan u. Omdat onderzoek cruciaal is voor een ziekenhuis, noemt het ministerie dit onacceptabel.",
    },
  },
  reputation = "REPUTATIE",
  cash = "GELD",
}
save_game_window = {
  caption = "Spel opslaan (%1%)",
  new_save_game = "Nieuw bestand",
}
staff_class = {
  doctor = "Arts",
  handyman = "Conciërge",
  receptionist = "Receptioniste",
  nurse = "Zuster",
  surgeon = "Chirurg",
}
fax = {
  epidemic_result = {
    fine_amount = "De regering heeft een nationaal alarm afgekondigd en legt u een boete op van %d.",
    close_text = "Fantastisch!",
    hospital_evacuated = "De commissie heeft geen andere keus dan het ziekenhuis te evacueren.",
    succeeded = {
      part_1_name = "De inspecteur heeft geruchten gehoord dat uw instituut gebukt ging onder zware gevallen van %s.",
      part_2 = "Hij heeft echter geen bewijzen gevonden ter bevestiging van deze geruchten.",
    },
    compensation_amount = "De regering heeft derhalve besloten u een schadevergoeding toe te kennen ter waarde van %d ter compensatie voor de schade die uw goede naam heeft geleden door deze leugens.",
    failed = {
      part_1_name = "Tijdens het verbergen van de uitbraak van %s",
      part_2 = "heeft je personeel de ziekte verspreidt onder de bevolking.",
    },
    rep_loss_fine_amount = "De media zal hiervan smullen. Dit is een zware klap voor je reputatie. Daarbij moet je een boete betalen van %d.",
  },
  vip_visit_query = {
    choices = {
      invite = "De VIP officieel uitnodigen.",
      refuse = "De VIP met een smoesje afwimpelen.",
    },
    vip_name = "%s wil graag je ziekenhuis bezoeken.",
  },
  vip_visit_result = {
    telegram = "Telegram!",
    remarks = {
      [1] = "Dat ziekenhuis loopt als een trein. Als mijn gezondheid me in de steek laat, wil ik daarnaartoe.",
      [2] = "Dat is pas een ziekenhuis!",
      [3] = "Wat een fantastisch ziekenhuis. En ik kan het weten: ik heb er wel een paar van binnen gezien.",
      [4] = "Dat ziekenhuis draait goed. Bedankt voor de uitnodiging.",
      [5] = "Hmm. Zeker een niet al te kwade medische instelling.",
      [6] = "Ik heb genoten van je charmante ziekenhuis. Goed, iemand zin in Nasi Goreng van de Indonees?",
      [7] = "Nou ja, het kan erger. Maar je moet er wat aan werken.",
      [8] = "Oh jee. Niet zo een fijne plaats als je je niet lekker voelt.",
      [9] = "Een matig ziekenhuis, eerlijk gezegd. Ik had meer verwacht.",
      [10] = "Was dat het nou? Het was nog erger dan een opera van vier uur!",
      [11] = "Ik walg van wat ik gezien heb. Was dat een ziekenhuis? Het leek meer op een zwijnenstal!",
      [12] = "Ik ben het zat een publiek figuur te zijn en zulke ranzige hokken te moeten bezoeken! Ik kap ermee.",
      [13] = "Wat een zooi. Ik ga kijken of ik het kan laten sluiten.",
      [14] = "Ik heb nog nooit zo'n verschrikkelijk ziekenhuis gezien. Wat een schande!",
      [15] = "Ik ben geschokt. Dat is toch geen ziekenhuis? Ik heb een biertje nodig.",

      free_build = {
        [1] = "U heeft een heel mooi ziekenhuis neergezet. Dat is natuurlijk ook niet zo moeilijk als geld geen rol speelt he?",
        [2] = "Ik ben geen econoom, maar ik denk dat ik dit ziekenhuis ook wel zou kunnen besturen, als u begrijpt wat ik bedoel...",
        [3] = "Een heel goed lopend ziekenhuis. Pas wel op voor de economische crisis! Oh nee... Daar hoeft u zich natuurlijk geen zorgen om te maken.",
      },
    },
    rep_boost = "Je reputatie is verbeterd!",
    vip_remarked_name = "Na zijn bezoek zei %s:",
    cash_grant = "Je hebt een bonus gekregen van %d.",
    rep_loss = "Je reputatie is heeft een flinke deuk opgelopen.",
    close_text = "Bedankt voor uw bezoek aan ons ziekenhuis.",
  },
  disease_discovered_patient_choice = {
    need_to_build = "Je moet een %s bouwen om dit te kunnen behandelen.",
    need_to_employ = "Huur een %s om deze situatie te behandelen.",
    what_to_do_question = "Wat moeten we met de patiënt doen?",
    guessed_percentage_name = "Je team moest raden naar de conditie van de patiënt. De kans dat het %s is bedraagt %d",
    choices = {
      send_home = "Stuur de patiënt naar huis.",
      research = "Stuur de patiënt naar het laboratorium.",
      wait = "Laat de patiënt even geduld hebben.",
    },
    disease_name = "Je team heeft een nieuwe ziekte ontdekt. Het is %s",
    need_to_build_and_employ = "Als je een %s bouwt en een %s aanneemt, kun je slagen.",
    can_not_cure = "Je kunt deze ziekte nu niet genezen.",
  },
  emergency_result = {
    earned_money = "Van de maximum bonus van %d heb je %d verdiend.",
    close_text = "Sluiten.",
    saved_people = "Je hebt %d van de %d patiënten genezen.",
  },
  disease_discovered = {
    discovered_name = "Je team heeft een nieuwe ziekte ontdekt. Het is %s",
    need_to_employ = "Neem een %s aan om dit probleem te overwinnen.",
    need_to_build_and_employ = "Als je een %s bouwt en een %s aanneemt, kun je slagen.",
    need_to_build = "Je moet een %s bouwen om dit te kunnen behandelen.",
    close_text = "Een nieuwe ziekte is ontdekt.",
    can_cure = "Je kunt deze ziekte genezen.",
  },
  emergency = {
    locations = {
      [1] = "Bakker's Chemische Fabriek.",
      [2] = "Schamper Universiteit.",
      [3] = "het Paraquat Tuincentrum.",
      [4] = "het instituut voor onderzoek naar gevaarlijke stoffen.",
      [5] = "het Klompendansers congres.",
      [6] = "Café de Brullende Kikker.",
      [7] = "Dikke Davids Bier- en Uitvaartwinkel.",
      [8] = "de lokale Chinees.",
      [9] = "Berts Gebruikte Petrochemische Producten Emporium.",
    },
    num_disease = "Er zijn %d mensen met %s die onmiddellijk hulp nodig hebben.",
    num_disease_singular = "Er is één persoon met %s die onmiddellijk hulp nodig heeft.",
    cure_possible_drug_name_efficiency = "Je hebt alle benodigde apparatuur en hulpverleners. Je hebt het geneesmiddel voor %s, deze is %d procent effectief.",
    cure_not_possible_employ = "Je zult een %s moeten aannemen",
    cure_not_possible = "Je kunt op dit moment de ziekte niet genezen.",
    cure_possible = "Je hebt de benodigde apparatuur en hulpverleners, dus je zou dit noodgeval aan moeten kunnen.",
    choices = {
      accept = "Ja, ik ben klaar om dit noodgeval te behandelen.",
      refuse = "Nee, ik weiger dit noodgeval te behandelen.",
    },
    location = "Er is een ongeluk gebeurd bij %s",
    cure_not_possible_build = "Je zult een %s moeten bouwen",
    cure_not_possible_build_and_employ = "Je zult een %s moeten bouwen en een %s moeten aannemen.",
    bonus = "De maximumbonus voor dit noodgeval bedraagt %d. Als je echter niet slaagt, zal je reputatie schade oplopen.",
    free_build = "Als je slaagt, is dit goed voor je reputatie. Als je echter niet slaagt, zal je reputatie schade oplopen.",
  },
  choices = {
    decline_new_level = "Nog even blijven doorspelen",
    accept_new_level = "Naar het volgende level",
    return_to_main_menu = "Terug naar het hoofdmenu",
  },
  debug_fax = {
    text4 = "FACTORS  : DOCS %d  NURSES %d  AREA %d  ROOMS %d  PRICING %d",
    text5 = "CONTRIBN : DOCS %d  NURSES %d  AREA %d  ROOMS %d  PRICING %d PERCENT",
    text3 = "FIGURES  : DOCS %d  NURSES %d  AREA %d  ROOMS %d  PRICING %d",
    text9 = "DISASTERS %d ALLOWED (MTHS) %d (%d)REDUCTION %d",
    close_text = "Ja ja!",
    text1 = "BEST COUNT %d",
    text6 = "THE FOLLOWING FACTORS ARE ALSO APPLIED",
    text8 = "AMENITIES %d PEEPS HANDLED %d REDUCTION %d",
    text2 = "TOTAL PEOPLE IN HOSPITAL %d CHECKING AGAINST %d",
    text10 = "KILLS %d ALLOWED (MTHS) %d (%d) REDUCTION %d",
    text11 = "PEOPLE THIS MONTH %d",
    text7 = "REPUTATION: %d EXPECTED %d REDUCTION %d",
  },
  epidemic = {
    cover_up_explanation_1 = "Als je probeert dit te verbergen, heb je een beperkte tijd om alle geïnfecteerde patiënten te genezen voor de inspectie erachter komt.",
    cover_up_explanation_2 = "Als je bezoek krijgt van een inspecteur terwijl je nog bezig bent de epidemie op te lossen, kan hij drastische maatregelen tegen je nemen.",
    choices = {
      cover_up = "Alle geïnfecteerde patiënten proberen te genezen voor de tijd voorbij is of iemand je ziekenhuis verlaat.",
      declare = "Een epidemie afkondigen. Betaal de boete en je reputatie eronder laten lijden.",
    },
    disease_name = "Je artsen hebben een besmettelijke variant van %s ontdekt.",
    declare_explanation_fine = "Als je een epidemie afkondigt, betaal je een boete van %d en worden al je patiënten automatisch ingeënt. Je reputatie zal hieronder lijden.",
  },
  diagnosis_failed = {
    choices = {
      send_home = "Stuur patiënt naar huis.",
      take_chance = "Waag de gok en probeer de behandeling.",
      wait = "Laat de patiënt even wachten terwijl je meer diagnostische kamers bouwt.",
    },
    situation = "We hebben al onze diagnostische opties al gebruikt, maar we weten nog steeds niet precies wat er met deze patiënt aan de hand is.",
    what_to_do_question = "Wat moeten we doen met deze patiënt?",
    partial_diagnosis_percentage_name = "Er is een kans van %d procent dat we weten wat voor soort %s de patiënt heeft.",
  },
}
bank_manager = {
  current_loan = "Uitstaande lening",
  balance = "Saldo",
  interest_payment = "Maandelijkse rente",
  hospital_value = "Waarde ziekenhuis",
  interest_rate = "Rentevoet",
  insurance_owed = "Deb. Verzekeringen",
  statistics_page = {
    balance = "Saldo",
    details = "Omschrijving",
    date = "Datum",
    current_balance = "Huidig Saldo",
    money_in = "Bij",
    money_out = "Af",
  },
  inflation_rate = "Inflatie",
}
staff_title = {
  junior = "Assistent",
  psychiatrist = "Psychiater",
  consultant = "Specialist",
  surgeon = "Chirurg",
  doctor = "Basisarts",
  researcher = "Onderzoeker",
  nurse = "Zuster",
  receptionist = "Receptioniste",
  general = "Algemeen",
}
tooltip = {
  message = {
    button = "Klik op de linkermuisknop om het bericht te openen",
    button_dismiss = "Klik op de linkermuisknop om het bericht te openen, klik op de rechtermuisknop om het te negeren",
  },
  lua_console = {
    textbox = "Voer LUA code in om uit te voeren",
    execute_code = "Voer de ingevoerde code uit",
    close = "Sluit de console",
  },
  fax = {
    close = "Sluit dit scherm zonder de fax weg te gooien",
  },
  cheats_window = {
    close = "Sluit het cheatmenu",
    cheats = {
      end_month = "Spring naar het einde van de maand.",
      emergency = "Creëer een noodgeval",
      vip = "Creëer een VIP",
      win_level = "Win het huidige level",
      create_patient = "Creëer een patiënt op de rand van de kaart.",
      money = "Voegt 10.000 toe aan je saldo",
      lose_level = "Verlies het huidige level", -- Zie ook information.level_lost.cheat
      all_research = "Voltooi al het onderzoek",
      end_year = "Spring naar het einde van het jaar.",
      earthquake = "Creëer een aardbeving",
      epidemic = "Maakt een besmette patient aan die mogelijk een epidemie veroorzaakt",
      toggle_infected = "Aan/uit zetten van weergave van geïnfecteerden van de ontdekte epidemie",
      increase_prices = "Verhoog alle prijzen met 50% (max. 200%)",
      decrease_prices = "Verlaag alle prijzen met 50% (min. 50%)",
      show_infected = "Toon/verberg de geïnfecteerde iconen voor de actieve, ontdekte epidemieën",
      max_reputation = "Zet de reputatie van het ziekenhuis op maximaal",
      toggle_epidemic = "Schakel epidemieën in of uit",
      reset_death_count = "Zet het aantal ziekhuisdoden terug op nul",
      toggle_earthquake = "Schakel aardbevingen in of uit",
    },
  },
  new_game_window = {
    player_name = "Voer de naam in die je wild gebruiken in het spel",
    difficulty = "Moeilijkheid",
    cancel = "Oh, ik wilde eigenlijk helemaal geen nieuw spel starten!",
    tutorial = "Klik hier als je wat hulp nodig hebt in het spel",
    start = "Begin het spel met de geselecteerde instellingen",
    easy = "Als je dit spel nog nooit gespeeld hebt, is deze optie voor jou",
    medium = "De gulden middenweg, als je geen idee hebt wat je wilt",
    hard = "Als je het spel kent en meer uitdaging zoekt, kies deze optie.",
  },
  calls_dispatcher = {
    assigned = "Dit vakje is aangekruist als de taak is toegewezen",
    task = "Lijst van de taken - klik op een taak om het personeelslid te zien die deze taak uit voert en om naar de locatie van de taak te gaan",
    close = "Sluit dit scherm",
  },
  hire_staff_window = {
    prev_person = "Vorige persoon bekijken",
    cancel = "Annuleren",
    psychiatrist = "Psychiater",
    salary = "Salaris",
    next_person = "Volgende persoon bekijken",
    nurses = "Beschikbare zusters bekijken",
    surgeon = "Chirurg",
    handymen = "Beschikbare conciërges bekijken",
    doctors = "Beschikbare artsen bekijken",
    doctor_seniority = "Niveau arts (assistent, basisarts of specialist)",
    hire = "Aannemen",
    researcher = "Onderzoeker",
    qualifications = "Extra kwalificaties",
    receptionists = "Beschikbare receptionistes bekijken",
    staff_ability = "Competentie",
  },
  handyman_window = {
    close = "Annuleren",
    ability = "Competentie",
    face = "Foto",
    prio_machines = "Hogere prioriteit geven aan reparaties",
    prio_litter = "Hogere prioriteit geven aan schoonmaken",
    happiness = "Tevredenheid",
    prio_plants = "Hogere prioriteit geven aan het watergeven van planten",
    name = "Naam van de conciërge",
    tiredness = "Moeheid",
    center_view = "Naar conciërge springen",
    salary = "Salaris",
    sack = "Ontslaan",
    pick_up = "Oppakken",
    parcel_select = "Het gebouw waar de conciërge taken mag verrichten. Klik om te veranderen",
  },
  staff_list = {
    ability_2 = "Competentie",
    next_person = "Volgende persoon in de lijst selecteren",
    detail = "Precisie",
    happiness = "Tevredenheid",
    researcher_train = "%d%% van de opleiding tot onderzoeker voltooid",
    handymen = "Lijst van conciërges bekijken",
    tiredness = "Laat zien hoe moe de werknemers zijn",
    researcher = "Gekwalificeerde onderzoeker",
    happiness_2 = "Moraal",
    pay_rise = "Salaris met 10% verhogen",
    bonus = "Een bonus van 10% geven",
    prev_person = "Vorige persoon in de lijst selecteren",
    nurses = "Lijst van zusters bekijken",
    psychiatrist = "Gekwalificeerde psychiater",
    salary = "Huidig salaris van deze werknemer",
    ability = "Competentie van deze werknemers",
    close = "Terugkeren naar het spel",
    sack = "Deze werknemer ontslaan",
    surgeon = "Gekwalificeerde chirurg",
    tiredness_2 = "Moeheid werknemer",
    doctors = "Lijst van artsen bekijken",
    doctor_seniority = "Niveau van arts",
    view_staff = "Bekijk deze persoon",
    surgeon_train = "%d%% van de opleiding tot chirurg voltooid",
    skills = "Extra bekwaamheden",
    receptionists = "Lijst van receptionistes bekijken",
    psychiatrist_train = "%d%% van de opleiding tot psychiater voltooid",
  },
  research = {
    cure_inc = "Budget voor onderzoek verhogen",
    close = "Onderzoeksscherm sluiten",
    specialisation_dec = "Budget voor specialisatie verlagen",
    diagnosis_dec = "Budget voor diagnostische apparatuur verlagen",
    allocated_amount = "Totaal budget",
    improvements_inc = "Budget voor verbeteringen verhogen",
    drugs_dec = "Budget voor medicijnen verlagen",
    drugs_inc = "Budget voor medicijnen verhogen",
    cure_dec = "Budget voor behandelmethodes verlagen",
    specialisation_inc = "Budget voor specialisatie verhogen",
    improvements_dec = "Budget voor verbeteringen verlagen",
    diagnosis_inc = "Budget voor diagnostische apparatuur verhogen",
  },
  machine_window = {
    repair = "Een Conciërge sturen om deze machine te repareren",
    name = "Naam",
    close = "Sluiten",
    times_used = "Aantal keren gebruikt",
    status = "Status machine",
    replace = "Machine vervangen",
  },
  place_objects_window = {
    confirm = "Bevestigen",
    cancel = "Annuleren",
    pick_up = "Voorwerp oppakken",
    buy_sell = "Voorwerp kopen of verkopen",
  },
  totd_window = {
    previous = "Vorige tip tonen",
    next = "Volgende tip tonen",
  },
  load_game_window = {
    load_game = "Laad spel %s",
    load_autosave = "Laad Autosave",
    load_game_number = "Laad spel %d",
  },
  queue_window = {
    end_of_queue = "Sleep een patiënt hier naartoe om hem of haar achteraan in de rij te plaatsen",
    num_entered = "Aantal patiënten die in deze kamer zijn behandeld",
    close = "Dit scherm sluiten",
    num_in_queue = "Aantal patiënten in de rij",
    num_expected = "Aantal patiënten die door de receptioniste worden verwacht zich aan te sluiten",
    front_of_queue = "Sleep een patiënt hier naartoe om ze vooraan de rij te plaatsen",
    dec_queue_size = "Maximum rijlengte verkleinen",
    max_queue_size = "Maximum rijlengte die de receptioniste zal proberen aan te houden",
    inc_queue_size = "Maximum rijlengte vergroten",
    patient = "Sleep een patiënt naar een specifieke plaats in de rij. Klik op de rechtermuisknop om een patiënt naar huis te sturen of naar een rivaliserend ziekenhuis door te verwijzen",
    patient_dropdown = {
      send_home = "Patiënt uit ziekenhuis ontslaan",
      hospital_2 = "Patiënt naar een ander ziekenhuis verwijzen",
      reception = "Patiënt naar receptioniste verwijzen",
      hospital_1 = "Patiënt naar een ander ziekenhuis verwijzen",
      hospital_3 = "Patiënt naar een ander ziekenhuis verwijzen",
    },
  },
  jukebox = {
    rewind = "Vorig nummer",
    loop = "Nummer herhalen",
    stop = "Stoppen",
    close = "Sluiten",
    current_title = "Jukebox",
    play = "Afspelen",
    fast_forward = "Volgend nummer",
  },
  graphs = {
    deaths = "Doden",
    close = "Scherm sluiten",
    scale = "Schaal",
    money_out = "Uitgaven",
    visitors = "Bezoekers",
    wages = "Salarissen",
    balance = "Saldo",
    money_in = "Inkomsten",
    cures = "Genezingen",
    reputation = "Waarde",
  },
  toolbar = {
    reputation = "Je reputatie",
    casebook = "Behandelingen",
    edit = "Aanpassen",
    staff_list = "Personeel",
    policy = "Beleid",
    date = "Datum",
    charts = "Grafieken",
    objects = "Gangartikelen",
    balance = "Je saldo",
    research = "Onderzoek",
    hire = "Personeel inhuren",
    status = "Status",
    town_map = "Kaart",
    rooms = "Bouwen",
    bank_button = "Klik voor het kasboek. Klik op de rechtermuisknop voor de bankafschriften",
  },
  pay_rise_window = {
    accept = "Aan de eis voldoen",
    decline = "Niet betalen en ontslaan.",
  },
  town_map = {
    close = "Kaart sluiten",
    plants = "Planten weergeven",
    fire_extinguishers = "Brandblussers weergeven",
    people = "Mensen weergeven",
    balance = "Saldo",
    heat_dec = "Verwarming lager zetten",
    heating_bill = "Energierekening",
    radiators = "Radiatoren weergeven",
    objects = "Voorwerpen weergeven",
    heat_level = "Verwarming",
    heat_inc = "Verwarming hoger zetten",
  },
  custom_game_window = {
    choose_game = "Klik op een level om meer informatie in te zien",
    free_build = "Klik hier als je wilt spelen zonder geld, en zonder win en verliesvoorwaarden", --Kan ook overwinningsvoorwaarden worden genoemd, maar is misschien net te weinig info
    load_selected_level = "laad en speel het geselecteerde level",
  },
  casebook = {
    sent_home = "Aantal afgewezen patiënten",
    cure_requirement = {
      possible = "Je kunt deze behandeling uitvoeren",
      not_possible = "Je kunt deze behandeling nog niet uitvoeren",
      ward_hire_nurse = "Je hebt een zuster en een slaapzaal nodig om deze behandeling uit te voeren",
      build_ward = "Je hebt een slaapzaal nodig om deze behandeling uit te voeren",
      research_machine = "De benodigde apparatuur is nog niet uitgevonden",
      hire_staff = "Je hebt een %s nodig om deze behandeling uit te voeren",
      build_room = "Je mist de relevante kamer om deze behandeling uit te voeren",
      hire_surgeon = "Je hebt een tweede chirurg nodig om een operatie uit te voeren",
      hire_surgeons = "Je hebt twee chirurgen nodig om operaties uit te voeren",
      hire_staff_old = "Je moet een %s aannemen om deze behandeling uit te voeren",
    },
    increase = "Verhogen",
    up = "Naar boven",
    reputation = "Reputatie",
    research = "Klik hier om het laboratorium zich op deze specialisatie te laten concentreren",
    close = "Scherm sluiten",
    earned_money = "Tot nu toe verdiend",
    cure_type = {
      psychiatrist = "Een psychiater voert deze behandeling uit",
      drug_percentage = "Deze behandeling gebruikt medicijnen. Die van jou zijn %d%% effectief.",
      drug = "Deze behandeling maakt gebruik van medicijnen",
      machine = "Deze behandeling maakt gebruik van apparatuur",
      surgery = "Deze behandeling maakt gebruik van operaties",
      unknown = "Je weet nog niet hoe je deze ziekte moet behandelen",
    },
    decrease = "Verlagen",
    deaths = "Aantal sterfgevallen",
    cured = "Aantal genezingen",
    down = "Naar beneden",
    treatment_charge = "Prijs",
  },
  policy = {
    diag_termination = "Het diagnoseproces zal doorlopen worden tot artsen zo zeker zijn als STOP PROCEDURE aangeeft, of tot alle diagnostische testen zijn uitgevoerd",
    close = "Sluit beleidsscherm",
    staff_leave = "Artsen en zusters mogen bijspringen waar nodig",
    diag_procedure = "Als de diagnose van een arts minder zeker is dan het WEGSTUREN percentage, zal de patiënt naar huis gestuurd worden. Als de diagnose beter is dan GOKKEN aangeeft, zal de patiënt de betreffende behandeling ondergaan",
    staff_rest = "Hoe moe personeelsleden moeten zijn voordat ze mogen uitrusten",
    staff_stay = "Artsen en zusters blijven in de kamer waar je ze plaatst",
  },
  bank_manager = {
    graph = "Verwachte betalingen van %s",
    close = "Kasboek sluiten",
    hospital_value = "Waarde ziekenhuis",
    graph_return = "Terug naar vorig venster",
    current_loan = "Nog uitstaande leningen",
    borrow_5000 = "$5000 lenen van de bank",
    balance = "Je huidige saldo",
    interest_payment = "Maandelijkse rente",
    inflation_rate = "Inflatie",
    interest_rate = "Rentevoet",
    repay_5000 = "$5000 aflossen",
    show_graph = "Toon grafiek met verwachte betalingen van %s",
    insurance_owed = "Nog tegoed van %s",
  },
  main_menu = {
    exit = "Nee! Nee! Verlaat ons niet!",
    custom_level = "Als uitzendkracht ben je verantwoordelijk voor maar één ziekenhuis",
    network = "Start een netwerkspel",
    quit = "Afsluiten",
    continue = "Doorgaan met vorig spel",
    options = "Verschillende instellingen aanpassen",
    load_menu = {
      load_slot = "SPEL LADEN",
      empty_slot = "LEEG",
    },
    new_game = "Begin met een compleet nieuw spel",
    load_game = "Een opgeslagen spel laden",
    custom_campaign = "Start een campagne die door de community is gemaakt",
    map_edit = "Creëer een aangepaste map"
  },
  patient_window = {
    graph = "Klik om te schakelen tussen de gezondheid en de geschiedenis van deze persoon",
    casebook = "Details bekijken van de ziekte van deze patiënt",
    close = "Venster sluiten",
    queue = "Bekijk de rij waarin deze persoon staat",
    happiness = "Tevredenheid van deze patiënt",
    warmth = "Hoe warm deze persoon het heeft",
    center_view = "Deze persoon bekijken",
    thirst = "Hoe dorstig deze patiënt is",
    send_home = "Uit ziekenhuis ontslaan",
    abort_diagnosis = "Behandel deze patiënt nu, zonder een complete diagnose",
  },
  menu_list_window = {
    back = "Dit venster sluiten",
    save_date = "Klik hier om te sorteren op datum van opslaan",
    name = "Klik hier om te sorteren op naam",
    ok = "Bevestig keuze",
  },
  watch = {
    emergency = "Noodgeval: tijd over om alle patiënten te genezen.",
    hospital_opening = "Bouwtijd: dit is hoelang het nog duurt voor je ziekenhuis opengaat. Klik op de START knop om je ziekenhuis nu te openen.",
    epidemic = "Epidemie: tijd over om de epidemie te verbergen. Als de tijd om is OF een besmettelijke patiënt je ziekenhuis verlaat, komt er een inspecteur langs. De knop zet vaccinatiemodus aan en uit. Klik ermee op een patiënt om hem of haar te laten inenten door een zuster.",
  },
  save_game_window = {
    new_save_game = "Voer hier de naam in",
    save_game = "Spel %s overschrijven",
  },
  information = {
    close = "Informatievenster sluiten",
  },
  rooms = {
    ultrascan = "Een arts gebruikt de echoscopie om diagnoses te stellen",
    research_room = "Artsen die een kwalificatie hebben als onderzoeker kunnen nieuwe medicijnen en machines ontwikkelen in het laboratorium",
    fracture_clinic = "Een zuster gebruikt de gipskamer om botfracturen te verhelpen",
    gps_office = "Patiënten krijgen hun eerste consult en resultaten in de spreekkamer.",
    inflation = "Een arts gebruikt de inflatiekliniek om patiënten met plofkop te genezen",
    staffroom = "Artsen en zusters ontspannen in de personeelsruimte en raken zo hun moeheid kwijt",
    jelly_vat = "Een arts gebruikt de gelatinetank om gelatinis te genezen",
    scanner = "Een arts gebruikt de scanner om een diagnose te stellen",
    decontamination = "Een arts gebruikt de ontsmettingscabine om radioactiviteit te genezen",
    pharmacy = "Een zuster geeft medicijnen uit een apotheek aan patiënten om hen te genezen van verschillende kwalen.",
    cardiogram = "Een arts gebruikt de cardiogram om een diagnose te stellen",
    ward = "Slaapzalen worden door zusters gebruikt om diagnoses te stellen en patiënten te behandelen. Patiënten worden hier naartoe gestuurd ter observatie en rusten hier voordat ze een operatie moeten ondergaan",
    training_room = "Een klaslokaal met een specialist kan worden gebruikt om andere artsen op te leiden",
    operating_theatre = "De operatiekamer heeft twee gekwalificeerde chirurgen nodig",
    psychiatry = "De psychiatrie geneest geesteszieke patiënten en helpt het diagnostisch proces. Het vereist echter wel een gekwalificeerde psychiater",
    hair_restoration = "Een arts gebruikt de haarrestaurateur om kaalheid te genezen",
    tongue_clinic = "Een arts gebruikt de snijmachine om lamme tong te genezen",
    dna_fixer = "Een arts gebruikt DNA hersteller om patiënten met buitenaards DNA te genezen",
    general_diag = "Een arts gebruikt de spreekkamer om een basisdiagnose voor zijn patiënten te stellen. Goedkoop en vaak zeer effectief",
    toilets = "Bouw toiletten, zodat mensen geen zooi maken van je ziekenhuis!",
    electrolysis = "Een arts gebruikt de elektrolysekamer om pilitis te genezen",
    x_ray = "Een arts gebruikt de röntgenkamer om een diagnose te stellen",
    blood_machine = "Een arts gebruikt de bloedmachinekamer om een diagnose te stellen",
  },
  statement = {
    close = "Afschriftenscherm sluiten",
  },
  buy_objects_window = {
    confirm = "Voorwerp(en) kopen",
    cancel = "Annuleren",
    increase = "Koop nog een exemplaar van dit voorwerp",
    total_value = "Totale aankoopwaarde",
    price = "Prijs per stuk",
    decrease = "Koop een exemplaar minder van dit voorwerp",
  },
  staff_window = {
    doctor_seniority = "Niveau - assistent, basisarts of specialist",
    psychiatrist = "Psychiater",
    close = "Annuleren",
    ability = "Competentie",
    pick_up = "Oppakken",
    sack = "Ontslaan",
    surgeon = "Chirurg",
    happiness = "Tevredenheid",
    salary = "Salaris per maand",
    name = "Naam",
    tiredness = "Moeheid",
    center_view = "Persoon bekijken",
    skills = "Speciale bekwaamheden",
    researcher = "Onderzoeker",
    face = "Foto",
  },
  status = {
    percentage_cured = "Je moet %d bezoekers hebben behandeld. Tot nu toe heb je er %d behandeld",
    thirst = "Gemiddelde dorst van de mensen in je ziekenhuis",
    close = "Overzicht sluiten",
    population_chart = "Dit diagram geeft aan welk deel van de zieken naar welk ziekenhuis gaat",
    win_progress_own = "Laat vooruitgang zien tot je ziekenhuis aan de eisen voldoet",
    reputation = "Je reputatie moet minimaal %d bedragen. Momenteel bedraagt deze %d",
    population = "Je moet %d%% van de bevolking aantrekken.",
    warmth = "Algemene warmte van de mensen in je ziekenhuis",
    percentage_killed = "Niet meer dan %d%% van je bezoekers mogen overlijden. Tot nu toe is %d%% overleden",
    balance = "Je saldo moet ten minste %d bedragen. Momenteel bedraagt deze %d",
    value = "Je ziekenhuis moet $%d waard zijn. Momenteel is deze $%d waard",
    win_progress_other = "Laat vooruitgang zien tot het ziekenhuis van %s aan de eisen voldoet",
    num_cured = "Je doel is %d patiënten te genezen. Tot nu toe heb je er %d genezen",
    happiness = "Algemene tevredenheid van de mensen in je ziekenhuis",
  },
  window_general = {
    confirm = "Bevestigen",
    cancel = "Annuleren",
  },
  objects = {
    chair = "Stoel: patiënten zitten hierop als ze over hun ziekte vertellen.",
    litter = "Troep: op de grond gegooid door een patiënt, omdat hij geen prullenbak kon vinden.",
    sofa = "Bankstel: werknemers rusten uit op een bankstel tenzij ze een betere manier vinden om zich te ontspannen.",
    operating_table = "30 OB_OP_TABLE",
    bed2 = "unused",
    bench = "Bank: hier kunnen patiënten comfortabel wachten op hun beurt.",
    scanner = "14 OB_SCANNER",
    couch = "18 OB_COUCH",
    blood_machine = "42 OB_BLOOD_MC",
    table1 = "Table (REMOVED): holds collection of magazines to keep waiting patients happy.", --[[ Schijnbaar hebben ze geen tafels in ziekenhuizen. --]]
    video_game = "Videospelletje: laat je personeel zich ontspannen met Hi-Octane.",
    lamp = "Lamp: geeft licht zodat je personeel kan zien.",
    op_sink2 = "34 OB_OP_SINK_2",
    door = "Deur: mensen openen deze vaak. Ook doen ze deze wel eens dicht.",
    auto_autopsy = "Autopsie: een grote hulp in het ontdekken van nieuwe behandelingen",
    reception_desk = "Receptie: een receptioniste stuurt mensen vanaf hier door naar artsen.",
    hair_restorer = "25 OB_HAIR_RESTORER",
    projector = "Beamer: een specialist gebruikt visuele hulp bij de lesstof",
    crash_trolley = "20 OB_CRASH",
    tv = "TV: nu hoeft je personeel hun favoriete programma niet meer te missen.",
    ultrascanner = "Echo apparaat",
    surgeon_screen = "35 OB_SURGEON_SCREEN",
    litter_bomb = "Afvalbom: saboteer het ziekenhuis van je tegenstander",
    inflator = "Compressor: geneest mensen met plofkop.",
    table2 = "12 OB_BTABLE",
    desk = "Bureau: essentieel voor een arts om zijn computer op te zetten.",
    pool_table = "Biljarttafel: helpt je personeel zich te ontspannen.",
    x_ray_viewer = "29 OB_XRAY_VIEWER",
    radiation_shield = "28 OB_RAD_SHIELD",
    bed = "Bed: erg zieke mensen liggen hierop.",
    swing_door2 = "53 OB_DOUBLE_DOOR2",
    console = "15 OB_SCANNER_CONSOLE",
    op_sink1 = "33 OB_OP_SINK_1",
    bookcase = "Boekenkast: referentiemateriaal voor artsen.",
    drinks_machine = "Frisdrankautomaat: lest de dorst van patiënten en zorgt voor inkomsten.",
    comfortable_chair = "61 OB_COMFY_CHAIR",
    skeleton = "Geraamte: gebruikt voor opleidingen en Halloween.",
    computer = "Computer: belangrijk voor onderzoek",
    bin = "Prullenbak: hier gooien patiënten hun afval in.",
    pharmacy_cabinet = "Apotheek: waar de medicijnen worden bewaard.",
    radiator = "Radiator: zo wordt het niet te koud in je ziekenhuis.",
    cast_remover = "24 OB_CAST_REMOVE",
    atom_analyser = "Pulsmixer: wordt geplaatst in het laboratorium. Versnelt het onderzoeksproces.",
    plant = "Plant: houdt patiënten tevreden en zuivert de lucht.",
    jelly_moulder = "47 OB_JELLY_VAT",
    cardio = "13 OB_CARDIO",
    toilet = "Pot: patiënten, eh, gebruiken dit.",
    electrolyser = "46 OB_ELECTRO",
    fire_extinguisher = "Blusser: verkleint het gevaar van defecte apparatuur.",
    bed3 = "unused",
    swing_door1 = "52 OB_DOUBLE_DOOR1",
    lecture_chair = "Schoolbank: je studerende artsen zitten hier om aantekeningen te maken, zich dood te vervelen en doelloos poppetjes te tekenen. Hoe meer schoolbanken je plaatst, des te groter je klas kan zijn.",
    screen = "16 OB_SCREEN",
    toilet_sink = "Wasbak: de patiënten die zich wat meer bewust zijn van hygiëne kunnen hier hun vieze handen in wassen. Als er niet genoeg wasbakken zijn, raken patiënten nukkig.",
    shower = "54 OB_DECON_SHOWER",
    gates_of_hell = "48 OB_HELL",
    entrance_right = "59 OB_ENT_RDOOR",
    entrance_left = "58 OB_ENT_LDOOR",
    slicer = "26 OB_SLICER",
    dna_fixer = "23 OB_DNA_FIXER",
    x_ray = "27 OB_XRAY",
    cabinet = "Dossierkast: bevat dossiers, aantekeningen en rapportages van patiënten.",
    rathole = "De thuisbasis van een rattenfamilie die uw ziekenhuis vies genoeg vond om hier te komen wonen.",
  },
  build_room_window = {
    cost = "Kosten van deze kamer",
    room_classes = {
      treatment = "Behandelkamers",
      diagnosis = "Diagnostische kamers",
      facilities = "Speciale faciliteiten",
      clinic = "Gespecialiseerde klinieken",
    },
    close = "Venster sluiten en terugkeren naar het spel",
  },
  options_window = {
    fullscreen = "Wil je het spel in volledig scherm of in een venster spelen?", --Hoe kun je ''Windowed mode'' het beste verwoorden? Omni: wat vind je hiervan?--
    resolution = "Verander de resolutie naar wat er rechts is ingevuld",
    apply = "Pas de ingevoerde resolutie toe",
    language_dropdown_item = "Kies %s als taal",
    language = "De taal waarin het spel wordt weergeven",
    select_language = "Selecteer de taal waarin je het spel wilt spelen",
    cancel = "Annuleren",
    select_resolution = "Een andere resolutie selecteren",
    fullscreen_button = "Volledig scherm",
    change_resolution = "Verander de resolutie naar wat er links is ingevuld",
    height = "Voer de gewenste verticale resolutie in",
    width = "Voer de gewenste horizontale resolutie in",
    language = "Kies %s als taal",
    back = "Sluit het instellingenvenster",
    audio_button = "Zet alle spelgeluiden aan of uit.",
    folder_button = "Mapopties.",
    audio_toggle = "Zet aan of uit.",
    customise_button = "Meer instellingen om je spel aan te passen.",
    apply_scrollspeed = "Pas de ingevoerde scrollsnelheid toe.",
    apply_shift_scrollspeed = "Pas de ingevoerde shift-scrollsnelheid toe.",
    apply_zoomspeed = "Pas de ingevoerde zoomsnelheid toe.",
    cancel_scrollspeed = "Ga terug zonder de scrollsnelheid te wijzigen.",
    cancel_shift_scrollspeed = "Ga terug zonder de shift-scrollsnelheid te wijzigen.",
    cancel_zoomspeed = "Ga terug zonder de zoomsnelheid te wijzigen.",
    capture_mouse = "Klik om de cursor te vangen in het spelvenster",
    check_for_updates = "Stel in of het spel bij het opstarten naar updates moet zoeken.",
    hotkey = "Pas sneltoetsen aan.",
    jukebox = "Open de Jukebox om de muziek te bedienen",
    language_dropdown_no_font = "Selecteer een lettertype in de spelinstellingen om deze taal in te schakelen",
    right_mouse_scrolling = "Wissel de muisknop die wordt gebruikt om door de kaart te scrollen",
    scrollspeed = "Stel de scrollsnelheid in tussen 1 (langzaamst) en 10 (snelst). De standaard waarde is 2",
    shift_scrollspeed = "Stel de shift-scrollsnelheid in tussen 1 (langzaamst) en 10 (snelst). De standaard waarde is 4",
    zoom_speed = "Stel de zoomsnelheid van de camera in van 10 (langzaamst) en 1000 (snelst). De standaard waarde is 80",
  },
  research_policy = {
    research_progress = "Voortgang tot de volgende ontdekking in deze categorie: %1%/%2%",
    no_research = "Naar deze categorie wordt momenteel geen onderzoek gedaan",
  },
  customise_window = {
    intro = "Zet de intro video aan of uit. Zet deze instelling aan om de intro video te tonen als CorsixTH wordt gestart.",
    fractured_bones = "Omdat de animatie niet mooi is, zijn vrouwelijke patiëntien met gebroken botten standaard uitgeschakeld. Om vrouwelijke patiënten met gebroken botten in je ziekenhuis te ontvangen zet je deze instelling uit.",
    movies = "Met algemene video instellingen zet je alle video's aan of uit.",
    volume = "Als de 'volume-lager' knop ook het behandelingenboek opent, zet deze instelling aan om de sneltoets naar het behandelingenboek te veranderen naar shift+C",
    aliens = "Vanwege de sleche animatie bezoeken patiënten met alien-DNA je ziekenhuis alleen bij een noodgeval. Om patiënten met alien-DNA ook buiten noodgevallen je ziekenhuis te laten bezoeken zet je deze instelling uit.",
    paused = "In Theme Hospital was het niet mogelijk de menubalk te gebruiken als het spel was gepauzeerd. De standaard instelling in CorsixTH is het zelfde, maar met deze instelling aan is dit tijdens pauze wel toegestaan.",
    average_contents = "Als het spel moet onthouden wat je gemiddeld genomen aan meubilair in een kamer bouwt, zet deze instelling aan.",
    back = "Sluit dit menu af en ga terug naar het instellingen menu.",
    remove_destroyed_rooms = "Schakel deze optie in als u vernielde kamers tegen betaling wilt kunnen verwijderen",
  },
  update_window = {
    download = "Ga naar de download pagina voor de nieuwste versie van CorsixTH",
    ignore = "Negeer deze update. Je wordt opnieuw herinnerd als je CorsixTH de volgende keer start.",
  },
  folders_window = {
    browse_font = "Zoek naar een ander lettertype ( huidige locatie: %1% ) ",
    screenshots_location = "Standaard worden screenshots opgeslagen bij het configuratie bestand. Als dit niet gewenst is, kies dan hier een andere locatie.",
    browse_music = "Zoek naar een andere locatie voor je muziek bestand ( huidige locatie: %1% ) ",
    data_location = "De map waar de originele Theme Hospital installatie in staat. Deze is nodig om CorsixTH te laten werken.",
    browse_data = "Zoek naar een andere locatie van je Theme Hospital installatie ( huidige lacatie: %1% )",
    savegames_location = "Standaard worden opgeslagen spellen in de saves map bij het configuratie bestand opgeslagen. Als dit niet gewenst is, kies dan hier een andere locatie.",
    back = "Sluit dit menu af en ga terug naar het instellingen menu.",
    browse_saves = "Zoek naar een andere locatie voor je saves map ( huidige locatie: %1% ) ",
    browse = "Zoek naar de lacatie van de map",
    browse_screenshots = "Zoek naar een andere locatie voor je screenshots map ( huidige locatie: %1% ) ",
    not_specified = "Nog geen map ingesteld!",
    font_location = "Locatie van een lettertype bestand dat de Unicode karakters van je taal kan weergeven. Als dit niet is ingesteld is het niet mogelijk talen te kiezen die meer karakters nodig hebben dan het originele spel kan tonen. Bijvoorbeeld Russisch of Chinees.",
    reset_to_default = "Herstel de map naar de standaard locatie.",
    default = "Standaard locatie.",
    no_font_specified = "Nog geen lettertype locatie ingesteld!",
    music_location = "Selecteer de locatie van je MP3 bestanden. Deze moet van te voren zijn gemaakt, zoek vervolgens hier naar de locatie.",
  },
  debug_patient_window = {
    item = "Creëer een patiënt met %s",
  },
  hotkey_window = {
    button_accept = "Bewaar sneltoetstoewijzingen",
    button_back_02 = "Ga terug naar het hoofdvenster voor sneltoetsen. Sneltoetsen die in dit venster zijn gewijzigd, kunnen daar worden geaccepteerd",
    button_cancel = "Herstel de wijzigingen en ga terug naar het optiemenu",
    button_defaults = "Herstel alle sneltoetsen naar de standaardinstellingen",
    button_gameSpeedKeys = "Open het venster van de sneltoetsen voor de spelsnelheid",
    button_recallPosKeys = "Open het venster van de sneltoetsen voor de cameraposities",
    caption_panels = "Open het venster om paneeltoetsen toe te wijzen",
  },
  save_map_window = {
    map = "Overschrijf spel %s",
    new_map = "Voer een naam in voor het opslagbestand",
  },
  custom_campaign_window = {
    choose_campaign = "Kies een carrière om er meer over te lezen",
    start_selected_campaign = "Laad het eerste scenario van deze carrière",
  },
}
menu_debug_overlay = {
  byte_w_wall = "  BYTE W WALL  ",
  byte_6 = "  BYTE 6  ",
  byte_0_1 = "  BYTE 0 & 1  ",
  byte_7 = "  BYTE 7  ",
  byte_5 = "  BYTE 5  ",
  byte_floor = "  BYTE FLOOR  ",
  positions = "  POSITIES  ",
  flags = "  FLAGS  ",
  parcel = "  PARCEL  ",
  byte_n_wall = "  BYTE N WALL  ",
  none = "  NONE  ",
  heat = "  TEMPERATUUR  "
}
menu_charts = {
  bank_manager  = "  (%1%) KASBOEK  ",
  statement     = "  (%1%) AFSCHRIFTEN  ",
  staff_listing = "  (%1%) PERSONEELSLIJST  ",
  town_map      = "  (%1%) KAART  ",
  casebook      = "  (%1%) BEHANDELINGEN  ",
  research      = "  (%1%) ONDERZOEK  ",
  status        = "  (%1%) STATUS  ",
  graphs        = "  (%1%) GRAFIEKEN  ",
  policy        = "  (%1%) BELEID  ",
  briefing      = "  OPDRACHT  ",
}
progress_report = {
  quite_unhappy = "De mensen zijn nogal ongelukkig. ",
  header = "Voortgang",
  very_unhappy = "De mensen zijn zeer ongelukkig. ",
  more_drinks_machines = "Plaats meer frisdrankautomaten. ",
  too_cold = "Het is veel te koud. Plaats radiatoren. ",
  too_hot = "Kijk naar je verwarming. Het is veel te heet. ",
  percentage_pop = "% bevolking",
  win_criteria = "Overwinningsvoorwaarden",
  free_build = "VRIJ BOUWEN",
}
dynamic_info = {                                      --[['' - '' is hier verschillende malen vervangen door een '';''.]]--
  patient = {
    emergency = "Noodgeval: %s",
    guessed_diagnosis = "Vermoede diagnose: %s ",
    diagnosis_progress = "Voortgang diagnose",
    actions = {
      sent_to_other_hospital = "Ergens anders naartoe verwezen",
      prices_too_high = "Je bent veel te duur; ik ga naar huis.",
      no_gp_available = "Wacht tot je een spreekkamer bouwt",
      waiting_for_treatment_rooms = "Wacht tot je een behandelkamer bouwt voor me",
      dying = "Sterft!",
      no_diagnoses_available = "Geen diagnoses meer; ik ga naar huis",
      epidemic_sent_home = "Naar huis gestuurd door de inspecteur",
      cured = "Genezen!",
      waiting_for_diagnosis_rooms = "Wacht tot je meer diagnostische kamers bouwt",
      epidemic_contagious = "Ik ben besmettelijk",
      awaiting_decision = "Wacht op je beslissing",
      sent_home = "Naar huis gestuurd",
      fed_up = "Heeft er schoon genoeg van en vertrekt",
      no_treatment_available = "Geen behandeling beschikbaar; ik ga naar huis",
      on_my_way_to = "Onderweg naar %s",
      queueing_for = "In de rij voor %s",
      epidemic_vaccinated = "Ik ben niet langer besmettelijk",
    },
    diagnosed = "Diagnose: %s ",
  },
  health_inspector = "Gezondheidsinspecteur",
  vip = "VIP",
  object = {
    times_used = "%d keer gebruikt",
    queue_size = "Rijlengte %d",
    strength = "Kracht %d",
    queue_expected = "Verwachte rijlengte %d",
    strength_extra_info = "Vermogen %d (Te verbeteren naar %d)",
  },
  staff = {
    ability = "Competentie",
    psychiatrist_abbrev = "Psych.",
    actions = {
      waiting_for_patient = "Wacht op patiënt",
      wandering = "Loopt wat rond",
      going_to_repair = "Gaat %s repareren",
      heading_for = "Gaat naar %s",
      fired = "Ontslagen",
      vaccine = "Een patiënt vaccineren",
    },
    tiredness = "Moeheid",
  },
}
adviser = {
  tutorial = {
    hire_receptionist = "Je hebt ook een receptioniste nodig om je patiënten de weg te wijzen.",
    build_pharmacy = "Gefeliciteerd! Bouw nu een apotheek en neem een zuster aan, zodat je een werkend ziekenhuis hebt.",
    hire_doctor = "Je hebt een arts nodig om diagnoses te stellen en de zieken te behandelen.",
    place_receptionist = "Plaats de receptioniste ergens in je ziekenhuis.",
    place_windows = "Je kunt ramen op dezelfde manier als deuren plaatsen. Je hebt ze niet echt nodig, maar het houdt je personeel wel tevreden.",
    confirm_room = "Klik op het knipperende icoontje om je kamer open te stellen of klik op de X om een stap terug te gaan.",
    rotate_and_place_reception = "Klik op de rechtermuisknop om het Bureau te draaien en klik op de linkermuisknop om het te plaatsen.",
    build_reception = "Hallo. Ten eerste moet je ziekenhuis een receptie hebben. Klik hiervoor op de gangartikelenknop.",
    doctor_in_invalid_position = "Hee! Daar kun je de arts niet plaatsen.",
    receptionist_invalid_position = "Daar kun je de receptioniste niet neerzetten.",
    room_too_small_and_invalid = "De blauwdruk is te klein en staat niet op bebouwbare grond. Kom op.",
    window_in_invalid_position = "Dit raam bevindt zich op een onmogelijke positie. Probeer het eens ergens anders te plaatsen.",
    choose_doctor = "Kijk goed naar wat een arts kan voor je er een aanneemt.",
    build_gps_office = "Om diagnoses te kunnen stellen moet je eerst een spreekkamer bouwen.",
    select_doctors = "Klik op het knipperende icoontje om te zien welke artsen je kunt inhuren.",
    place_objects = "Klik op de rechtermuisknop om voorwerpen te draaien en op de linkermuisknop om ze te plaatsen.",
    select_receptionists = "Klik op het knipperende icoontje om de beschikbare receptionistes te bekijken. Het nummer onder het icoontje geeft aan uit hoeveel sollicitantes kunt kiezen.",
    order_one_reception = "Klik eenmaal op de knipperende regel om een receptie te bestellen.",
    choose_receptionist = "Kies een receptioniste met voldoende competentie en een redelijke salariseis. Klik ten slotte op het knipperende icoontje om haar aan te nemen.",
    place_doctor = "Plaats de arts ergens in het ziekenhuis. Zodra er een diagnose gesteld moet worden, zal hij zich naar de spreekkamer begeven.",
    accept_purchase = "Klik op het knipperende icoontje om de bestelling af te ronden.",
    place_door = "Beweeg de muis langs de muren van de blauwdruk om te bepalen waar je de deur wil hebben.",
    next_receptionist = "Dit is de eerste receptioniste in de lijst. Klik op het knipperende icoontje om de volgende sollicitante te bekijken.",
    room_in_invalid_position = "Hé! De kamer kan niet gebouwd worden; de rode vakjes geven aan waar je een andere kamer of een muur overlapt",
    room_big_enough = "De blauwdruk is nu groot genoeg. Laat de muisknop los en pas eventueel nog de grootte of de locatie aan.",
    room_too_small = "De blauwdruk is rood omdat hij te klein is. Sleep net zolang door tot de blauwdruk groot genoeg is.",
    click_gps_office = "Klik op de knipperende regel om de spreekkamer te kiezen.",
    reception_invalid_position = "De receptie is grijs omdat er iets in de weg staat. Probeer het bureau te draaien of ergens anders neer te zetten.",
    click_and_drag_to_build = "Om een Praktijk te bouwen moet je eerst beslissen hoe groot hij moet worden. Klik en sleep de blauwdruk uit tot de gewenste grootte.",
    door_in_invalid_position = "Oeps! Je kunt de deur daar niet plaatsen. Probeer het op een ander stuk muur.",
    object_in_invalid_position = "Dit voorwerp kan hier niet geplaatst worden. Plaats het ergens anders of draai het tot het past.",
    select_diagnosis_rooms = "Klik op het knipperende icoontje om de lijst met diagnosekamers te bekijken.",
    prev_receptionist = "Klik op het knipperende icoontje om de vorige sollicitante te bekijken.",
    start_tutorial = "Lees je opdracht en druk op de linkermuisknop om te beginnen.",
    information_window = "De hulpbox verteld je alles over die prachtige spreekkamer die je net gebouwd hebt.",
  },
  epidemic = {
    hurry_up = "Als je die epidemie nu niet snel oplost zit je straks flink in de knoei. Schiet op!",
    serious_warning = "Deze besmettelijke ziekte ziet er ernstig uit. Je moet snel actie ondernemen!",
    multiple_epidemies = "Zo te zien heersen er meerdere epidemieën tegelijk. Dit kan op een enorme ramp uitlopen, dus doe er snel wat aan.",
  },
  staff_advice = {
    need_handyman_machines = "Je zult conciërges moeten inhuren om je apparatuur te onderhouden.",
    need_doctors = "Je hebt meer artsen nodig. Zet de beste artsen in de kamers met de langste wachtrijen.",
    need_handyman_plants = "Je zult een conciërge moeten aannemen om de planten water te geven.",
    need_handyman_litter = "Mensen maken een zootje van je ziekenhuis. Huur een conciërge in om het op te ruimen.",
    need_nurses = "Je moet zusters aannemen. Slaapzalen en apotheken hebben zusters nodig.",
    too_many_doctors = "Je hebt teveel artsen. Sommigen hebben nu niets te doen.",
    too_many_nurses = "Ik denk dat je teveel zusters hebt aangenomen.",
  },
  earthquake = {
    damage = "Die aardbeving heeft %d beschadigd en %d bezoekers getroffen.",
    alert = "Een aardbeving. Tijdens een aardbeving raakt je apparatuur beschadigd. Ze kunnen zelfs vernietigd worden als ze niet goed zijn onderhouden.",
    ended = "Poeh poeh. Dat zal de moeder geweest zijn: %d op de Schaal van Richter.",
  },
  multiplayer = {
    everyone_failed = "Niemand heeft dat laatste doel gehaald. Dus iedereen mag vrolijk doorspelen!",
    players_failed = "De volgende speler(s) hebben het laatste doel niet gehaald: ",
    poaching = {
      in_progress = "Ik laat je nog wel weten of deze medewerker voor je wil werken.",
      not_interested = "Ha! Ze zijn totaal niet geïnteresseerd om voor jou te werken. Ze zijn tevreden met hun huidige baan.",
      already_poached_by_someone = "Dat gaat niet door! Iemand anders probeert deze medewerker al te stropen.",
    },
    objective_completed = "Je hebt het doel behaald! Gefeliciteerd!",
    objective_failed = "Je hebt je doel helaas niet behaald",
  },
  surgery_requirements = {
    need_surgeons_ward_op = "Om operaties uit te kunnen voeren moet je twee chirurgen aannemen, een slaapzaal en een operatiekamer bouwen.",
    need_surgeon_ward = "Om operaties uit te kunnen voeren moet je nog een chirurg inhuren, een slaapzaal en een operatiekamer bouwen.",
  },
  vomit_wave = {
    started = "Zo te zien waart er een kotsvirus rond in je ziekenhuis. Dit had je kunnen voorkomen door je ziekenhuis schoner te houden. Misschien moet je meer conciërges aannemen.",
    ended = "Poeh poeh. Het ziet ernaar uit dat die kotsgolf voorbij is. Hou je ziekenhuis in het vervolg wat beter schoon.",
  },
  level_progress = {
    nearly_won = "Je hebt dit level bijna gewonnen.",
    three_quarters_lost = "Je bent driekwart onderweg naar verlies van dit level.",
    halfway_won = "Je bent halverwege naar de winst van dit level.",
    halfway_lost = "Je bent halverwege naar verlies van dit level.",
    nearly_lost = "Je hebt dit level bijna verloren.",
    three_quarters_won = "Je bent driekwart op weg naar de winst van dit level.",
    dont_kill_more_patients = "Je kunt echt niet meer patiënten afmaken!",
    another_patient_killed = "Oh nee! Je hebt nog een patiënt vermoord. Dat zijn er nu al %d.",
    close_to_win_increase_value = "Je hebt bijna gewonnen, verhoog de waarde van je ziekenhuis met %d.",
    financial_criteria_met = "Je hebt aan alle financiële eisen van dit level voldaan. Hou je banksaldo boven de %d, en zorg ervoor dat je ziekenhuis soepel draait.",
    hospital_value_enough = "Hou de waarde van je ziekenhuis boven de %d en los alle andere problemen in de gaten om dit level te winnen",
    another_patient_cured = "Goed gedaan; nog een patiënt is genezen, dat zijn er nu al %d.",
    reputation_good_enough = "Oké, je reputatie is goed genoeg om dit level te winnen, hou het boven %d en los andere problemen op om te winnen",
    cured_enough_patients = "Je hebt genoeg van je patiënten genezen om dit level te winnen, nu moet je je ziekenhuis nog efficiënter maken om te winnen.",
    improve_reputation = "Je moet je reputatie met %d punten verbeteren om dit level te kunnen winnen.",
  },
  staff_place_advice = {
    receptionists_only_at_desk = "Receptionistes kunnen alleen op de receptie werken.",
    only_psychiatrists = "Artsen kunnen alleen in de psychiatrie werken als ze gediplomeerd psychiater zijn.",
    only_surgeons = "Artsen kunnen alleen in de operatiekamer werken als ze chirurg zijn.",
    only_nurses_in_room = "Alleen zusters kunnen werken in de %s",
    only_doctors_in_room = "Alleen artsen kunnen werken in de %s",
    only_researchers = "Artsen kunnen alleen in het laboratorium werken als ze onderzoekers zijn.",
    nurses_cannot_work_in_room = "Zusters kunnen niet werken in de %s",
    doctors_cannot_work_in_room = "Artsen kunnen niet werken in de %s",
  },
  room_forbidden_non_reachable_parts = "Als je de kamer hier bouwt zijn andere delen van het ziekenhuis onbereikbaar.",
  research = {
    machine_improved = "De %s is verbeterd door het laboratorium.",
    autopsy_discovered_rep_loss = "Je Auto-Autopsie machine is ontdekt. Verwacht negatieve reacties van het publiek.",
    drug_fully_researched = "Je onderzoek op het gebied van %s is voltooid.",
    new_machine_researched = "Het laboratorium heeft een %s uitgevonden.",
    drug_improved = "Het medicijn voor %s is verbeterd door het laboratorium.",
    drug_improved_1 = "%s medicijn is vebeterd door het laboratorium.", --is dit netjes in het spel? of kunnen we beter bovenstaande string kopiëren?
    new_available = "Er is nu een %s beschikbaar.",
    new_drug_researched = "Het laboratorium heeft een middel tegen %s uitgevonden.",
  },
  boiler_issue = {
    minimum_heat = "Aha, daar ben je. De boiler in de kelder is kapot. De mensen in je ziekenhuis zullen het straks nogal fris krijgen.",
    maximum_heat = "De boiler in de kelder is op hol geslagen. De verwarming zit vast op maximum. Mensen zullen het snikheet krijgen. Plaats wat frisdrankautomaten ter compensatie.",
    resolved = "Goed nieuws. De boiler en verwarming doen het weer normaal. De temperatuur zou nu weer goed moeten zijn voor je personeel en patiënten.",
  },
  competitors = {
    staff_poached = "Eén van je personeelsleden is gestroopt door een tegenstander.",
    hospital_opened = "Er is door %s een concurrerend ziekenhuis geopend.",
    land_purchased = "%s heeft zojuist land gekocht.",
  },
  room_requirements = {
    research_room_need_researcher = "Je moet nog een arts met een onderzoeksgraad aannemen voor het laboratorium.",
    op_need_another_surgeon = "Je hebt nog één chirurg nodig om de operatiekamer te kunnen gebruiken.",
    op_need_ward = "Je moet nog een slaapzaal bouwen voor de patiënten die uit moeten rusten voor de operatie.",
    reception_need_receptionist = "Je moet een receptioniste aannemen om je patiënten wegwijs te maken.",
    psychiatry_need_psychiatrist = "Nu je een psychiatrie gebouwd hebt, zal je een psychiater moeten aannemen.",
    pharmacy_need_nurse = "Je zult een zuster moeten aannemen voor de apotheek.",
    ward_need_nurse = "Je moet nog een zuster aannemen om in deze slaapzaal te werken.",
    op_need_two_surgeons = "Neem twee chirurgen aan om operaties uit te kunnen voeren in de operatiekamer.",
    training_room_need_consultant = "Je hebt een specialist nodig om les te kunnen geven in dat klaslokaal.",
    gps_office_need_doctor = "Je moet een arts aannemen voor de spreekkamer.",
  },
  goals = {
    win = {
      money = "Je hebt nog %d nodig om het financiële doel te halen voor dit level.",
      cure = "Genees nog %d patiënten en je hebt genoeg mensen genezen om dit level te winnen.",
      reputation = "Bouw je reputatie op naar %d punten om je doel te behalen.",
      value = "Bouw je ziekenhuis uit tot het %d waard is om dit doel te behalen.",
    },
    lose = {
      kill = "Als er nog %d patiënten overlijden heb je dit level verloren!",
    },
  },
  warnings = {
    charges_too_low = "Je behandelingen zijn te goedkoop. Dit brengt wel mensen binnen, maar je verdient erg weinig aan ze.",
    charges_too_high = "Je vraagt veel geld. Op de korte termijn brengt dat geld in het laatje, maar uiteindelijk jaag je er mensen mee weg.",
    plants_thirsty = "Je moet een oogje houden op je planten. Ze zien er dorstig uit.",
    staff_overworked = "Je personeel is overwerkt. Ze worden inefficiënt en gaan fouten maken, met alle rampzalige gevolgen van dien.",
    queue_too_long_at_reception = "Er staan teveel mensen te wachten om een kamer toegewezen te krijgen door de receptioniste. Plaats nog een receptie en neem een receptioniste aan.",
    queue_too_long_send_doctor = "De rij voor de %s is te lang. Is er daar wel een arts aan het werk?",
    handymen_tired = "Je conciërges zijn erg moe. Laat ze uitrusten.",
    money_low = "Je hebt bijna geen geld meer!",
    money_very_low_take_loan = "Je hebt amper geld over. Je kunt een lening afsluiten, weet je.",
    staff_unhappy = "Je personeel is ongelukkig. Geef ze een bonus, of beter nog: geef ze een personeelsruimte! Je kunt ook je beleid aanpassen in het beleidsscherm.",
    no_patients_last_month = "Ik ben geschokt! Er is in de afgelopen maand geen enkele nieuwe patiënt binnengekomen.",
    queues_too_long = "Je wachtrijen zijn te lang.",
    patient_stuck = "Er is iemand verdwaald. Plan de opzet van je ziekenhuis beter.",
    patients_too_hot = "De patiënten krijgen het te heet. Verwijder wat radiatoren, zet de verwarming wat lager of plaats meer frisdrankautomaten.",
    doctors_tired = "Je artsen zijn hartstikke moe. Laat ze onmiddellijk uitrusten.",
    need_toilets = "Patiënten hebben toiletten nodig. Bouw ze op een plek waar mensen snel bij kunnen komen.",
    machines_falling_apart = "Je apparatuur valt haast uit elkaar. Stuur er snel conciërges op af!",
    nobody_cured_last_month = "Er is in de afgelopen maand helemaal niemand genezen.",
    patients_thirsty = "Mensen krijgen dorst. Misschien zou je wat frisdrankautomaten kunnen plaatsen?",
    nurses_tired = "Je zusters zijn moe. Laat ze uitrusten.",
    machine_severely_damaged = "%s is bijna onherstelbaar beschadigd.",
    reception_bottleneck = "Er is een opstopping bij de receptie. Neem nog een receptioniste aan.",
    bankruptcy_imminent = "Hé! Straks ben je nog failliet. Pas op!",
    receptionists_tired = "Je receptionistes zijn erg moe. Laat ze eens uitrusten.",
    too_many_plants = "Je hebt veel te veel planten. Het lijkt wel een regenwoud.",
    many_killed = "Je hebt nu %d doden op je geweten. Je weet toch wel dat het de bedoeling is dat je ze geneest, hè?",
    need_staffroom = "Bouw een personeelsruimte, zodat je werknemers kunnen uitrusten.",
    staff_too_hot = "Je personeel raakt oververhit. Zet de verwarming wat lager of verwijder radiatoren uit hun kamers.",
    patients_unhappy = "Patiënten hebben geen hoge pet op van je ziekenhuis. Je zou iets aan hun omgeving kunnen doen.",
    people_did_it_on_the_floor = "Sommige patiënten konden het niet meer ophouden. Iemand zal het toch op moeten ruimen.",
    patients_very_thirsty = "Patiënten hebben echt dorst; als je niet snel frisdrankautomaten neerzet zullen veel patiënten je ziekenhuis verlaten en naar huis gaan om cola te drinken.",
    machinery_very_damaged = "Spoed! Zorg dat een conciërge je machines gaat repareren! Ze exploderen bijna!",
    handymen_tired2 = "Je conciërges zijn totaal uitgeput, zorg dat ze meteen uit kunnen rusten.",
    desperate_need_for_watering = "Je moet echt een conciërge inhuren om de planten water te geven.",
    too_much_litter = "Er is een afvalprobleem, meer conciërges zouden hier tegen kunnen helpen.",
    place_plants4 = "Vrolijk de patiënten op met wat planten in je ziekenhuis.",
    change_priorities_to_plants = "Je moet de prioriteiten van je conciërges aanpassen zodat ze meer tijd besteden aan de planten.",
    finanical_trouble2 = "Zorg dat je wat inkomsten krijgt of je wordt ontslagen. Je zult het level verliezen als je nog %d verder in de min komt.",
    litter_everywhere = "Er ligt overal troep. Zet er wat conciërges op.",
    nurses_tired2 = "Je zusters zijn erg moe, zorg dat ze wat rust krijgen.",
    plants_dying = "Je planten gaan dood: ze zijn wanhopig op zoek naar water. Zorg dat je er meer conciërges op zet want patiënten houden helemaal niet van dode planten.",
    reduce_staff_rest_threshold = "Verkort de tijd dat je personeel moet doorwerken tussen pauzes op het beleidsscherm, zodat ze wat vaker kunnen rusten. Het is maar een idee.",
    more_toilets = "Je hebt meer toiletten nodig. Mensen in de rij beginnen kabouters te kleien!",
    hospital_is_rubbish = "Mensen zeggen openlijk dat je ziekenhuis slecht is. Als je niet oppast, zullen ze hun ziektes ergens anders mee naartoe nemen.",
    pay_back_loan = "Je hebt meer dan genoeg geld. Misschien kun je nu die lening afbetalen?",
    financial_trouble3 = "Je banksaldo is zorgelijk. Misschien moet je je inkomsten wat verhogen, je zit %d af van een faillissement.",
    build_toilet_now = "Bouw nu een toilet, mensen houden het niet meer! Niet lachen, dit is serieus.",
    more_benches = "Misschien moet je meer bankjes plaatsen, zieke mensen blijven namelijk niet graag staan",
    many_epidemics = "Het lijkt erop dat er meer dan één epidemie tegelijk plaatsvind. Dit zou een enorme ramp kunnen worden dus doe er snel iets aan.",
    place_plants_to_keep_people = "Mensen gaan weg. Als je wat planten plaatst, zou dat kunnen helpen.",
    patients_thirsty2 = "Mensen klagen over dorst. Je zou wat frisdrankautomaten neer moeten zetten of bestaande automaten dichter bij de mensen moeten zetten.",
    people_freezing = "Onvoorstelbaar. In deze tijd van centrale verwarming vriezen sommige patiënten dood. Bouw radiatoren om het weer warmer te krijgen in je ziekenhuis en zet de thermostaat hoger.",
    patients_very_cold = "Patiënten hebben het erg koud. Probeer de thermostaat hoger te zetten of plaats meer radiatoren.",
    build_toilets = "Bouw nu meteen een toilet of je zult iets onplezierigs zien, om over de stank nog maar te zwijgen.",
    place_plants2 = "Mensen lopen weg. Wat meer planten zou ze misschien op andere gedachten kunnen brengen.",
    staff_tired = "Je personeel is helemaal kapot. Als je ze niet laat uitrusten in een personeelsruimte kunnen ze gek worden van de stress.",
    place_plants3 = "Patiënten worden ongelukkig, zet wat meer planten neer om ze op te vrolijken.",
    staff_unhappy2 = "Je personeel is over het algemeen ongelukkig, dat betekend dat ze binnenkort om een hoger salaris zullen vragen.",
    cash_low_consider_loan = "Je hoeveelheid cash is erg laag, heb je al eens aan een lening gedacht?",
    financial_trouble = "Je zit zwaar in de financiële problemen, los dit zo snel mogelijk op! Als je nog %d verliest is al je moeite voor niks geweest!",
    doctors_tired2 = "Je doktoren zijn ongelofelijk moe, laat ze nu meteen rusten.",
    patient_leaving = "Er gaat een patiënt weg. De reden? Je slecht draaiende ziekenhuis.",
    machinery_damaged2 = "Je moet een conciërge aannemen om je machines te laten repareren.",
    patients_leaving = "Patiënten gaan weg. Verbeter het ziekenhuis voor je bezoekers door bijvoorbeeld planten, bankjes en frisdrankautomaten te plaatsen.",
    epidemic_getting_serious = "Die besmettelijke ziekte is serieus. Je moet er snel iets aan doen!",
    machinery_damaged = "Repareer je machines snel. Het zal niet lang meer duren voordat ze uit elkaar gaan vallen.",
    people_have_to_stand = "Zieke en zwakke mensen moeten blijven staan? Zorg dat ze ergens kunnen zitten!",
    build_staffroom = "Bouw meteen een personeelsruimte. Je personeel werkt te hard, ze storten bijna in! Kom op!",
    machinery_slightly_damaged = "Je machines zijn enigszins beschadigd geraakt. Vergeet niet om ze zo af en toe te onderhouden.",
    patients_getting_hot = "Patiënten hebben het te warm. Probeer de thermostaat wat lager te zetten of verwijder wat radiatoren.",
    machinery_deteriorating = "Je machines zijn zojuist behoorlijk achteruit gegaan, doordat ze te veel gebruikt worden. Hou een oogje in het zeil.",
    litter_catastrophy = "Het afvalprobleem heeft epische proporties aangenomen. Trek een blik conciërges open en zet ze aan het werk!",
    staff_very_cold = "Personeel klaagt over de kou. Zet de thermostaat hoger of plaats meer radiatoren.",
    deal_with_epidemic_now = "Als je die epidemie niet snel oplost zal je de gevolgen moeten ondervinden. Aan het werk!",
    patients_really_thirsty = "Patiënten hebben erg veel dorst. Plaats meer frisdrankautomaten of verplaats bestaande automaten naar de langste rijen.",
    some_litter = "Conciërges kunnen die rommel opruimen voordat het echt een probleem wordt.",
    patients_annoyed = "Mensen hebben genoeg van de manier waarop je dit ziekenhuis bestuurd en ik kan ze geen ongelijk geven. Verbeter of verdwijn!",
    receptionists_tired2 = "Je receptionistes zijn erg vermoeid, laat ze zo snel mogelijk rusten.",
    doctor_crazy_overwork = "Oh nee! Een van je artsen is overspannen door overwerk. Misschien komt hij er nog bovenop als je hem meteen laat rusten.",
    falling_1 = "Hé! Daar kan ik niet om lachen, kijk uit waar je met die muis klikt; straks raken er mensen gewond!",
    falling_2 = "Stop daarmee, zou jij dat leuk vinden?",
    falling_3 = "Au, dat doet vast zeer, is er een dokter in de buurt?!",
    falling_4 = "Dit is een ziekenhuis, geen pretpark!",
    falling_5 = "Dit is niet de plek om mensen omver te duwen, je ziet toch dat ze ziek zijn?!",
    falling_6 = "Het is hier geen bowlingbaan! Zieken horen niet zo behandeld te worden!",
    no_desk = "Je zult op enig moment wel een receptiebalie moeten bouwen en een receptioniste moeten aannemen!",
    no_desk_1 = "Als je wilt dat patiënten je ziekenhuis bezoeken, moet je een receptioniste inhuren en een receptiebalie bouwen, zodat ze haar werk kan doen!",
    no_desk_2 = "Lekker gedaan, dit moet een nieuw record zijn: bijna een jaar zonder patiënten! Als je hier manager wilt blijven, neem dan nu een receptioniste aan en bouw een receptiebalie waar ze kan werken!",
    no_desk_3 = "Fantastisch, bijna een jaar voorbij en je hebt nog steeds geen bemande receptie. Hoe denk je dat je patiënten gaat krijgen? Los het onmiddellijk op, en stop met dat gerommel!",
    no_desk_4 = "Een receptioniste moet haar eigen werkplek hebben om de patiënten te begroeten bij binnenkomst.",
    no_desk_5 = "Nou, het werd tijd! Je zult binnekort een paar patiënten zien arriveren!",
    no_desk_6 = "Je hebt een receptioniste aangenomen, dus zou je niet een receptiebalie bouwen waar ze haar werk kan doen?",
    no_desk_7 = "Je hebt een receptiebalie gebouwd, dus zou je niet een receptioniste aannemen? Je zult geen patiënten zien binnenkomen tot je dit opgelost hebt!",
    cannot_afford = "Je hebt niet genoeg geld op je rekening staan om dit personeelslid aan te nemen.",
    cannot_afford_2 = "Je hebt niet genoeg geld op de bank staan om dit te kopen!",
    research_screen_open_1 = "Je moet eerst een laboratorium bouwen, voordat je het onderzoeksscherm kunt bekijken.",
    research_screen_open_2 = "Onderzoek is in dit level nog niet toegankelijk.",
    researcher_needs_desk_1 = "Een onderzoeker heeft een bureau nodig om aan te werken.",
    researcher_needs_desk_2 = "Je onderzoeker is blij dat je hem op pauze laat gaan. Als het je bedoeling was om meer onderzoekers tegelijk te laten werken, dan moet je voor elk van hen een bureau neerzetten zodat ze hun werk kunnen doen.",
    researcher_needs_desk_3 = "Elke onderzoeker heeft zijn eigen bureau nodig om aan te werken.",
    nurse_needs_desk_2 = "Je zuster is blij dat je haar een pauze gunt. Als het je bedoeling was om meer zusters tegelijk in de slaapzaal te laten werken, dan moet je voor elk van hen een bureau neerzetten.",
    nurse_needs_desk_1 = "Elke zuster heeft haar eigen bureau nodig om aan te werken.",
    patient_not_paying = "Een patiënt is vertrokken zonder te betalen voor %s omdat het te duur is!",
    cannot_afford_machine = "Je hebt minstens $%1% op de bank nodig om een nieuwe %2% te kunnen betalen!",
    another_desk = "Je moet een andere balie bouwen voor de nieuwe receptioniste.",
    fair_prices = "Je kosten voor %s lijken eerlijk en evenwichtig",
    low_prices = "Je rekent te weinig voor %s. Dit zal mensen naar je ziekenhuis brengen, maar je zult er niet veel winst uit halen.",
    high_prices = "Je kosten voor %s zijn hoog. Dit zal op korte termijn veel winst opleveren, maar uiteindelijk zul je mensen wegjagen.",
  },
  placement_info = {
    door_can_place = "Je kunt hier een deur plaatsen als je wilt.",
    window_can_place = "Jahoor, je kunt hier een raam plaatsen.",
    door_cannot_place = "Sorry, maar je kunt hier geen deur plaatsen.",
    object_can_place = "Je kunt dit voorwerp hier plaatsen.",
    reception_can_place = "Je kunt de receptie hier plaatsen.",
    staff_cannot_place = "Je kunt hier geen werknemer neerzetten. Sorry.",
    staff_can_place = "Je kunt hier een werknemer neerzetten. ",
    object_cannot_place = "Hé, je kunt dat voorwerp daar niet plaatsen.",
    room_cannot_place = "Je kunt hier de kamer niet bouwen.",
    room_cannot_place_2 = "De kamer kan hier niet gebouwd worden.",
    window_cannot_place = "Eh, dat raam kun je daar niet plaatsen",
    reception_cannot_place = "Je kunt daar geen receptie plaatsen.",
  },
  praise = {
    many_benches = "Patiënten hebben nu genoeg zitplaats. Netjes.",
    many_plants = "Heerlijk. Je hebt planten zat. Dat zullen je patiënten fijn vinden.",
    patients_cured = "%d patiënten genezen.",
    plants_are_well = "Oh mooi. Je zorgt goed voor je planten, prachtig.",
    few_have_to_stand = "Bijna niemand hoeft te blijven staan in jouw ziekenhuis. De patiënten zullen daar blij mee zijn",
    plenty_of_benches = "Er is voldoende zitplaats, dus dat is geen probleem",
    plants_thriving = "Erg goed. Je planten bloeien prachtig en zien er fantastisch uit. Als dat zo doorgaat kun je een prijs verwachten.",
  },
  information = {
    larger_rooms = "Grotere kamers strelen het ego van het personeel, waardoor ze beter gaan werken.",
    extra_items = "Extra voorwerpen in de kamer zorgen voor comfort, waardoor je personeel beter gaan werken.",
    epidemic = "Je hebt een besmettelijke ziekte in je ziekenhuis. Daar moet je meteen achteraan!",
    promotion_to_doctor = "Eén van je ASSISTENTEN is zojuist BASISARTS geworden",
    emergency = "We hebben een noodgeval! Hup hup hup!",
    patient_abducted = "Eén van je patiënten wordt ontvoerd door aliens!",
    first_cure = "Goed werk! Je hebt zojuist je eerste patiënt genezen.",
    promotion_to_consultant = "Eén van je BASISARTSEN is zojuist SPECIALIST geworden.",
    handyman_adjust = "Je kunt de conciërges effectiever laten werken door hun prioriteiten aan te passen.",
    promotion_to_specialist = "Een van je artsen is gepromoveerd tot %s.",
    initial_general_advice = {
      rats_have_arrived = "Ratten hebben zich in je ziekenhuis genesteld. Schiet ze dood met je muis!",
      autopsy_available = "De Auto-Autopsie machine is uitgevonden. Als je een lastige patiënt hebt, kun je ze hiermee 'kwijtraken' en onderzoek doen op hun lichaam. Wees gewaarschuwd: deze machine is erg berucht.", --[[''Berucht'' is toch een goede vertaling voor ''controversieel?'' Controversieel kent namelijk niet iedereen.]]--
      first_patients_thirsty = "Er zijn dorstige mensen in je ziekenhuis. Plaats een frisdrankautomaat.",
      research_now_available = "Je hebt je eerste laboratorium gebouwd. Nu kun je naar het onderzoeksscherm gaan.",
      psychiatric_symbol = "Artsen die psychiatrie hebben gestudeerd dragen het symbool: |",
      decrease_heating = "Mensen hebben het te heet in je ziekenhuis. Draai de verwarming wat lager. Dit kun je doen bij de kaart.",
      surgeon_symbol = "Artsen die kunnen opereren dragen het symbool: {",
      first_emergency = "Patiënten van een Noodgeval hebben een blauwe sirene boven hun hoofd. Genees ze voor ze sterven of de tijd is voorbij.",
      first_epidemic = "Er is een epidemie gaande! Beslis of je het in de doofpot wil stoppen of wil opbiechten.",
      taking_your_staff = "Iemand probeert je personeel weg te stropen. Je zult moeten vechten om ze bij je te houden.",
      place_radiators = "Mensen in je ziekenhuis hebben het koud. Je kunt meer radiatoren in het gangartikelen menu kopen.",
      epidemic_spreading = "Er waart een besmettelijke ziekte rond. Probeer de geïnfecteerde patiënten te genezen voor ze kunnen vertrekken.",
      research_symbol = "Dokters die onderzoek kunnen doen dragen dit symbool: }",
      machine_needs_repair = "Er is een apparaat dat gerepareerd moet worden. Zoek naar een rokend apparaat en klik erop. Klik dan op de conciërgeknop.",
      increase_heating = "Mensen hebben het koud. Zet de verwarming hoger in het kaartscherm.",
      first_VIP = "Straks komt er voor het eerst een VIP langs. Zorg ervoor dat de VIP geen onhygiënische dingen of ongelukkige patiënten ziet.",
    },
    patient_leaving_too_expensive = "Een patiënt is vertrokken zonder te betalen voor je %s. Schijnbaar is het te duur.",
    vip_arrived = "Let op; %s is zojuist gearriveerd! Zorg dat alles gladjes verloopt, zodat hij tevreden is.",
    epidemic_health_inspector = "Nieuws van je epidemie is aangekomen bij het Ministerie van Volksgezondheid. Verwacht een bezoekje van de inspectie.",
    first_death = "Je hebt zojuist je eerste patiënt gedood. Hoe voelt dat?",
    pay_rise = "Een personeelslid dreigt op te stappen. Kies of je de eis inwilligt of hem ontslaat. Klik op het bericht linksonder om te zien welk personeelslid dreigt ontslag te nemen.",
    place_windows = "Ramen plaatsen zorgt voor lichtere kamers en komt het moraal van je werknemers ten goede.",
    fax_received = "Het icoontje dat zojuist in de linkeronderhoek omhoog is gekomen, betekent dat er een belangrijk stuk informatie te lezen valt of dat er een beslissing moet worden genomen.",
  },
  build_advice = {
    placing_object_blocks_door = "Dat voorwerp daar plaatsen, zou de toegang tot een deur blokkeren.",
    blueprint_would_block = "Met deze blauwdruk zou een andere kamer worden geblokkeerd. Probeer een andere grootte of een andere locatie!",
    door_not_reachable = "Zo kunnen mensen niet bij een deur komen. Hou je koppie erbij.",
    blueprint_invalid = "Dat is geen geldige blauwdruk.",
  },
  cheats = {
    th_cheat = "Gefeliciteerd, je hebt de cheats ontdekt!",
    roujin_on_cheat = "Roujin's uitdaging geactiveerd, succes...",
    roujin_off_cheat = "Roujin's uitdaging gedeactiveerd.",
    norest_on_cheat = "Oh nee! Het lijkt erop dat je personeel te veel cafeïne heeft geconsumeerd en nu geen behoefte meer heeft aan rust.",
    norest_off_cheat = "Oef! Het lijkt erop dat die buzz eindelijk is verdwenen. Het personeel zal nu goed rusten.",
  },
  staff_place_advice = {
    not_enough_lecture_chairs = "Elke student-arts heeft een collegestoel nodig om te zitten!",
  }
}
room_descriptions = {
  ultrascan = {
    [1] = "Echoscopie//",
    [2] = "De echoscopie is zo'n beetje het ultieme in diagnostische apparatuur. Het kost een aardige duit, maar dan heb je ook wat als je gaat voor fantastische diagnoses in je ziekenhuis.//",
    [3] = "De echoscopie wordt gebruikt door een arts. Het moet ook onderhouden worden. ",
  },
  gp = {
    [1] = "Spreekkamer//",
    [2] = "Dit is het fundament van alle diagnoses. Nieuwe patiënten komen hier langs zodat er gekeken kan worden wat er met hen aan de hand is. Vanaf hier worden ze doorverwezen naar andere diagnostische kamers of naar een kamer waar ze genezen kunnen worden. Als de eerste spreekkamer te druk wordt, zal je er waarschijnlijk nog één willen bouwen. Hoe groter de kamer, hoe meer voorwerpen je erin kwijt kunt, en hoe beter de arts in functie zich zal voelen. Dit geldt trouwens voor alle kamers.//",
    [3] = "De spreekkamer wordt gebruikt door een arts. ",
  },
  fracture_clinic = {
    [1] = "Gipskamer//",
    [2] = "Hier worden patiënten die de pech hebben een Botfactuur te hebben opgelopen geholpen. De gipsverwijderaar gebruikt krachtige industriële lasers om verhard gips weg te snijden, met slechts een kleine martelgang voor de patiënt.//",
    [3] = "De gipskamer heeft een zuster nodig. Het moet ook eens in de zoveel tijd onderhouden worden. ",
  },
  tv_room = {
    [1] = "TV ROOM NOT USED",
  },
  inflation = {
    [1] = "Inflatiekliniek//",
    [2] = "Patiënten met de pijnlijke doch grappige plofkop worden naar de inflatiekliniek gestuurd, waar het opgeblazen hoofd wordt doorgeprikt en meteen weer opgeblazen tot de juiste luchtdruk is bereikt.//",
    [3] = "De inflatiekliniek heeft een arts nodig. Het moet ook in de gaten worden gehouden door een conciërge. ",
  },
  jelly_vat = {
    [1] = "Gelatinekliniek//",
    [2] = "Patiënten die tot de lachwekkende ziekte gelatinis zijn overgeleverd blubberen zichzelf naar de gelatinekliniek, waar ze in een gelatinetank worden geplaatst. Dit geneest ze op een manier die zelfs de medische wetenschap nog niet helemaal duidelijk is.//",
    [3] = "De gelatinekliniek heeft een arts nodig, en het waakzame oog van een conciërge voor onderhoud. ",
  },
  scanner = {
    [1] = "Scanner//",
    [2] = "Met de moderne scanner kan er een nauwkeurige diagnose gesteld worden. Wanneer de diagnose is afgerond gaat de patiënt weer naar de spreekkamer voor verdere behandelingen.//",
    [3] = "De scanner heeft zowel een arts als onderhoud nodig. ",
  },
  blood_machine = {
    [1] = "Bloedmachine//",
    [2] = "De bloedmachine is een diagnosemachine die de bloedcellen van een patiënt analyseert om te zien wat er mis is.//",
    [3] = "De bloedmachine wordt gebruikt door een arts. Het heeft ook onderhoud nodig. ",
  },
  pharmacy = {
    [1] = "Apotheek//",
    [2] = "Patiënten die behandeld worden met een medicinaal drankje brengen een bezoekje aan de apotheek. Hoe meer geneesmiddelen er worden uitgevonden, hoe drukker het hier zal worden. Waarschijnlijk zal je later nog een apotheek willen bouwen.//",
    [3] = "Alleen zusters kunnen in een apotheek werken. ",
  },
  cardiogram = {
    [1] = "Cardio//",
    [2] = "Patiënten gaan hier naar toe voor controle en diagnose. Daarna gaan ze terug naar de spreekkamer om zich te laten behandelen.",
    [3] = "De cardio heeft een arts en onderhoud nodig. ",
  },
  ward = {
    [1] = "Slaapzaal//",
    [2] = "Patiënten verblijven hier kort voor observatie door een zuster. Ze rusten hier ook uit als ze zich klaar moeten maken voor een operatie.//",
    [3] = "De slaapzaal heeft een zuster nodig. ",
  },
  psych = {
    [1] = "Psychiatrie//",
    [2] = "Patiënten die een psychisch probleem hebben worden naar de psychiatrie gestuurd voor therapie. psychiaters kunnen ook diagnoses stellen. Als een patiënt aan een geestelijk probleem lijdt, kunnen ze met behulp van de trouwe ligbank de patiënt behandelen.//",
    [3] = "De psychiatrie heeft een arts nodig die een diploma heeft voor psychiater. ",
  },
  staff_room = {
    [1] = "Personeelsruimte//",
    [2] = "Op den duur worden je personeelsleden moe en moeten ze uitrusten. Ze gaan dan naar deze kamer toe zodat ze later weer met frisse moed en energie aan de slag kunnen. Personeelsleden die moe zijn gaan langzamer werken, fouten maken, meer geld vragen en zullen uiteindelijk ontslag nemen. Een personeelsruimte met genoeg ruimte is dus het geld en de ruimte waard. Richt de kamer zo in dat er genoeg mensen tegelijk gebruik kunnen maken van de kamer. ",
  },
  operating_theatre = {
    [1] = "Operatiekamer//",
    [2] = "De operatiekamer is onmisbaar in een ziekenhuis. Patiënten met verschillende lichamelijke kwalen kunnen hier worden geopereerd door twee chirurgen. Het is van belang dat de operatiekamer groot genoeg is en dat de juiste apparatuur aanwezig is.//",
    [3] = "Om de operatiekamer te kunnen gebruiken moet je twee chirurgen aannemen. ",
  },
  training = {
    [1] = "Klaslokaal//",
    [2] = "Je assistenten en basisartsen kunnen waardevolle ervaring opdoen en kwalificaties behalen door in dit lokaal te studeren onder een specialist. Deze specialist geeft zijn kennis van chirurgie, psychiatrie en/of onderzoek door aan de leerlingen. Artsen die al deze kwalificaties hebben zullen leren hoe ze hun vak nog beter kunnen uitvoeren.//", --[[''en/of:'' wordt de ''/'' hierbij getoond in het spel?]]--
    [3] = "Het klaslokaal heeft een specialist en leerlingen nodig. ",
  },
  dna_fixer = {
    [1] = "DNA hersteller//",
    [2] = "Patiënten waarmee gerotzooid is door bewoners van een andere wereld moeten hun DNA laten vervangen in deze kamer. De DNA reparatiemachine is een ingewikkeld en duur instrument en er zal altijd, gewoon voor het geval dat, een brandblusser bij de hand gehouden moeten worden.//",
    [3] = "De DNA reparatiemachine heeft onderhoud nodig van een conciërge. Alleen een arts met een onderzoeksgraad kan van deze machine gebruik maken. ",
  },
  research = {
    [1] = "Laboratorium//",
    [2] = "Hier worden nieuwe medicijnen en behandelingen uitgevonden. Dit belangrijke onderdeel van je ziekenhuis zal je beter in staat stellen je patiënten te genezen met als resultaat dat er meer patiënten zijn die je ziekenhuis gezond zullen verlaten.//",
    [3] = "Het laboratorium heeft een arts met een onderzoeksgraad nodig. ",
  },
  hair_restoration = {
    [1] = "Haarrestauratiekliniek//",
    [2] = "Patiënten die last hebben van extreme kaalheid worden naar de haarrestaurateur gestuurd. Een arts zal met deze machine het hoofd van de patiënt van een frisse, nieuwe coupe voorzien.//",
    [3] = "De haarrestauratie heeft een arts nodig. Ook moet een conciërge zo nu en dan wat onderhoud plegen. ",
  },
  general_diag = {
    [1] = "Algemene diagnose//",
    [2] = "Patiënten die een verdere diagnose moeten ondergaan worden hier naartoe gestuurd voor controle. Als men er in de spreekkamer niet achter komt wat er mis is, zal dit na de algemene diagnose vaak wel lukken. Na deze kamer gaan ze terug naar de spreekkamer om de resultaten te laten analyseren.//",
    [3] = "Algemene diagnose heeft alleen een arts nodig. ",
  },
  electrolysis = {
    [1] = "Elektrolyse//",
    [2] = "Patiënten met pilitis worden naar deze kamer gestuurd waar een speciale machine, de elektrolyseerder, de haren uitrukt en de poriën elektrisch sluit met een substantie die veel weg heeft van beton.//",
    [3] = "De elektrolysekamer wordt gebruikt door een arts en onderhouden door een conciërge. ",
  },
  slack_tongue = {
    [1] = "Lamme tongkliniek//",
    [2] = "Patiënten waarvan in de spreekkamer wordt vastgesteld dat ze lijden aan lamme tong, worden naar deze kliniek gestuurd voor een behandeling. De arts gebruikt hier een technisch hoogstandje om de tong uit te rekken en het overtollige spierweefsel weg te snijden. Hierna mag de patiënt weer volledig gezond zijn of haar weg naar huis vinden.//",
    [3] = "De lamme tongkliniek heeft een arts nodig. Het moet ook zo nu en dan onderhouden worden door een conciërge. ",
  },
  toilets = {
    [1] = "Toiletten//",
    [2] = "Ook patiënten voelen af en toe in hun binnenste dat het tijd is om een bruine trui te breien. Dit kunnen ze doen op je comfortabele toiletten. Als je veel bezoekers verwacht, kun je extra wasbakken en toiletten bouwen. Soms zal je meerdere faciliteiten willen bouwen verspreid over het ziekenhuis, zodat iedereen snel zijn behoefte kan doen. ",
  },
  no_room = {
    [1] = "",
  },
  x_ray = {
    [1] = "Röntgenkamer//",
    [2] = "Het röntgenapparaat maakt met speciale stralen een foto van het binnenste van de patiënt zodat ze een goed idee hebben van wat er met hem aan de hand is.//",
    [3] = "De röntgenkamer heeft een arts nodig. Ook moet het af en toe nagekeken worden door een conciërge. ",
  },
  decontamination = {
    [1] = "Ontsmettingskliniek//",
    [2] = "Patiënten die aan Straling zijn blootgesteld worden snel naar de ontsmettingskliniek doorverwezen. Deze kamer heeft een ontsmettingscabine die de patiënt reinigt van al die verschrikkelijke radioactiviteit.//",
    [3] = "De ontsmettingscabine heeft een arts nodig voor gebruik en een conciërge voor onderhoud. ",
  },
}
introduction_texts = {
  level17 =
    "Nog een laatste waarschuwing: hou een oogje op je reputatie. Je reputatie is namelijk iets wat patiënten van heinde en verre naar je ziekenhuis laat komen. " ..
    "Als je niet teveel mensen doodt en ze redelijk gelukkig houdt, zou je niet al teveel problemen moeten hebben met dit level!//" ..
    "En nu mag je het zelf opknappen. Veel succes ermee!",
  level1 =
    "Welkom in je eerste ziekenhuis!//" ..
    "Zorg dat de boel op gang komt door een receptie te plaatsen en een spreekkamer te bouwen. Neem ook een receptioniste en een arts in dienst. " ..
    "Wacht dan tot er mensen langskomen. " ..
    "Het is een goed idee om een psychiatrische afdeling te bouwen en een arts in te huren met de benodigde kwalificaties. " ..
    "Een apotheek en een zuster zijn essentieel voor het genezen van je patiënten. " ..
    "Kijk uit voor ernstige gevallen van plofkop. Een inflatiekliniek lost deze probleempjes op. " ..
    "Genees, om de spits af te bijten, 10 mensen en hou je reputatie boven de 200.",
  level9 =
    "Nu je de kas van het ministerie flink hebt gespekt en de minister dankzij jouw donaties vrolijk in zijn splinternieuwe limousine rondrijdt, kun je nu weer terug naar je echte taak: het bouwen van een ziekenhuis dat niet alleen goed draait maar ook duidelijk om haar arme en zieke patiënten geeft. " ..
    "Verwacht dat er een boel problemen de kop opsteken. " ..
    "Als je genoeg kamers en een goed getrainde staf hebt, zal je die problemen makkelijk het hoofd moeten kunnen bieden. " ..
    "Je ziekenhuis moet uiteindelijk $200,000 waard zijn. Verzamel ook een comfortabele $400.000 op je bankrekening. " ..
    "Met minder dan dat kun je het level niet uitspelen.",
  level2 =
    "Er zijn hier in de omgeving een stuk meer ziektes. " ..
    "Zet je ziekenhuis zo op dat je de grotere hoeveelheid patiënten kunt behapstukken en bouw ook nog een laboratorium. " ..
    "Hou je ziekenhuis schoon en je reputatie zo hoog mogelijk. Je zult te maken krijgen met ziektes zoals lamme tong, dus je hebt een lamme tongkliniek nodig. " ..
    "Je hebt ook een cardio nodig zodat je betere diagnoses kunt stellen en nieuwe ziektes kunt ontdekken. " ..
    "Beide kamers moeten worden onderzocht voor je ze kunt bouwen. Je kunt nu ook extra gebouwen kopen om je ziekenhuis uit te breiden. Gebruik hier het kaartscherm voor. " ..
    "Probeer een reputatie van 300 te behalen, een saldo van 10,000 op de teller te hebben staan en 40 mensen te genezen.",
  level7 =
    "Je wordt in de gaten gehouden door het Ministerie van Volksgezondheid, dus zorg ervoor dat je flinke winst draait en dat je reputatie constant hoog blijft. " ..
    "We kunnen ons geen doden veroorloven; dat is slecht voor zaken. " ..
    "Zorg dat je personeel in vorm is en dat je alle apparatuur hebt die nodig is. " ..
    "Zorg voor een reputatie van 600 en een saldo $200.000.",
  level5 =
    "Dit wordt een druk ziekenhuis met een grote variatie aan ziektebeelden. " ..
    "Je artsen komen allemaal net van school af, dus bouw een klaslokaal en geef ze een opleiding tot een acceptabel niveau. " ..
    "Je hebt maar drie specialisten om de rest van je personeel op te leiden, dus hou ze tevreden. " ..
    "Daarbij is je ziekenhuis gebouwd op de San Androïde-breuk. " ..
    "Aardbevingen kunnen dus elk moment toeslaan. " ..
    "Deze zullen je machines beschadigen en je goedlopende ziekenhuis flink verstoren. " ..
    "Bouw je reputatie op tot boven de 400 en zorg voor een nette $50.000 op je bankrekening. Zorg daarnaast dat je 200 patiënten geneest.",
  level4 =
    "Hou al je patiënten tevreden en werk ze zo efficiënt mogelijk af. Voorkom sterfgevallen zoveel mogelijk." ..
    "Je reputatie staat op het spel, dus hou die zo hoog mogelijk. " ..
    "Maak je niet al teveel zorgen over geld; dat komt wel als die o zo belangrijke reputatie groeit. " ..
    "Je kunt nu je ook artsen trainen, zodat ze beter gekwalificeerd zullen zijn. " ..
    "Waarschijnlijk zal je heel wat patiënten tegenkomen die nogal doorzichtig zijn. " ..
    "Bouw je reputatie op tot deze de 500 heeft bereikt.",

  --[[ Level 13 and 14 are rat shooting galleries and are thus not available through the File menu as of yet. --]]

  level14 =
    "Je hebt nog een uitdaging gekregen; een compleet onverwacht verrassingsziekenhuis! " ..
    "Als je hier een succes van kunt maken ben je de winnaar van alle winnaars. " ..
    "Maar denk niet dat het een eitje is. Het is de moeilijkste opdracht die je ooit zult aannemen. " ..
    "Veel succes!",

--[[ Level 15 is most likely just removed content. I translated it as usual just in case the team finds something to do with it. --]]

  level15 =
    "Goed, dat is dus de basis van een ziekenhuis bouwen.//" ..
    "Je artsen zullen alle hulp nodig hebben die ze kunnen gebruiken bij het stellen van diagnoses. Je kunt ze helpen " ..
    "door meerdere diagnostische kamers te bouwen, zoals de algemene diagnose.",
  level8 =
    "Het is aan jou om het meeste efficiënte ziekenhuis op te zetten voor zo weinig mogelijk geld. " ..
    "De mensen zitten hier goed in de slappe was, dus pers zoveel mogelijk geld uit ze als mogelijk is. " ..
    "Ja, mensen genezen is heel leuk, maar je hebt het geld dat ze binnenbrengen echt NODIG. " ..
    "Schudt die zieke mensen dus maar flink uit. " ..
    "Verzamel een fortuin van $300.000 om dit level uit te spelen.",
  level13 =
    "Je fantastische werk als directeur is ondertussen bij de Speciale Geheime Divisie van de Geheime Speciale Dienst bekend. " ..
    "Ze hebben een bonus voor je; er is een ziekenhuis geïnfecteerd met ratten en ze hebben een echte Terminator nodig. " ..
    "Vermorzel zoveel mogelijk ratten voordat de conciërges de boel hebben opgeruimd. " ..
    "Denk je dat je die taak aankunt?",
  level16 =
    "Zodra je wat diagnoses hebt gesteld zal je behandelkamers en klinieken moeten bouwen om voor de mensen te zorgen. Een goede om mee te beginnen is de apotheek. " ..
    "Je moet ook een zuster inhuren zodat ze de verschillende medicijnen kan toedienen.",
  level6 =
    "Gebruik al je kennis om je ziekenhuis soepel te laten draaien, een gezonde winst te maken en alle ziektes te genezen die de mensen met zich meedragen. " ..
    "Wees je ervan bewust dat de atmosfeer hier erg geschikt is voor het overdragen van bacteriën en infecties. " ..
    "Hou je ziekenhuis dus schoon, tenzij je een lange rits van epidemieën onder je patiënten wilt brengen. " ..
    "Zorg ervoor dat je $150.000 verdient en dat je ziekenhuis meer dan $140.000 waard is.",
  level12 =
    "Dit is de moeder van alle uitdagingen. " ..
    "Het ministerie is zo onder de indruk van je succes, dat ze je de hoogste positie hebben aangeboden. Ze willen iemand hebben die nog een ultiem ziekenhuis kan bouwen, veel geld kan verdienen en een fantastische reputatie kan opbouwen. " ..
    "Je wordt verwacht alle, maar dan ook echt alle ziektes te kunnen genezen en alle prijzen in de wacht te slepen. " ..
    "Denk je dat je dat aankunt?" ..
    "Verdien $650.000, genees 750 mensen en verdien krijg een reputatie van 800 om dit te winnen.",
  level3 =
    "Dit keer bouw je een ziekenhuis in een rijke buurt. " ..
    "Het Ministerie van Volksgezondheid vraagt een gezonde winst van je. " ..
    "Je zult eerst een goede reputatie moeten opbouwen, maar schakel zodra je ziekenhuis volloopt over op zoveel mogelijk geld binnenhalen. " ..
    "Er kunnen zich ook noodgevallen voordoen. " ..
    "Dit zijn gevallen waarin er meerdere patiënten binnenkomen met dezelfde ziekte. " ..
    "Als je ze allemaal binnen een bepaalde tijd geneest, zit er een vette bonus aan vast en gaat je reputatie erop vooruit. " ..
    "Ziektes als het King Complex kunnen voorkomen en er wordt aangeraden om wat geld opzij te zetten voor een operatiekamer in de buurt van een slaapzaal. " ..
    "Verdien $20.000 om het level te halen.",
  level10 =
    "Het ministerie vraagt nu niet alleen dat je alle ziektes in deze buurt aanpakt, maar ook dat je je concentreert op de efficiëntie van je medicijnen. " ..
    "Er zijn wat klachten binnengekomen van Ofziek, de waakhond van de gezondheidszorg, dus als je goed over wil komen, zorg je ervoor dat je medicijnen goed werken. " ..
    "Zorg ook dat er niets te klagen valt over je ziekenhuis zelf. Hou die sterfgevallen zeldzaam. " ..
    "Hint: Hou wat ruimte vrij voor een gelatinetank. " ..
    "Ontwikkel al je medicijnen door tot ze ten minste 80 procent effectief zijn, behaal een reputatie van 650 en behaal een saldo van $500.000. ",
  level11 =
    "Je hebt de kans gekregen het ultieme ziekenhuis te bouwen. " ..
    "Dit is een zeer prestigieuze omgeving, en het ministerie wil een zo goed mogelijk ziekenhuis zien. " ..
    "We verwachten dat je flink geld binnenhaalt, een fantastische reputatie hebt en elke situatie aan kunt. " ..
    "Dit is een belangrijke taak. " ..
    "Je bent heel wat als je dit lukt. " ..
    "Opmerkenswaardig is dat er UFO's in de omgeving gezien zijn. Zorg ervoor dat je personeel klaar is voor onverwachte bezoekers. " ..
    "Je ziekenhuis moet $240.000 waard zijn en je moet $500.000 op de bank hebben staan. Ook moet je reputatie minimaal 700 bedragen.",
  level18 = "",
  demo =
    "Welkom in het demo ziekenhuis!//" ..
    "Jammer genoeg bevat de demo versie buiten zelfgemaakte levels alleen dit ziekenhuis, maar er is meer dan genoeg te doen om je voorlopig bezig te houden! " ..
    "Je zult verschillende kwalen tegenkomen die verschillende ruimtes nodig hebben om genezen te worden, af en toe kunnen zich noodgevallen voordoen, en je zult nieuwe ruimtes uit moeten vinden met het laboratorium. " ..
    "Jouw doel is om $100,000 te verdienen, de waarde van je ziekenhuis te verhogen naar $70,000 en een reputatie van 700 te behalen, terwijl je 75% van je patiënten geneest. " ..
    "Zorg er voor dat je reputatie niet lager wordt dan 300 en dat je niet meer dan 40% van je patiënten vermoord, anders zal je ontslagen worden!//" ..
    "Succes!",
}
humanoid_name_starts = {
  [1] = "GOUD",
  [2] = "HOOGE",
  [3] = "EEN",
  [4] = "BENE",
  [5] = "BAN",
  [6] = "BILT",
  [7] = "WIJDE",
  [8] = "WATER",
  [9] = "POOT",
  [10] = "KONINGS",
  [11] = "VAN BAR",
  [12] = "DE PET",
  [13] = "MAR",
  [14] = "BAAI",
  [15] = "WARS",
  [16] = "RIDDER",
  [17] = "VAN KRAB",
  [18] = "VIS",
  [19] = "WATER",
  [20] = "MOLEN",
  [21] = "DE BIJ",
  [22] = "VEEN",
  [23] = "RICHT",
  [24] = "SCHOOTS",
  [25] = "BOERE",
  [26] = "VAN PRIJK",
  [27] = "KOERS",
  [28] = "WIT",
  [29] = "BINNENS",
  [30] = "BON",
  [31] = "VD POOG",
  [32] = "VAN REGT",
  [33] = "VD KERK",
}
humanoid_name_ends = {
  [1] = "SMID",
  [2] = "WIJK",
  [3] = "WEGE",
  [4] = "SEN",
  [5] = "TEN",
  [6] = "VELD",
  [7] = "WEG",
  [8] = "ZOON",
  [9] = "HOUT",
  [10] = "BEEK",
  [11] = "BOOM",
  [12] = "ING",
  [13] = "LAAT",
  [14] = "PLAAT",
  [15] = "DIJK",
  [16] = "POORTE",
  [17] = "MARS",
  [18] = "HEIDE",
  [19] = "MOND",
  [20] = "MAN",
  [21] = "SPRAEK",
  [22] = "BERGH",
  [23] = "BOER",
  [24] = "MOER",
  [25] = "PLEIJN",
  [26] = "GRAAF",
}
vip_names = {
  [1] = "De Burgemeester van Lagerzand",
  [2] = "Marko Boerzaato",
  [3] = "Koning Filip van België",
  [4] = "Aung Sang Su Kyi, de Myanmarese Oppositieleidster",
  [5] = "De helderziende Zomanda",
  [6] = "De schrijver Jan Volkerts",
  [7] = "Jan Peter Bakellende",
  [8] = "Hans Spreeuwen",
  [9] = "Een Eredivise voetballer",
  [10] = "Albert Zweijn",
  health_minister = "De Minister van Volksgezondheid",
}
custom_game_window = {
  caption = "Uitzendwerk",
  free_build = "Vrij bouwen",
  load_selected_level = "Start"
}
transactions = {  --[[Hier geen veranderingen in aanbrengen. Sommige woorden zijn bewust weggelaten vanwege ruimtegebrek ingame!]]--
  severance = "Ontslagpremie",
  research = "Onderzoekskosten",
  eoy_trophy_bonus = "Prijzengeld",
  buy_object = "Aankoop",
  cure_colon = "Genezen:",
  epidemy_coverup_fine = "Boete verbergen epidemie",
  final_treat_colon = "Laatste behandeling:",
  jukebox = "Inkomen: jukebox",
  loan_interest = "Rente lening",
  overdraft = "Rente rood staan",
  wages = "Salaris",
  loan_repayment = "Afbetaling lening",
  personal_bonus = "Persoonlijke bonus",
  drug_cost = "Medicijnen",
  cure = "Genezen",
  heating = "Stookkosten",
  treat_colon = "Behandeld:",
  compensation = "Compensatie v. overheid",
  epidemy_fine = "Boete epidemie",
  buy_land = "Land gekocht",
  research_bonus = "Bonus onderzoek",
  general_bonus = "Algemene bonus uitbetaling",
  deposit = "Treatment Deposit",  --[[geen functie]]
  eoy_bonus_penalty = "Eindejaarsbonus / -boete",
  cheat = "Gefraudeerd",
  drinks = "Inkomen: frisdrankautomaat",
  vaccination = "Inenting",
  advance_colon = "Advance:", --[[geen functie]]
  vip_award = "VIP bonus",
  hire_staff = "Inhuren personeel",
  bank_loan = "Lening",
  machine_replacement = "Vervanging apparatuur",
  emergency_bonus = "Noodgeval bonus",
  build_room = "Constructie",
  insurance_colon = "Verzekering:",
  sell_object = "Verkoop",
  remove_room = "Constructie: Vernielde kamer",
}
letter = {
  [1] = {
    [1] = "Beste %s//",
    [2] = "Fantastisch! Je hebt dit ziekenhuis goed onder controle gehouden. Wij, hoge pieten van het Ministerie van Volksgezondheid, zouden graag willen weten of je geïnteresseerd bent in een groter project. Wij denken dat je een perfecte kandidaat bent voor een andere locatie. Het salaris is $%d. Denk er maar eens over na.//",
    [3] = "Ben je geïnteresseerd in een baan in het %s-ziekenhuis?",
  },
  [2] = {
    [1] = "Beste %s//",
    [2] = "Goed werk! Je hebt fantastische vooruitgang geboekt met je ziekenhuis. We hebben een andere locatie die je kunt managen als je eens een andere omgeving en een paar frisse uitdagingen wilt tegemoetzien. Je hoeft het niet te accepteren, maar het is het wel waard. Het salaris is $%d//",
    [3] = "Wil je een baan in Ziekenhuis %s?",
  },
  [3] = {
    [1] = "Beste %s//",
    [2] = "Je bent erg succesvol geweest tijdens je termijn in dit ziekenhuis. We zien grootse dingen in je toekomst en willen je graag een andere positie aanbieden. Het salaris bedraagt $%d, en volgens ons zal je de nieuwe uitdaging fantastisch vinden.//",
    [3] = "Wil je een positie in het %s-ziekenhuis?",
  },
  [4] = {
    [1] = "Beste %s//",
    [2] = "Gefeliciteerd! Wij van het ministerie zijn erg onder de indruk van je kundigheid met ziekenhuizen. Je bent zeker weten een ster in de gezondheidszorg. Toch denken we dat je voorkeur uitgaat naar een iets moeilijkere positie. Je zou een salaris van $%d krijgen, maar de keuze is helemaal aan jou.//",
    [3] = "Ben je geïnteresseerd in werken in het ziekenhuis bij %s?",
  },
  [5] = {
    [1] = "Beste %s//",
    [2] = "We hebben respect voor je beslissing in dit fantastische ziekenhuis te blijven, maar we willen je verzoeken het nog eens te overdenken. We zullen je het fantastische salaris van $%d aanbieden als je bereid bent om te verhuizen naar een ander ziekenhuis, waar je het net zo gladjes kan laten draaien als op je huidige plek.//",
    [3] = "Wil je nu naar Ziekenhuis %s?",
  },
  [6] = {
    [1] = "Beste %s//",
    [2] = "Gegroet. We weten hoe gelukkig je bent met dit prachtige instituut, maar waarschijnlijk zou je eens over de voortgang van je carrière moeten nadenken. Je zult beschikken over een salaris van $%d als je besluit te verhuizen. Het is het overdenken waard.//",
    [3] = "Wil je een positie in het %s-ziekenhuis?",
  },
  [7] = {
    [1] = "Beste %s//",
    [2] = "Goedendag! Het Ministerie van Volksgezondheid wil graag weten of je terug wilt komen op je beslissing om bij het huidige ziekenhuis te blijven. We vinden dat je een prachtig ziekenhuis hebt, maar je zou er goed aan doen een uitdagendere positie aan te nemen met een salaris van $%d.//",
    [3] = "Wil je een positie in het ziekenhuis van %s accepteren?",
  },
  [8] = {
    [1] = "Beste %s//",
    [2] = "Nogmaals goedendag. Op onze afgelopen brief heb je afwijzend gereageerd, toen we je een prachtige positie aanboden in een nieuw ziekenhuis en een salaris van $%d. We denken echter dat je nog eens zou moeten nadenken over deze beslissing. We hebben de perfect baan voor je!//",
    [3] = "Wil je de positie in het ziekenhuis van %s accepteren? Asjeblieft?",
  },
  [9] = {
    [1] = "Beste %s//",
    [2] = "Je hebt bewezen de beste ziekenhuisdirecteur te zijn die de medische wereld ooit heeft gekend. Het is een goliathprestatie die niet onbeloond gelaten kan worden, dus we willen je bij dezen de positie van Opperdirecteur van Alle Ziekenhuizen aanbieden. Dit is een hele eer met het riante salaris van $%d. Je krijgt een parade met confetti en mensen zullen hun dankbaarheid tonen waar je ook gaat.//",
    [3] = "Bedankt voor alles dat je hebt gedaan. Geniet van je semi-pensionering.//",
    [4] = "",
  },
  [10] = {
    [1] = "Beste %s//",
    [2] = "Gefeliciteerd met het fantastische werk dat je hebt geleverd bij elk ziekenhuis waar we je hebben over aangesteld. Zo'n geweldige prestatie geeft je de vrijheid van alle steden ter wereld. Je krijgt een pensioen van $%d, een limousine en alles wat we vragen is dat je van stad tot stad reist, je aanbidders gedag zeggen en lezingen houden ter promotie van ziekenhuizen waar nodig.//",
    [3] = "We zijn allemaal erg trots op je. Een ieder van ons is dankbaar voor het harde werk dat je hebt verzet, zodat vele levens gered konden worden.//",
    [4] = "",
  },
  [11] = {
    [1] = "Beste %s//",
    [2] = "Je hebt een voorbeeldige carrière achter de rug en je bent een inspiratie voor ons allen. Hartelijk bedankt voor het geweldige werk dat je hebt gedaan in alle ziekenhuizen waar we je over hebben aangesteld. We willen je eren met een levenslang salaris van $%d als je ons helpt door in een officiële cabrio van stad naar stad te reizen, waar je lezingen geeft over hoe je zo veel, zo snel voor elkaar hebt gekregen.//",
    [3] = "Je bent een voorbeeld voor elk verstandig mens en iedereen ter wereld, zonder uitzondering. Iedereen ziet je als een geschenk uit de hemel.//",
    [4] = "",
  },
  [12] = {
    [1] = "Beste %s//",
    [2] = "Je succesvolle carrière naar de beste ziekenhuisdirecteur sinds Mozes is tot een einde gekomen. De impact op het knusse wereldje van gezondheidszorg is echter zo groot geweest dat het ministerie je graag een salaris van $%d wil aanbieden om in onze naam festivals te openen, schepen te dopen en in praatprogramma's te verschijnen. De hele wereld kijkt uit naar je eerste verschijning! Het zou fantastische PR zijn voor ons allemaal!//",
    [3] = "Accepteer asjeblieft deze positie. Het werk is niet zwaar. Ook geven we je een auto en een politie escorte waar je ook gaat.//",
    [4] = "",
  },
  dear_player = "Beste %s",
  custom_level_completed = "Goed werk! Je hebt alle doelen voor dit ziekenhuis behaald!",
  return_to_main_menu = "Wil je teruggaan naar het hoofdmenu of doorspelen?",
  campaign_completed = "Ongelofelijk! Je hebt alle levels gehaald. Je kunt nu ontspannen en genieten van het vullen van forums op internet over je prestaties. Veel succes!",
  campaign_level_completed = "Goed gedaan! Je hebt het level gehaald. Maar het is nog niet voorbij!// Wil je een baan bij %s Hospital?",
  campaign_level_missing = "Sorry, maar het volgende level van deze campagne lijkt te ontbreken. (Naam: %s)",
}
install = {
  title = "--------------------------------- CorsixTH Setup ---------------------------------",
  th_directory = "CorsixTH heeft de databestanden van de originele Theme Hospital (of de demo) nodig om te kunnen draaien. Geef hieronder aan waar Theme Hospital staat geïnstalleerd.",
  exit = "Afsluiten",
  ok = "OK",
  cancel = "Annuleren",
}
casebook = {
  sent_home = "weggestuurd",
  deaths = "doden",
  treatment_charge = "kosten behandeling",
  reputation = "reputatie",
  research = "onderzoek specialiseren",
  cure = "behandeling",
  cured = "genezen",
  earned_money = "omzet",
  cure_desc = {
    hire_psychiatrists = "Je moet psychiaters aannemen.",
    improve_cure = "Behandeling verbeteren.",
    hire_nurses = "Je moet zusters aannemen.",
    build_ward = "Je moet nog een slaapzaal bouwen.",
    no_cure_known = "Geen geneesmiddel bekend.",
    cure_known = "Geneesmiddel.",
    build_room = "Ik raad je aan een %s te bouwen",
    hire_doctors = "Je moet artsen aannemen.",
    hire_surgeons = "Je moet chirurgen aannemen.",
  },
}
errors = {
  dialog_missing_graphics = "Sorry, de demobestanden bevatten geen data voor dit scherm.",
  load_quick_save = "Error, kan de quicksave niet laden, omdat het niet bestaat. Maak je maar geen zorgen, we hebben er eentje voor je aangemaakt!",
  load_prefix = "Fout bij het laden van het spel: ",
  save_prefix = "Fout bij het opslaan van het spel: ",
  map_file_missing = "Bestand %s voor dit level is niet gevonden!",
  minimum_screen_size = "Voer een resolutie in van minstens 640x480.",
  unavailable_screen_size = "De resolutie die je hebt ingevoerd is niet beschikbaar in fullscreen",
  alien_dna = "LET OP: Er zijn geen animaties voor alien patiënten die zitten, op deuren kloppenen, deuren openen, enz. Daarom veranderen ze naar een normaal mens als ze dit doen en veranderen dan weer terug, net als in Them Hospital.  Patiënten met alien-DNA verschijnen alleen wanneer dit in het level is toegestaan.",
  fractured_bones = "LET OP: De animatie voor vrouwelijke patiënten met gebrokken botten is niet goed.",
  no_games_to_contine = "Er zijn geen opgeslagen spellen.",
  dialog_empty_queue = "Een mensachtige is de weg helemaal kwijt, er was geen informatie meer wat vervolgens te gaan doen. Meer gedetailleerde informatie kun je vinden in het kommando scherm. Een window met deze mensachtige is geopend, wil je dat ze het ziekenhuis verlaten?",
  compatibility_error = {
    demo_in_full = "Sorry, je kunt geen demo-savegame openen terwijl de volledige gamebestanden zijn geladen. Werk je TH Data-mapinstelling bij.",
    full_in_demo = "Sorry, je kunt geen savegame van de volledige game openen terwijl de demobestanden zijn geladen. Werk je TH Data-mapinstelling bij.",
    new_in_old = "Sorry, dit opslagbestand is aangemaakt met een nieuwere versie van CorsixTH en is niet compatibel. Update naar een recentere versie.",
  },
  could_not_find_first_campaign_level = "Kon het eerste level van deze campagne niet vinden: %s",
  could_not_load_campaign = "Kan de campagne niet laden: %s",
  load_level_prefix = "Fout bij het laden van level: ",
  load_map_prefix = "Fout bij het laden van map: ",
  music = "Er zijn afspeelproblemen met een of meer bestanden in uw muziekfolder. Problematische bestanden worden uitgeschakeld in de jukebox. Zie het consolevenster voor meer informatie.",
  save_to_tmp = "Poging om naar %s te schrijven is mislukt. Het bestand is in plaats daarvan geschreven naar de tijdelijke locatie %s vanwege de fout: %s",
}
diseases = {
  diag_ward = {
    name = "Diag slaapzaal",
  },
  diag_ultrascan = {
    name = "Diag echoscopie",
  },
  autopsy = {
    name = "Autopsie",
  },
  diag_blood_machine = {
    name = "Diag bloedmachine",
  },
  diag_x_ray = {
    name = "Diag röntgen",
  },
  diag_psych = {
    name = "Diag psychiater",
  },
  diag_general_diag = {
    name = "Diag algemeen",
  },
  general_practice = {
    name = "Spreekkamerbezoek",
  },
  diag_cardiogram = {
    name = "Diag cardio",
  },
  diag_scanner = {
    name = "Diag scanner",
  },

  third_degree_sideburns = {   --[[3rd Degree Sideburns (een woordspeling op derdegraads brandwonden en bakkebaarden--]]--
    cause = "Oorzaak: nostalgisch verlangen naar de seventies.",
    cure = "Behandeling: de psychiater probeert de patiënt er via moderne conversatietechnieken van te overtuigen dat die flamboyante stijlen echt niet meer kunnen.",
    name = "Derdegraads brandhaar",
    symptoms = "Symptomen: fel geverfd haar, bakkebaarden, plateauschoenen en glitter make-up.",
  },
  discrete_itching = {
    cause = "Oorzaak: kleine insecten met scherpe tandjes.",
    cure = "Behandeling: patiënt drinkt een farmaceutische klodder anti-jeuksiroop.",
    name = "Onregelmatige jeuk",
    symptoms = "Symptomen: krabben met lokale ontstekingen tot gevolg.",
  },
  the_squits = {
    cause = "Oorzaak: het eten van aan de binnenkant van de oven aangebakken stukjes pizza.",
    cure = "Behandeling: een plakkerige mix van draderige chemicaliën drinken om de binnenkant van de patiënt weer wat te laten stollen.",
    name = "Sproeipoep",
    symptoms = "Symptomen: ugh. Dat kun je vast zelf wel bedenken.",
  },
  spare_ribs = {
    cause = "Oorzaak: op koude stenen vloeren zitten.",
    cure = "Behandeling: het stukje rib wordt verwijderd door twee chirurgen en aan de patiënt in een zakje meegegeven.",
    name = "Spare Ribs", --its has the same double meaning as in English.
    symptoms = "Symptomen: een iets te grote borstkas.",
  },
  king_complex = {
    cause = "Oorzaak: de geest van de King neemt bezit van de patiënt.",
    cure = "Behandeling: een psychiater vertelt de patiënt hoe belachelijk hij of zij eruit ziet.",
    name = "King Complex",
    symptoms = "Symptomen: een dieet van cheeseburgers en felgekleurd suedè schoeisel.",
  },
  pregnancy = {
    cause = "Oorzaak: stroomuitval in steden.",
    cure = "Behandeling: de baby wordt verwijderd in de operatiekamer en aan de patiënt gegeven.",
    name = "Zwangerschap",
    symptoms = "Symptomen: veel eten met bolle buik tot gevolg.",
  },
  fake_blood = {
    cause = "Oorzaak: de patiënt is het slachtoffer van een flauwe grap.",
    cure = "Behandeling: de kalmerende stem van een psychiater is het enige dat dit kan oplossen.",
    name = "Nepbloed",
    symptoms = "Symptomen: rode vloeistof in aderen die oplost bij contact met kleding.",
  },
  invisibility = {
    cause = "Oorzaak: gebeten worden door een radioactieve (en onzichtbare) mier.",
    cure = "Behandeling: een fel drankje uit de apotheek toont weer de ware kleuren van de patiënt.",
    name = "Onzichtbaarheid",
    symptoms = "Symptomen: patiënten lijden er niet onder. Sommigen maken misbruik van de situatie door grapjes uit te halen met hun familie.",
  },
  golf_stones = {
    cause = "Oorzaak: blootstelling aan giftig gas uit golfballen.",
    cure = "Behandeling: verwijdering via operatie door twee chirurgen.",
    name = "Golfstenen",
    symptoms = "Symptomen: ijlen en grote schaamte.",
  },
  infectious_laughter = {
    cause = "Oorzaak: klassieke comedyseries.",
    cure = "Behandeling: een gekwalificeerde psychiater vertelt de patiënt hoe verschrikkelijk zijn ziekte wel niet is.",
    name = "Aanstekelijke lach",
    symptoms = "Symptomen: constant gegniffel en het herhalen van flauwe kantlijngrapjes.",
  },
  baldness = {
    cause = "Oorzaak: liegen en verhalen verzinnen om populair te zijn.",
    cure = "Behandeling: het haar wordt naadloos vastgesmolten in het hoofd van de patiënt met deze pijnlijke machine.",
    name = "Kaalheid",
    symptoms = "Symptomen: een glimmend hoofd en schaamte.",
  },
  heaped_piles = {
    cause = "Oorzaak: rondhangen bij het koffieautomaat.",
    cure = "Behandeling: een prettig, krachtig drankje met een zuurgraad waarvan de kruisbessen van binnenuit oplossen.",
    name = "Kuise kruisbessen",
    symptoms = "Symptomen: het is voor de patiënt net alsof hij op een zak knikkers zit.",
  },
  unexpected_swelling = {
    cause = "Oorzaak: iets onverwachts.",
    cure = "Behandeling: de zwelling kan alleen worden doorgeprikt door twee chirurgen.",
    name = "Onverwachte zwelling",
    symptoms = "Symptomen: een zwelling.",
  },
  jellyitis = {
    cause = "Oorzaak: gelatinerijk dieet en teveel beweging.",
    cure = "Behandeling: de patiënt wordt in een gelatinetank gegoten om daar een beetje te stollen.",
    name = "Gelatinis",
    symptoms = "Symptomen: uitzonderlijke drillerigheid en vallen.",
  },
  hairyitis = {
    cause = "Oorzaak: overmatige blootstelling aan de maan.",
    cure = "Behandeling: een elektrolysemachine verwijdert het haar en dicht de poriën.",
    name = "Pilitis",
    symptoms = "Symptomen: de zieke ervaart een betere reukzin.",
  },
  alien_dna = {
    cause = "Oorzaak: gezichtzuigers met het bloed van intelligente aliens.",
    cure = "Behandeling: het DNA wordt machinaal verwijderd, de buitenaardse elementen worden gefilterd en het DNA wordt snel weer teruggepompt.",
    name = "Buitenaards DNA",
    symptoms = "Symptomen: langzame monsterachtige metamorfose en een drang tot het vernietigen van onze steden.",
  },
  bloaty_head = {
    cause = "Oorzaak: het opsnuiven van kaas en het drinken van ongezuiverd regenwater.",
    cure = "Behandeling: het opgezwollen hoofd wordt doorgeprikt en weer opgeblazen met een handige machine.",
    name = "Plofkop",
    symptoms = "Symptomen: een enorm opgezwollen hoofd; zeer ongemakkelijk voor de zieke.",
  },
  gastric_ejections = {
    cause = "Oorzaak: pittig Mexicaans of Indiaas eten.",
    cure = "Behandeling: een speciaal bindend drankje zorgt ervoor dat er niets meer uit wordt geworpen.",
    name = "Gastrische uitstoot",
    symptoms = "Symptomen: halfverteerd voedsel wordt in willekeurige clusters uit de patiënt gestoten.",
  },
  uncommon_cold = {
    cause = "Oorzaak: deeltjes snot in de lucht.",
    cure = "Behandeling: een grote slok speciale hoestdrank uit de apotheek, gemaakt van speciale ingrediënten.",
    name = "Verguurheid",
    symptoms = "Symptomen: loopneus, niezen en verkleurde longen.",
  },
  corrugated_ankles = {
    cause = "Oorzaak: het rijden over infrastructurele aanpassingen die het verkeer behoren te vertragen.",
    cure = "Behandeling: het drinken van een licht bijtend kruidenmengsel zou de enkels weer recht moeten trekken.",
    name = "Geribbelde enkels",
    symptoms = "Symptomen: schoeisel zit niet zo lekker.",
  },
  sleeping_illness = {
    cause = "Oorzaak: een overactieve slaapklier in het gehemelte.",
    cure = "Behandeling: een hoge dosis oppepmiddel wordt door een zuster toegediend.",
    name = "Slaapkwaal",
    symptoms = "Symptomen: een onbedwingbare zin om gewoon ergens in slaap te vallen.",
  },
  sweaty_palms = {
    cause = "Oorzaak: angst voor sollicitaties.",
    cure = "Behandeling: een psychiater moet de patiënt overtuigen dat dit geen echte ziekte is.",
    name = "Zweethanden",
    symptoms = "Symptomen: de hand van de patiënt voelt aan als een natte spons.",
  },
  serious_radiation = {
    cause = "Oorzaak: plutoniumisotopen verwarren met kauwgom.",
    cure = "Behandeling: de patiënt wordt voor grondige reiniging in een ontsmettingscabine geplaatst.",
    name = "Zware straling",
    symptoms = "Symptomen: patiënten met deze aandoening voelen zich heel, heel erg ziek.",
  },
  gut_rot = {
    cause = "Oorzaak: tante Triens Vrolijke Whiskey Hoestsiroop.",
    cure = "Behandeling: een zuster dient een selectie opgeloste chemicaliën toe om het buikje van binnen te bekleden.",
    name = "Buikrot",
    symptoms = "Symptomen: geen hoest, maar ook geen maagwand.",
  },
  iron_lungs = {
    cause = "Oorzaak: smog van de binnenstad vermengd met kebabrestjes.",
    cure = "Behandeling: twee chirurgen verwijderen de massieve longen in een operatiekamer.",
    name = "IJzeren longen",
    symptoms = "Symptomen: vuurspuwen en luid onder water kunnen schreeuwen.",
  },
  broken_wind = {
    cause = "Oorzaak: een loopband gebruiken net na de maaltijd.",
    cure = "Behandeling: in de apotheek wordt er snel een zware mix van speciale waterige atomen gedronken.",
    name = "Wind tegen",
    symptoms = "Symptomen: de patiënt verschijnt altijd chagrijnig op het werk. Dat geld ook voor mensen die dezelfde kant op fietsen.",
  },
  kidney_beans = {
    cause = "Oorzaak: kauwen op ijsklontjes uit drankjes.",
    cure = "Behandeling: twee chirurgen verwijderen het froliet zonder gevoelige lichaamsdelen aan te raken.",
    name = "Nierfroliet", --combinatie van Nierstenen en synoniem Nefroliet
    symptoms = "Symptomen: pijn en de patiënt moet heel vaak naar het toilet.",
  },
  transparency = {
    cause = "Oorzaak: het aflikken van bladfolie-lipjes van vers geopende zuivelproducten.",
    cure = "Behandeling: een drankje uit de apotheek, gemaakt van speciaal gekoeld en gekleurd water, verhelpt deze ziekte.",
    name = "Doorzichtigheid",
    symptoms = "Symptomen: organen worden doorzichtig en zien er ranzig uit.",
  },
  broken_heart = {
    cause = "Oorzaak: iemand die rijker, jonger en slanker is dan de patiënt.",
    cure = "Behandeling: twee chirurgen openen de borstkas en herstellen ademloos en liefdevol het hart.",
    name = "Gebroken hart",
    symptoms = "Symptomen: huilen en RSI door het constante verscheuren van vakantiefoto's.",
  },
  slack_tongue = {
    cause = "Oorzaak: eindeloos geklets over soaps.",
    cure = "Behandeling: de tong wordt in de Snijmachine geplaatst en snel, efficiënt en pijnlijk verwijderd.",
    name = "Lamme tong",
    symptoms = "Symptomen: tong zwelt op tot vijf maal de normale lengte.",
  },
  tv_personalities = {
    cause = "Oorzaak: dagtelevisie.",
    cure = "Behandeling: een getrainde psychiater moet de patiënt overtuigen zijn televisie te verkopen en een radio aan te schaffen.",
    name = "TV persoonlijkheid",
    symptoms = "Symptomen: de patiënt denkt dat hij of zij een kookprogramma kan presenteren.",
  },
  ruptured_nodules = {
    cause = "Oorzaak: bungeejumpen in de kou.",
    cure = "Behandeling: twee gekwalificeerde chirurgen verwijderen de knobbels met vaste hand.",
    name = "Gebarsten knobbels",
    symptoms = "Symptomen: niet lekker kunnen liggen.",
  },
  fractured_bones = {
    cause = "Oorzaak: van hoge dingen afvallen en op beton landen.",
    cure = "Behandeling: er wordt gips gezet en vervolgens verwijderd met een lasergestuurde machine.",
    name = "Botfractuur",
    symptoms = "Symptomen: luid gekraak en betreffend ledemaat niet meer kunnen gebruiken.",
  },
  chronic_nosehair = {
    cause = "Oorzaak: het ophalen van de neus in verachting voor mensen die slechter af zijn dan de patiënt.",
    cure = "Behandeling: een smerig, haar verwijderend drankje wordt door een zuster in de apotheek klaargemaakt en wordt door de patiënt gedronken.",
    name = "Chronisch neushaar",
    symptoms = "Symptomen: neushaar waarin een marter zich zou kunnen nestelen.",
  },
}
policy = {
  header = "Ziekenhuisbeleid",
  diag_termination = "diagnose stoppen",
  sliders = {
    guess = "GOKKEN",
    send_home = "WEGSTUREN",
    stop = "STOP PROCEDURE",
    staff_room = "GA NAAR DE PERSONEELSRUIMTE",
  },
  diag_procedure = "diagnostische procedures",
  staff_rest = "personeel laten rusten",
  staff_leave_rooms = "personeel verlaat kamers",
}
competitor_names = {
  [1] = "ORAC",
  [2] = "HAL",
  [3] = "COLOSSUS",
  [4] = "MULTIVAC",
  [5] = "HOLLY",
  [6] = "DEEP THOUGHT",
  [7] = "ZEN",
  [8] = "LEON",
  [9] = "AKIRA",
  [10] = "SAM",
  [11] = "CHARLIE",
  [12] = "JAYNE",
  [13] = "ARTHUR",
  [14] = "MAGNUS",
  [15] = "MOTHER",
  [16] = "SAL",
  [17] = "MARVIN",
  [18] = "JOSHUA",
  [19] = "DANEEL",
  [20] = "OLIVAW",
  [21] = "NIC",
  [22] = "DANEEL",
  [23] = "OLIVAW",
  [24] = "NIC",
}
main_menu = {
  exit = "Afsluiten",
  custom_level = "Uitzendwerk",
  new_game = "Nieuwe carrière",
  load_game = "Spel laden",
  options = "Instellingen",
  version = "Versie: ",
  savegame_version = "Savegame versie: ",
  continue = "Zet spel voort",
  custom_campaign = "Aangepaste carrière",
  updates_off = "Niet controleren op updates",
  map_edit = "Kaartbewerker",
}
confirmation = {  --spaces on the end make the text fit properly in text windows
  quit = "Weet je zeker dat je het spel wilt verlaten?                ",
  return_to_blueprint = "Weet je zeker dat je terug wil gaan naar de blauwdrukmodus?                   ",
  needs_restart = "Om deze instellingen toe te passen, moet CorsixTH opnieuw opstarten. Niet opgeslagen vooruitgang zal hierdoor verloren gaan. Weet je zeker dat je dit wil doen?                     ",
  overwrite_save = "Er is hier al een spel opgeslagen. Weet je zeker dat je het bestaande spel wilt overschrijven?                   ",
  delete_room = "Weet je zeker dat je deze kamer wilt verwijderen?                  ",
  sack_staff = "Weet je zeker dat je dit personeelslid wilt ontslaan?                  ",
  replace_machine = "Weet je zeker dat je de %s wilt vervangen voor $%d?           ",
  abort_edit_room = "Je bent een ruimte aan het bouwen of aanpassen. Wanneer alle benodigde objecten geplaatst zijn, is de ruimte af. Zo niet, dan wordt de ruimte vernietigd.                     ",
  restart_level = "Weet je zeker dat je het level opnieuw wilt beginnen?                      ",
  maximum_screen_size = "De resolutie die je hebt ingevoerd is groter dan 3000x2000. Een hoge resolutie is mogelijk, mits je hardware goed genoeg is om een speelbare framerate te behalen. Weet je zeker dat je wilt doorgaan?",
  replace_machine_extra_info = "De nieuwe machine zal %d vermogen hebben (momenteel %d)",
  remove_destroyed_room = "Wil je de kamer voor $%d verwijderen?",
  very_old_save = "Er zijn veel updates geweest sinds je met dit level bent begonnen. Om zeker te zijn dat alles werkt zoals het hoort, zou je nu opnieuw willen beginnen dit level?//Je opgeslagen spel blijft beschikbaar tenzij je het overschrijft.",
}
menu_display = {
  mcga_lo_res = "  LAGE RES  ",
  shadows = "  SHADUWEN  ",
  high_res = "  HOGE RES  ",
}
menu_list_window = {
  back = "Terug",
  save_date = "Gewijzigd op",
  name = "Naam",
  ok = "OK"
}
menu_options_volume = {
  [50] = "  50%  ",
  [100] = "  100%  ",
  [30] = "  30%  ",
  [60] = "  60%  ",
  [90] = "  90%  ",
  [10] = "  10%  ",
  [20] = "  20%  ",
  [40] = "  40%  ",
  [80] = "  80%  ",
  [70] = "  70%  ",
}
menu_file_load = {
  [1] = "  GAME 1  ",
  [2] = "  GAME 2  ",
  [3] = "  GAME 3  ",
  [4] = "  GAME 4  ",
  [5] = "  GAME 5  ",
  [6] = "  GAME 6  ",
  [7] = "  GAME 7  ",
  [8] = "  GAME 8  ",
}
menu_file = {
  quit =    "  (%1%) AFSLUITEN  ",
  save =    "  (%1%) OPSLAAN  ",
  load =    "  (%1%) LADEN  ",
  restart = "  (%1%) HERSTARTEN  ",
}
high_score = {
  categories = {
    deaths = "DODEN",
    total_value = "TOTALE WAARDE",
    money = "RIJKSTE",
    cures = "GENEZEN",
    visitors = "MEESTE BEZOEKERS",
    staff_number = "MEESTE PERSONEEL",
    cure_death_ratio = "GENEZINGEN VS DODEN",
    patient_happiness = "KLANTTEVREDENHEID",
    staff_happiness = "PERSONEELSTEVREDENHEID",
    salary = "HOOGSTE SALARIS",
    clean = "REINHEID",
  },
  player = "SPELER",
  score = "SCORE",
  pos = "POS",
  best_scores = "HALL OF FAME",
  worst_scores = "HALL OF SHAME",
  killed = "Gedood",
}

--[[ Ik denk niet dat het belangrijk is om dit stukje te vertalen.
     Als iemand geen Engels spreekt, zou hij sowieso niet met debug
     tools moeten zitten klooien. ]]--

menu_debug = {
  porter_pagers = "  PORTER PAGERS        ",  --[[ Wat? "portier biepers"? --]]
  display_pager = "  TOON PAGER        ", --[[ Een pager is zo een apparaatje dat in de nineties razend populair was... --]]
  disable_salary_raise = "  SALARISVERHOGINGEN UITSCHAKELEN  ",
  display_big_cells = "  BIG CELLS TONEN    ",
  make_debug_patient = "  DEBUG PATIENT  ",
  mapwho_checking = "  MAPWHO CHECKING      ",
  sprite_viewer = "  SPRITE VIEWER  ",
  keep_clear_cells = "  LEGE CELLS BEHOUDEN     ",
  dump_strings = "  (%1%) STRINGDUMP MAKEN  ",
  machine_pagers = "  MACHINE PAGERS       ",
  remove_objects = "  VOORWERPEN VERWIJDEREN       ",
  enter_nav_debug = "  GA NAAR NAV DEBUG      ",
  lose_game_anim = {
    [1] = "  VERLOREN 1 ANIM     ",
    [2] = "  VERLOREN 2 ANIM     ",
    [3] = "  VERLOREN 3 ANIM     ",
    [4] = "  VERLOREN 4 ANIM     ",
    [5] = "  VERLOREN 5 ANIM     ",
    [6] = "  VERLOREN 6 ANIM     ",
    [7] = "  VERLOREN 7 ANIM     ",
  },
  map_overlay = "  MAP OVERLAYS  ",
  display_room_status = "  KAMERSTATUS TONEN  ",
  win_game_anim = "  SPEL GEWONNEN ANIM        ",
  object_cells = "  VOORWERP CELLS         ",
  limit_camera = "  CAMERABEGRENZING  ",
  nav_bits = "  NAV BITS             ",
  remove_walls = "  MUREN ONZICHTBAAR MAKEN         ",
  dump_gamelog = "  (%1%) GAME LOG DUMPEN  ",
  win_level_anim = "  LEVEL GEWONNEN ANIM       ",
  pixbuf_cells = "  PIXBUF CELLS         ",
  transparent_walls = "  (%1%) TRANSPARANTE MUREN  ",
  show_help_hotspot = "  HELP HOTSPOTS TONEN   ",
  show_nav_cells = "  NAV CELLS TONEN       ",
  entry_cells = "  ENTRY CELLS          ",
  plant_pagers = "  PLANT PAGERS         ",
  lua_console = "  (%1%) LUA CONSOLE  ",
  make_debug_fax = "  DEBUG FAX  ",
  calls_dispatcher = "  CALLS DISPATCHER  ",
  cheats = "  (%1%) CHEATS  ",
  jump_to_level = "  SPRING NAAR LEVEL  ",
  debug_script = "  (%1%) LAAT FOUTSCRIPT LOPEN  ",
  connect_debugger = "  (%1%) MAAK VERBINDING MET LUA DBGp SERVER  ",
  allow_blocking_off_areas = "  STA TOE OM GEBIEDEN AF TE SLUITEN  ",
}

drug_companies = {
  [1] = "Machtige Medicatie",
  [2] = "GeneesGoed",
  [3] = "Pimpelpaarse Kruis",
  [4] = "Per Vers BV.",
  [5] = "OmniPharma VOF",
}

graphs = {
  deaths = "Doden",
  money_in = "Geld bij",
  money_out = "Geld af",
  visitors = "Bezoekers",
  wages = "Salaris",
  balance = "Saldo",
  time_spans = {
    [1] = "1 Jaar",
    [2] = "12 Jaar",
    [3] = "48 Jaar",
  },
  cures = "Genezingen",
  reputation = "Reputatie",
}
months = {
  [1] = "Jan",
  [2] = "Feb",
  [3] = "Maa",
  [4] = "Apr",
  [5] = "Mei",
  [6] = "Jun",
  [7] = "Jul",
  [8] = "Aug",
  [9] = "Sep",
  [10] = "Okt",
  [11] = "Nov",
  [12] = "Dec",
}
date_format.daymonth = "%1% %2:months%"

menu_options = {
  game_speed = "  SNELHEID  ",
  sound_vol = "  VOLUME GELUID  ",
  music_vol = "  VOLUME MUZIEK  ",
  announcements = "  OMROEPBERICHTEN   ",
  lock_windows = "  VENSTERS VASTZETTEN  ",
  sound = "  (%1%) GELUID   ",
  announcements_vol = "  (%1%) VOLUME OMROEPBERICHTEN  ",
  music = "  (%1%) MUZIEK   ",
  autosave = "  AUTOSAVE  ",
  jukebox = "  (%1%) JUKEBOX  ",
  edge_scrolling = "  RANDSCROLLEN  ",
  adviser_disabled = "  (%1%) ADVISEUR  ",
  warmth_colors = "  WARMTE KLEUREN  ",
  twentyfour_hour_clock = "  24 UUR KLOK  ",
  wage_increase = "  SALARIS VERZOEKEN  ",
  capture_mouse = "  MUIS VANGEN  ",
}
menu_options_wage_increase = {
  deny = "    AFWIJZEN ",
  grant = "    TOEKENNEN ",
}
menu_options_game_speed = {
  pause = "  (%1%) PAUZE  ",
  slowest = "  (%1%) EN NOG LANGZAMER  ",
  slower = "  (%1%) LANGZAAM  ",
  normal = "  (%1%) NORMAAL  ",
  max_speed = "  (%1%) MAX SNELHEID ",
  and_then_some_more = "  (%1%) EN NOG EEN BEETJE ",
}
menu_options_warmth_colors = {
  choice_1 = "   ROOD ",
  choice_2 = "   BLAUW, GROEN EN ROOD ",
  choice_3 = "   GEEL, ORANJE EN ROOD ",
}
menu = {
  debug = "  DEBUG  ",
  display = "  BEELD  ",
  file = "  BESTAND  ",
  options = "  OPTIES  ",
  charts = "  OVERZICHTEN  ",
  player_count = "  SPELERSAANTAL  ",
}
rooms_short = {
  ultrascan = "Echoscopie",
  research_room = "Laboratorium",
  fracture_clinic = "Gipskamer",
  gps_office = "Spreekkamer",
  destroyed = "Vernietigd",
  staffroom = "Personeelsruimte",
  jelly_vat = "Gelatinetank",
  scanner = "Scanner",
  decontamination = "Ontsmetting",
  pharmacy = "Apotheek",
  cardiogram = "Cardio",
  reception = "Receptie",
  training_room = "Klaslokaal",
  corridor_objects = "Gangartikelen",
  operating_theatre = "Operatiekamer",
  dna_fixer = "DNA hersteller",
  ward = "Slaapzaal",
  psychiatric = "Psychiatrie",
  hair_restoration = "Haarrestauratie",
  general_diag = "Algemene diagnose",
  inflation = "Inflatie",
  tongue_clinic = "Lamme tongkliniek",
  toilets = "Toiletten",
  electrolysis = "Elektrolyse",
  x_ray = "Röntgenkamer",
  blood_machine = "Bloedmachine",
}
object = {
  chair = "Stoel",
  litter = "Afval",
  sofa = "Sofa",
  operating_table = "Operatietafel",
  bed2 = "Bed",
  bench = "Bank",
  scanner = "Scanner",
  couch = "Sofa",
  blood_machine = "Bloedmachine",
  table1 = "Tafel",
  video_game = "Videospel",
  lamp = "Lamp",
  op_sink2 = "Wastafel",
  door = "Deur",
  auto_autopsy = "Auto Autopsie",
  reception_desk = "Receptie",
  hair_restorer = "Haarrestaurateur",
  projector = "Projector",
  crash_trolley = "Werktafel",
  tv = "Televisie",
  ultrascanner = "Echo apparaat",
  surgeon_screen = "Omkleedscherm",
  litter_bomb = "Afvalbom",
  inflator = "Compressor",
  table2 = "Tafel",
  desk = "Bureau",
  pool_table = "Biljarttafel",
  x_ray_viewer = "Röntgenscherm",
  radiation_shield = "Radiatieschild",
  bed = "Bed",
  swing_door2 = "Klapdeur",
  console = "Paneel",
  op_sink1 = "Wasbak",
  bookcase = "Boekenkast",
  drinks_machine = "Frisdrankautomaat",
  comfortable_chair = "Luie stoel",
  skeleton = "Geraamte",
  computer = "Computer",
  bin = "Prullenbak",
  pharmacy_cabinet = "Medicijnkast",
  radiator = "Radiator",
  cast_remover = "Gipsverwijderaar",
  atom_analyser = "Pulsmixer",
  plant = "Plant",
  jelly_moulder = "Gelatinetank",
  cardio = "Cardio",
  toilet = "Toilet",
  electrolyser = "Elektrolysator",
  fire_extinguisher = "Brandblusser",
  bed3 = "Bed",
  swing_door1 = "Klapdeur",
  lecture_chair = "Schoolbank",
  screen = "Screen",
  toilet_sink = "Wastafel",
  shower = "Cabine",
  gates_of_hell = "Poort naar de hel",
  entrance_right = "Rechterkant ingang",
  entrance_left = "Linkerkant ingang",
  slicer = "Snijmachine",
  dna_fixer = "DNA reparatiemachine",
  x_ray = "Röntgen",
  cabinet = "Dossierkast",
  rathole = "Rattenhol"
}
pay_rise = {
  definite_quit = "Niets kan mij hier nog houden. Ik heb hier schoon genoeg van.",
  regular = {
    [1] = "Ik ben kapot. Ik moet eens goed uitrusten en een salarisverhoging krijgen van %d, tenzij je graag wil zien hoe ik dit rotbaantje vaarwel zeg.",
    [2] = "Ik ben erg moe. Ik heb rust nodig en een salarisverhoging van %d naar %d. En snel een beetje, slavendrijver!",
    [3] = "Kom op! Ik werk me uit de naad. Geef me een bonus van %d, dan blijf ik in je ziekenhuis.",
    [4] = "Ik ben hier erg ongelukkig. Ik eis een opslag van %d, zodat mijn salaris %d wordt, anders pak ik mijn biezen.",
    [5] = "Mijn ouders vertelden me dat het salaris van een medicus fantastisch was. Geef me dus een opslag van %d, anders word ik programmeur.",
    [6] = "Ik ben het zat. Geef me een fatsoenlijk salaris. Een opslag van %d moet genoeg zijn.",
  },
  poached = "Ik heb een aanbod van %d gekregen van %s. Als je me niet hetzelfde betaalt ben ik weg.",
}
town_map = {
  number = "Landnummer",
  not_for_sale = "Niet voor verkoop",
  chat = "Chatroom",
  price = "Landprijs",
  for_sale = "Te koop",
  owner = "Eigenaar",
  area = "Gebied",
}
level_names = {
  [1] = "Ziekwijk",
  [2] = "Rustenvreugd",
  [3] = "Grootzand",
  [4] = "Uitwijk-aan-Zee",
  [5] = "Eenwoud",
  [6] = "Pusch-aan-de-Gaas",
  [7] = "Groenpoel",
  [8] = "Manwerf",
  [9] = "Oostdorp",
  [10] = "Schakendam",
  [11] = "Ferekhart",
  [12] = "Knuppelenburg",
  [13] = "Laagschorem",
  [14] = "Klein Hildrecht",
  [15] = "Diepegraven",
}
build_room_window = {
  pick_room_type = "Kies soort",
  pick_department = "Kies afdeling",
  cost = "Kosten: ",
}
insurance_companies = { --[[''VOF'' em ''BV'' regelmatig verwijderd i.v.m. de niet passende tekst.]]--
  [1] = "ZwaanBlat BV",
  [2] = "Oorha",
  [3] = "FTBA",
  [4] = "Achweeja",
  [5] = "Zwemblaas BV",
  [6] = "Noordelijk Beheer",
  [7] = "Aagod",
  [8] = "Leo Katjes NV.",
  [9] = "Pokkie en Keppie",
  [10] = "Blij met Blijheid",
  [11] = "De Familie",
  out_of_business = "FAILLIET",
}
menu_file_save = {
  [1] = "  SPEL 1  ",
  [2] = "  SPEL 2  ",
  [3] = "  SPEL 3  ",
  [4] = "  SPEL 4  ",
  [5] = "  SPEL 5  ",
  [6] = "  SPEL 6  ",
  [7] = "  SPEL 7  ",
  [8] = "  SPEL 8  ",
}
new_game_window = {
  player_name = "Gebruikersnaam",
  difficulty = "Selecteer moeilijkheid",
  hard = "Specialist (Moeilijk)",
  medium = "Arts (Gemiddeld)",
  easy = "Assistent (Makkelijk)",
  start = "Begin",
  cancel = "Annuleren",
  tutorial = "Leermodus",
  option_on = "Aan",
  option_off = "Uit",
  caption = "Nieuwe carrière",
}
calls_dispatcher = {
  repair = "Reparatie",
  summary = "%d oproepen, %d toegewezen",
  close = "Sluiten",
  watering = "Watergeven @ %d,%d",
  staff = "%s - %s",
}
debug_patient_window = {
  caption = "Debug patiënt",
}
lua_console = {
  execute_code = "Uitvoeren",
  close = "Sluiten",
}
cheats_window = {
  cheats = {
    end_month = "Einde van de maand",
    emergency = "Creëer noodgeval",
    vip = "Creëer VIP",
    win_level = "Win Level",
    create_patient = "Creëer patiënt",
    money = "Geld cheat (+ $10.000)",
    lose_level = "Verlies Level",
    all_research = "All research cheat",
    end_year = "Einde van het jaar",
    earthquake = "Creëer aardbeving",
    epidemic = "Besmettelijke patient laten verschijnen",
    toggle_infected = "Aan/uit zetten besmet iconen",
    decrease_prices = "Prijzen verlagen",
    increase_prices = "Prijzen verhogen",
    max_reputation = "Maximale reputatie",
    reset_death_count = "Reset sterfgevallen",
    show_infected = "Geïnfecteerde iconen schakelen",
    toggle_epidemic = "Epidemieën schakelen",
    toggle_earthquake = "Aardbevingen schakelen",
  },
  cheated = {
    no = "Cheats gebruikt: Nee",
    yes = "Cheats gebruikt: Ja",
  },
  close = "Sluiten",
  caption = "Cheats",
  warning = "Waarschuwing: wanneer je cheat zul je aan het einde van het level geen bonuspunten verdienen",
}
handyman_window = {
  all_parcels = "Overal", --Translates to: Everywhere, because the full Dutch translation would be far too long to fit the ingame window
  parcel = "Gebouw",
}
original_credits = {
  [1] = " ",
  [2] = " ",
  [3] = " ",
  [4] = " ",
  [5] = " ",
  [6] = " ",
  [7] = " ",
  [8] = " ",
  [9] = " ",
  [10] = " ",
  [11] = " ",
  [12] = ":Designed and Created by",
  [13] = ":Bullfrog Productions",
  [14] = " ",
  [15] = ":Pluto Development Team",
  [16] = ",",
  [17] = "Mark Webley",
  [18] = "Gary Carr",
  [19] = "Matt Chilton",
  [20] = "Matt Sullivan",
  [21] = "Jo Rider",
  [22] = "Rajan Tande",
  [23] = "Wayne Imlach",
  [24] = "Andy Bass",
  [25] = "Jon Rennie",
  [26] = "Adam Coglan",
  [27] = "Natalie White",
  [28] = " ",
  [29] = " ",
  [30] = " ",
  [31] = ":Programming",
  [32] = ",",
  [33] = "Mark Webley",
  [34] = "Matt Chilton",
  [35] = "Matt Sullivan",
  [36] = "Rajan Tande",
  [37] = " ",
  [38] = " ",
  [39] = " ",
  [40] = ":Art",
  [41] = ",",
  [42] = "Gary Carr",
  [43] = "Jo Rider",
  [44] = "Andy Bass",
  [45] = "Adam Coglan",
  [46] = " ",
  [47] = " ",
  [48] = " ",
  [49] = ":Additional Programming",
  [50] = ",",
  [51] = "Ben Deane",
  [52] = "Gary Morgan",
  [53] = "Jonty Barnes",
  [54] = " ",
  [55] = " ",
  [56] = " ",
  [57] = ":Additional Art",
  [58] = ",",
  [59] = "Eoin Rogan",
  [60] = "George Svarovsky",
  [61] = "Saurev Sarkar",
  [62] = "Jason Brown",
  [63] = "John Kershaw",
  [64] = "Dee Lee",
  [65] = " ",
  [66] = " ",
  [67] = " ",
  [68] = ":Intro Sequence",
  [69] = ",",
  [70] = "Stuart Black",
  [71] = " ",
  [72] = " ",
  [73] = " ",
  [74] = ":Music and Sound Effects",
  [75] = ",",
  [76] = "Russell Shaw",
  [77] = "Adrian Moore",
  [78] = " ",
  [79] = " ",
  [80] = " ",
  [81] = ":Additional Music",
  [82] = ",",
  [83] = "Jeremy Longley",
  [84] = "Andy Wood",
  [85] = " ",
  [86] = " ",
  [87] = " ",
  [88] = ":Announcer Voiceover",
  [89] = ",",
  [90] = "Rebecca Green",
  [91] = " ",
  [92] = " ",
  [93] = " ",
  [94] = ":Level Design",
  [95] = ",",
  [96] = "Wayne Imlach",
  [97] = "Natalie White",
  [98] = "Steven Jarrett",
  [99] = "Shin Kanaoya",
  [100] = " ",
  [101] = " ",
  [102] = " ",
  [103] = ":Scripting",
  [104] = ",",
  [105] = "James Leach",
  [106] = "Sean Masterson",
  [107] = "Neil Cook",
  [108] = " ",
  [109] = " ",
  [110] = " ",
  [111] = ":R&D",
  [112] = " ",
  [113] = ":Graphics Engine",
  [114] = ",",
  [115] = "Andy Cakebread",
  [116] = "Richard Reed",
  [117] = " ",
  [118] = " ",
  [119] = " ",
  [120] = ":R&D Support",
  [121] = ",",
  [122] = "Glenn Corpes",
  [123] = "Martin Bell",
  [124] = "Ian Shaw",
  [125] = "Jan Svarovsky",
  [126] = " ",
  [127] = " ",
  [128] = " ",
  [129] = ":Library and Tools",
  [130] = " ",
  [131] = "Dos and Win 95 Library",
  [132] = ",",
  [133] = "Mark Huntley",
  [134] = "Alex Peters",
  [135] = "Rik Heywood",
  [136] = " ",
  [137] = " ",
  [138] = " ",
  [139] = ":Network Library",
  [140] = ",",
  [141] = "Ian Shippen",
  [142] = "Mark Lamport",
  [143] = " ",
  [144] = " ",
  [145] = " ",
  [146] = ":Sound Library",
  [147] = ",",
  [148] = "Russell Shaw",
  [149] = "Tony Cox",
  [150] = " ",
  [151] = " ",
  [152] = " ",
  [153] = ":Installer Programming",
  [154] = ",",
  [155] = "Andy Nuttall",
  [156] = "Tony Cox",
  [157] = "Andy Cakebread",
  [158] = " ",
  [159] = " ",
  [160] = " ",
  [161] = ":Moral Support",
  [162] = ",",
  [163] = "Peter Molyneux",
  [164] = " ",
  [165] = " ",
  [166] = " ",
  [167] = ":Testing Manager",
  [168] = ",",
  [169] = "Andy Robson",
  [170] = " ",
  [171] = " ",
  [172] = " ",
  [173] = ":Lead Testers",
  [174] = ",",
  [175] = "Wayne Imlach",
  [176] = "Jon Rennie",
  [177] = " ",
  [178] = " ",
  [179] = " ",
  [180] = ":Play Testers",
  [181] = ",",
  [182] = "Jeff Brutus",
  [183] = "Wayne Frost",
  [184] = "Steven Lawrie",
  [185] = "Tristan Paramor",
  [186] = "Nathan Smethurst",
  [187] = " ",
  [188] = "Ryan Corkery",
  [189] = "Simon Doherty",
  [190] = "James Dormer",
  [191] = "Martin Gregory",
  [192] = "Ben Lawley",
  [193] = "Joel Lewis",
  [194] = "David Lowe",
  [195] = "Robert Monczak",
  [196] = "Dominic Mortoza",
  [197] = "Karl O'Keeffe",
  [198] = "Michael Singletary",
  [199] = "Andrew Skipper",
  [200] = "Stuart Stephen",
  [201] = "David Wallington",
  [202] = " ",
  [203] = "And all our other Work Experience Play Testers",
  [204] = " ",
  [205] = " ",
  [206] = " ",
  [207] = ":Technical Support",
  [208] = ",",
  [209] = "Kevin Donkin",
  [210] = "Mike Burnham",
  [211] = "Simon Handby",
  [212] = " ",
  [213] = " ",
  [214] = " ",
  [215] = ":Marketing",
  [216] = ",",
  [217] = "Pete Murphy",
  [218] = "Sean Ratcliffe",
  [219] = " ",
  [220] = " ",
  [221] = " ",
  [222] = ":With thanks to:",
  [223] = ",",
  [224] = "Tamara Burke",
  [225] = "Annabel Roose",
  [226] = "Chris Morgan",
  [227] = "Pete Larsen",
  [228] = " ",
  [229] = " ",
  [230] = " ",
  [231] = ":PR",
  [232] = ",",
  [233] = "Cathy Campos",
  [234] = " ",
  [235] = " ",
  [236] = " ",
  [237] = ":Documentation",
  [238] = ",",
  [239] = "Mark Casey",
  [240] = "Richard Johnston",
  [241] = "James Lenoel",
  [242] = "Jon Rennie",
  [243] = " ",
  [244] = " ",
  [245] = " ",
  [246] = ":Documentation & Packaging Design",
  [247] = ",",
  [248] = "Caroline Arthur",
  [249] = "James Nolan",
  [250] = " ",
  [251] = " ",
  [252] = " ",
  [253] = ":Localisation Project Manager",
  [254] = ",",
  [255] = "Carol Aggett",
  [256] = " ",
  [257] = " ",
  [258] = " ",
  [259] = ":Localisation",
  [260] = ",",
  [261] = "Sandra Picaper",
  [262] = "Sonia 'Sam' Yazmadjian",
  [263] = " ",
  [264] = "Bettina Klos",
  [265] = "Alexa Kortsch",
  [266] = "Bianca Normann",
  [267] = " ",
  [268] = "C.T.O. S.p.A. Zola Predosa (BO)",
  [269] = "Gian Maria Battistini",
  [270] = "Maria Ziino",
  [271] = "Gabriele Vegetti",
  [272] = " ",
  [273] = "Elena Ruiz de Velasco",
  [274] = "Julio Valladares",
  [275] = "Ricardo Martinez",
  [276] = " ",
  [277] = "Kia Collin",
  [278] = "CBG Consult",
  [279] = "Ulf Thor",
  [280] = " ",
  [281] = " ",
  [282] = " ",
  [283] = ":Production",
  [284] = ",",
  [285] = "Rachel Holman",
  [286] = " ",
  [287] = " ",
  [288] = " ",
  [289] = ":Producer",
  [290] = ",",
  [291] = "Mark Webley",
  [292] = " ",
  [293] = " ",
  [294] = " ",
  [295] = ":Associate Producer",
  [296] = ",",
  [297] = "Andy Nuttall",
  [298] = " ",
  [299] = " ",
  [300] = " ",
  [301] = ":Operations",
  [302] = ",",
  [303] = "Steve Fitton",
  [304] = " ",
  [305] = " ",
  [306] = " ",
  [307] = ":Company Administration",
  [308] = ",",
  [309] = "Audrey Adams",
  [310] = "Annette Dabb",
  [311] = "Emma Gibbs",
  [312] = "Lucia Gobbo",
  [313] = "Jo Goodwin",
  [314] = "Sian Jones",
  [315] = "Kathy McEntee",
  [316] = "Louise Ratcliffe",
  [317] = " ",
  [318] = " ",
  [319] = " ",
  [320] = ":Company Management",
  [321] = ",",
  [322] = "Les Edgar",
  [323] = "Peter Molyneux",
  [324] = "David Byrne",
  [325] = " ",
  [326] = " ",
  [327] = ":All at Bullfrog Productions",
  [328] = " ",
  [329] = " ",
  [330] = " ",
  [331] = ":Special Thanks to",
  [332] = ",",
  [333] = "Everyone at Frimley Park Hospital",
  [334] = " ",
  [335] = ":Especially",
  [336] = ",",
  [337] = "Beverley Cannell",
  [338] = "Doug Carlisle",
  [339] = " ",
  [340] = " ",
  [341] = " ",
  [342] = ":Keep On Thinking",
  [343] = " ",
  [344] = " ",
  [345] = " ",
  [346] = " ",
  [347] = " ",
  [348] = " ",
  [349] = " ",
  [350] = " ",
  [351] = " ",
  [352] = " ",
  [353] = " ",
  [354] = " ",
  [355] = " ",
  [356] = " ",
  [357] = " ",
  [358] = " ",
  [359] = " ",
  [360] = " ",
  [361] = ".",
}
multiplayer = {
  everyone_failed = "Niemand slaagde erin om aan dat laatste doel te voldoen. Dus krijgt iedereen nog een kans om te spelen!",
  players_failed = "De volgende speler(s) slaagden er niet in om het laatste doel te behalen:",
}
save_map_window = {
  caption = "Map opslaan (%1%)",
  new_map = "Nieuwe map",
}
map_editor_window = {
  pages = {
    camera_1 = "Camera 1",
    camera_2 = "Camera 2",
    camera_3 = "Camera 3",
    camera_4 = "Camera 4",
    delete_wall = "Muren verwijderen",
    foliage = "Beplanting",
    hedgerow = "Haag",
    helipad = "Helikopterplatform",
    heliport_1 = "Heliport 1",
    heliport_2 = "Heliport 2",
    heliport_3 = "Heliport 3",
    heliport_4 = "Heliport 4",
    inside = "Binnen",
    north_wall = "Noordelijke muur",
    outside = "Buiten",
    pond = "Vijver",
    paste = "Gebied plakken",
    parcel = "Pakket %d",
    road = "Straat",
    set_parcel_tooltip = "Kies een nummer en druk op enter.",
    set_parcel = "Zet pakket nummer",
    west_wall = "Westelijke muur",
  },
  checks = {
    spawn_points_and_path = "Waarschuwing: Patiënten kunnen het ziekenhuis niet bereiken. Ze hebben 'weg'-tegels of 'buiten'-grijze tegels nodig aan de rand van de map en een pad van deze tegels naar de ingang van het ziekenhuis.",
  },
}
warnings = {
  levelfile_variable_is_deprecated = "Let op: Het level '%s' bevat een verouderde variabele definitie in het levelbestand. '%LevelFile' is hernoemd naar '%MapFile'. Geef de maker van dit scenario advies om het level bij te werken.",
  newersave = "Waarschuwing, je hebt een spel geladen die in een nieuwere versie van CorsixTH is opgeslagen. Het wordt afgeraden om door te gaan, omdat er crashes kunnen optreden. Speel op eigen risico.",
}
disease_discovered_patient_choice = {
  need_to_employ = "Schakel een %s in die deze situatie kan behandelen."
}
hotkeys_file_err = {
  file_err_01 = "Kan hotkeys.txt-bestand niet laden. Zorg ervoor dat CorsixTH lees-/schrijfrechten heeft ",
  file_err_02 = ", of gebruik de opdrachtregeloptie --hotkeys-file=bestandsnaam om een beschrijfbaar bestand op te geven. Ter referentie, de fout bij het laden van het hotkeys-bestand was: ",
}
level_progress = {
  cured_enough_patients = "Je hebt genoeg patiënten genezen, maar je moet je ziekenhuis beter op orde krijgen om het level te winnen.",
  hospital_value_enough = "Houd de waarde van je ziekenhuis boven %d en los je andere problemen op om het level te winnen.",
}
menu_player_count = {
  players_1 = "  1 SPELER  ",
  players_2 = "  2 SPELERS  ",
  players_3 = "  3 SPELERS  ",
  players_4 = "  4 SPELERS  ",
}
custom_campaign_window = {
  caption = "Aangepaste carrière",
  start_selected_campaign = "Start carrière",
}
hotkey_window = {
  button_accept = "Opslaan",
  button_back = "Terug",
  button_cancel = "Annuleren",
  button_defaults = "Herstel naar standaardinstellingen",
  button_gameSpeedKeys = "Spel snelheid toetsen",
  button_recallPosKeys = "Camera positie toetsen",
  button_toggleKeys = "Schakel toetsen",

  caption_main = "Sneltoetsen toewijzen",
  caption_panels = "Paneeltoetsen",

  global_cancel = "Annuleren",
  global_cancel_alt = "Annuleren (alternatief)",
  global_confirm = "Accepteren",
  global_confirm_alt = "Accepteren (alternatief)",
  global_connectDebugger = "Debugger",
  global_exitApp = "Applicatie afsluiten",
  global_fullscreen_toggle = "Volledig scherm",
  global_releaseMouse = "Laat de muis los",
  global_resetApp = "Applicatie herstarten",
  global_runDebugScript = "Debugscript",
  global_showLuaConsole = "Lua-console",
  global_stop_movie_alt = "Stop Video",
  global_screenshot = "Schermafbeelding",
  global_window_close_alt = "Venster Sluiten",

  panel_debugKeys = "Debug Toetsen",
  panel_generalInGameKeys = "Algemene Spel Toetsen",
  panel_globalKeys = "Globale Toetsen",
  panel_gameSpeedKeys = "Spel Snelheid Toetsen",
  panel_recallPosKeys = "Camera Positie Laden",
  panel_scrollKeys = "Scroll Toetsen",
  panel_toggleKeys = "Schakel Toetsen",
  panel_storePosKeys = "Camera Positie Opslag",
  panel_zoomKeys = "Zoom Toetsen",

  ingame_gamespeed_speedup = "Versnellen",

  ingame_gamespeed_slowest = "En Nog Langzamer",
  ingame_gamespeed_slower = "Langzaam",
  ingame_gamespeed_normal = "Normaal",
  ingame_gamespeed_max = "Max Snelheid",
  ingame_gamespeed_thensome = "En Nog Een Beetje",

  ingame_jukebox = "Jukebox",

  ingame_loadMenu = "Spel Laden",

  ingame_openFirstMessage = "Level Bericht",

  ingame_panel_bankManager = "Kasboek",
  ingame_panel_bankStats = "Afschriften",
  ingame_panel_buildRoom = "Kamer Bouwen",
  ingame_panel_casebook = "Dossier",
  ingame_panel_casebook_alt = "Dossier 2",
  ingame_panel_casebook_alt02 = "Dossier 3",
  ingame_panel_charts = "Grafieken",
  ingame_panel_editRoom = "Kamer Verbouwen",
  ingame_panel_furnishCorridor = "Gang Inrichten",
  ingame_panel_hireStaff = "Personeel Inhuren",
  ingame_panel_map_alt = "Kaart 2",
  ingame_panel_policy = "Ziekenhuisbeleid",
  ingame_panel_research = "Onderzoek",
  ingame_panel_research_alt = "Onderzoek 2",
  ingame_panel_staffManage = "Personeel Beheren",
  ingame_panel_status = "Voortgang",
  ingame_panel_townMap = "Kaart",
  ingame_patient_gohome = "Stuur Naar Huis",
  ingame_pause = "Pauzeren",
  ingame_poopLog = "Dump Log",
  ingame_poopStrings = "Dump Vertalingen",

  ingame_quickLoad = "Snel Laden",
  ingame_quickSave = "Snel Opslaan",
  ingame_quitLevel = "Sluit Level",

  ingame_recallPosition_0 = "10",
  ingame_recallPosition_1 = "1",
  ingame_recallPosition_2 = "2",
  ingame_recallPosition_3 = "3",
  ingame_recallPosition_4 = "4",
  ingame_recallPosition_5 = "5",
  ingame_recallPosition_6 = "6",
  ingame_recallPosition_7 = "7",
  ingame_recallPosition_8 = "8",
  ingame_recallPosition_9 = "9",
  ingame_reset_zoom = "Zoom Resetten",
  ingame_restartLevel = "Herstart Level",
  ingame_rotateobject = "Roteer Object",

  ingame_saveMenu = "Spel Opslaan",
  ingame_scroll_up = "Omhoog Scrollen",
  ingame_scroll_down = "Omlaag Scrollen",
  ingame_scroll_left = "Links Scrollen",
  ingame_scroll_right = "Rechts Scrollen",
  ingame_scroll_shift = "Snelheid Aanpassen",
  ingame_setTransparent = "Transparant",
  ingame_showCheatWindow = "Cheatsmenu",
  ingame_showmenubar = "Menu Balk Weergeven",
  ingame_storePosition_0 = "10",
  ingame_storePosition_1 = "1",
  ingame_storePosition_2 = "2",
  ingame_storePosition_3 = "3",
  ingame_storePosition_4 = "4",
  ingame_storePosition_5 = "5",
  ingame_storePosition_6 = "6",
  ingame_storePosition_7 = "7",
  ingame_storePosition_8 = "8",
  ingame_storePosition_9 = "9",

  ingame_toggleAdvisor = "Adviseur",
  ingame_toggleAnnouncements = "Mededelingen",
  ingame_toggleInfo = "Informatie",
  ingame_toggleMusic = "Muziek",
  ingame_toggleSounds = "Geluiden",

  ingame_zoom_in = "Inzoomen",
  ingame_zoom_in_more = "Meer Inzoomen",
  ingame_zoom_out = "Uitzoomen",
  ingame_zoom_out_more = "Meer Uitzoomen",
}
